#!/usr/bin/env perl

#
# PostGIS - Spatial Types for PostgreSQL
# http://postgis.net
#
# Copyright (C) 2011 OpenGeo.org
# Copyright (C) 2009 Paul Ramsey <pramsey@cleverelephant.ca>
#
# This is free software; you can redistribute and/or modify it under
# the terms of the GNU General Public Licence. See the COPYING file.
#
#---------------------------------------------------------------------
#
# This script is aimed at restoring postgis data
# from a dumpfile produced by pg_dump -Fc
#
# Basically it will restore all but things known to belong
# to postgis. Will also convert some old known constructs
# into new ones.
#
# Tested on:
#
#    pg-8.4.9/pgis-1.4.3    => pg-8.4.9/pgis-2.0.0SVN
#    pg-8.4.9/pgis-2.0.0SVN => pg-8.4.9/pgis-2.0.0SVN
#    pg-8.4.9/pgis-2.0.0SVN => pg-9.1.2/pgis-2.0.0SVN
#    pg-9.1b3/pgis-1.5.3    => pg-9.1.1/pgis-2.0.0SVN
#
#---------------------------------------------------------------------

use warnings;
use strict;

my $me = $0;

my $usage = qq{
Usage:	$me [-v] [-L TOC] [-s schema] <dumpfile>
        Restore a custom dump (pg_dump -Fc) of a PostGIS-enabled database.
        First dump the old database: pg_dump -Fc MYDB > MYDB.dmp
        Then create a new database: createdb NEWDB
        Then install PostGIS in the new database:
           psql -f postgis/postgis.sql NEWDB
        Also install PostGIS topology and raster, if you were using them:
           psql -f topology/topology.sql NEWDB
           psql -f raster/rtpostgis.sql NEWDB
        Finally, pass the dump to this script and feed output to psql:
           $me MYDB.dmp | psql NEWDB
        The -v switch writes detailed report on stderr.
        Use -L to provide a TOC rather than extracting it from the dump.
        Use -s if you installed PostGIS in a custom schema.

};

my $DEBUG = 0;
my $POSTGIS_SCHEMA;
my $POSTGIS_TOC;

# NOTE: the SRID limits here are being discussed:
# http://lists.osgeo.org/pipermail/postgis-devel/2012-February/018440.html
my $SRID_MAXIMUM = 999999;
my $SRID_USER_MAXIMUM = 998999;

while (@ARGV && $ARGV[0] =~ /^-/) {
  my $arg = shift(@ARGV);
  if ( $arg eq '-v' ) {
    $DEBUG = 1;
  }
  elsif ( $arg eq '-s' ) {
    $POSTGIS_SCHEMA = shift(@ARGV);
  }
  elsif ( $arg eq '-L' ) {
    $POSTGIS_TOC = shift(@ARGV);
  }
  elsif ( $arg eq '--' ) {
    last;
  }
  else {
    print STDERR "Unknown switch " . $arg;
    die $usage;
  }
}

die $usage if (@ARGV < 1);

my $dumpfile = $ARGV[0];
my $manifest = $dumpfile;
$manifest =~ s/\/$//; # strip trailing slash
$manifest .= ".lst";
my $hasTopology = 0;

die "$me:\tUnable to find 'pg_dump' on the path.\n" if ! `pg_dump --version`;
die "$me:\tUnable to find 'pg_restore' on the path.\n" if ! `pg_restore --version`;
die "$me:\tUnable to open dump file '$dumpfile'.\n" if ! -r $dumpfile;

print STDERR "Converting $dumpfile to ASCII on stdout...\n";

STDOUT->autoflush(1);

######################################################################
# Load the signatures of things to skip.
#

print STDERR "  Reading list of functions to ignore...\n";

my %skip = ();
while(my $l = <DATA>) {
  chop($l);
  print STDERR "DATA: $l\n" if $DEBUG;
  $l =~ s/\s//g;
  $skip{$l} = 1;
}

######################################################################
# Write a new manifest for the dump file, skipping the things that
# are part of PostGIS
#

if(!defined($POSTGIS_TOC)) {
  print STDERR "  Writing manifest of things to read from dump file...\n";

  open( DUMP, "pg_restore -f - -l $dumpfile |" ) || die "$me:\tCannot open dump file '$dumpfile'\n";
} else {
  open( DUMP, '<' . $POSTGIS_TOC) || die "$me:\tCannot open TOC file '$POSTGIS_TOC'\n";
}
open( MANIFEST, ">$manifest" ) || die "$me:\tCannot open manifest file '$manifest'\n";
while( my $l = <DUMP> ) {

  next if $l =~ /^\;/;
  my $sigHR = linesignature($l);
  my $sig = $sigHR; $sig =~ s/\s//g;
  $hasTopology = 1 if $sig eq 'SCHEMAtopology';

	if ( not defined ($POSTGIS_SCHEMA) )
	{
		if ( $l =~ / TABLE DATA ([^ ]*) spatial_ref_sys / )
		{
			$POSTGIS_SCHEMA = $1;
			print STDERR "Setting postgis schema to $POSTGIS_SCHEMA, as found in the dump";
		}
	}

  if ( $skip{$sig} ) {
    print STDERR "SKIP: $sigHR\n" if $DEBUG;
    next
  }
  print STDERR "KEEP: $sigHR\n" if $DEBUG;
  print MANIFEST $l;

}
close(MANIFEST);
close(DUMP) || die "$me: pg_restore returned an error\n";

######################################################################
# Convert the dump file into an ASCII file, stripping out the
# unwanted bits.
#
print STDERR "  Writing ASCII to stdout...\n";
open( INPUT, "pg_restore -f - -L $manifest $dumpfile |") || die "$me:\tCan't run pg_restore\n";

if ( defined $POSTGIS_SCHEMA ) {
  print STDOUT "SET search_path = \"" . $POSTGIS_SCHEMA . "\";\n";
}

#
# Disable topology metadata tables triggers to allow for population
# in arbitrary order.
#
if ( $hasTopology ) {
  print STDOUT "ALTER TABLE topology.layer DISABLE TRIGGER ALL;\n";
}

# Drop the spatial_ref_sys_srid_check to allow for custom invalid SRIDs in the dump
print STDOUT "ALTER TABLE spatial_ref_sys DROP constraint "
           . "spatial_ref_sys_srid_check;\n";
# Drop the spatial_ref_sys primary key to allow for SRID conversions
# which possibly end up taking the same spot
print STDOUT "ALTER TABLE spatial_ref_sys DROP constraint "
           . "spatial_ref_sys_pkey;\n";

# Backup entries found in new spatial_ref_sys for later updating the
print STDOUT "CREATE TEMP TABLE _pgis_restore_spatial_ref_sys AS "
            ."SELECT * FROM spatial_ref_sys;\n";
print STDOUT "DELETE FROM spatial_ref_sys;\n";

my $inCopy;
while( my $l = <INPUT> ) {
  if ( $l =~ /^COPY .+ FROM stdin;$/ ) {
    $inCopy = 1;
  }
  elsif ( $inCopy && $l =~ /^\\\.$/ ) {
    $inCopy = 0;
  }

  next if !$inCopy && $l =~ /^ *--/;

  if ( $l =~ /^SET search_path/ ) {
    $l =~ s/; *$/, public;/;
  }

  # This is to avoid confusing OPERATOR CLASS and OPERATOR FAMILY
  # with OPERATOR below
  elsif ( $l =~ /CREATE OPERATOR CLASS/ || $l =~ /CREATE OPERATOR FAMILY/ )
  {
  }

  # We can't skip OPERATORS from the manifest file
  # because it doesn't contain enough informations
  # about the type the operator is for
  elsif ( $l =~ /CREATE OPERATOR *([^ ,]*)/)
  {
    my $name = canonicalize_typename($1);
    my $larg = undef;
    my $rarg = undef;
    my @sublines = ($l);
    while( my $subline = <INPUT>)
    {
      push(@sublines, $subline);
      last if $subline =~ /;[\t ]*$/;
      if ( $subline =~ /leftarg *= *([^ ,]*)/i )
      {
        $larg=canonicalize_typename($1);
      }
      if ( $subline =~ /rightarg *= *([^ ,]*)/i )
      {
        $rarg=canonicalize_typename($1);
      }
    }

    if ( ! $larg ) {
      print STDERR "No larg, @sublines: [" . @sublines . "]\n";
    }

    my $sigHR = "OPERATOR " . $name .' ('.$larg.', '.$rarg.')';
    my $sig = $sigHR; $sig =~ s/\s//g;

    if ( $skip{$sig} )
    {
       print STDERR "SKIP: $sig\n" if $DEBUG;
       next;
    }

    print STDERR "KEEP: $sig\n" if $DEBUG;
    print STDOUT @sublines;
    next;
  }

  # Rewrite spatial table constraints
  #
  # Example 1:
  # CREATE TABLE geos_in (
  #     id integer NOT NULL,
  #     g public.geometry,
  #     CONSTRAINT enforce_dims_g CHECK ((public.st_ndims(g) = 2)),
  #     CONSTRAINT enforce_geotype_g CHECK (((public.geometrytype(g) = 'MULTILINESTRING'::text) OR (g IS NULL))),
  #     CONSTRAINT enforce_srid_g CHECK ((public.st_srid(g) = (-1)))
  # );
  #
  # Example 2:
  # CREATE TABLE boszip (
  #     gid integer NOT NULL,
  #     zip5 character(5),
  #     the_geom geometry,
  #     CONSTRAINT enforce_dims_the_geom CHECK ((ndims(the_geom) = 2)),
  #     CONSTRAINT enforce_geotype_the_geom CHECK (((geometrytype(the_geom) = 'MULTIPOLYGON'::text) OR (the_geom IS NULL))),
  #     CONSTRAINT enforce_srid_the_geom CHECK ((srid(the_geom) = 2249))
  # );
  #
  # Example 3:
  # CREATE TABLE "PIANIFICAZIONE__ELEMENTO_LINEA" (
  #     soft_gis_serial integer NOT NULL,
  #     "G" public.geometry,
  #     CONSTRAINT "enforce_dims_G" CHECK ((public.st_ndims("G") = 2)),
  #     CONSTRAINT "enforce_geotype_G" CHECK (((public.geometrytype("G") = 'MULTICURVE'::text) OR ("G" IS NULL))),
  #     CONSTRAINT "enforce_srid_G" CHECK ((public.st_srid("G") = (-1)))
  # );
  #
  #
  elsif ( $l =~ /CREATE TABLE *([^ ,]*)/)
  {
    print STDOUT $l;
    while( my $subline = <INPUT>)
    {
      if ( $subline =~ /CONSTRAINT "?enforce_dims_/i ) {
        $subline =~ s/\bndims\(/st_ndims(/;
      }
      if ( $subline =~ /CONSTRAINT "?enforce_srid_/i ) {
        $subline =~ s/\bsrid\(/st_srid(/;
        if ( $subline =~ /=\s\(?([-0-9][0-9]*)\)/ ) {
          my $oldsrid = $1;
          my $newsrid = clamp_srid($oldsrid);
          $subline =~ s/=\s*(\(?)[-0-9][0-9]*/= $1$newsrid/;
        } else {
          print STDERR "WARNING: could not find SRID value in: $subline";
        }
      }
      print STDOUT $subline;
      last if $subline =~ /;[\t ]*$/;
    }
    next;
  }

  # Parse comments, to avoid skipping quoted comments
  # See http://trac.osgeo.org/postgis/ticket/2759
  elsif ( $l =~ /^COMMENT ON .* IS '(.*)/)
  {
    print STDOUT $l;
    while( my $subline = <INPUT>)
    # A comment ends with an odd number of single quotes and a semicolon
    {
      print STDOUT $subline;
      last if ( $subline !~ /('*)[\t ]*;[\t ]*$/ || length($1) % 2 == 0)
    }
    next;
  }

  # Clamp SRIDS in spatial_ref_sys
  elsif ( $l =~ /COPY spatial_ref_sys /)
  {
    print STDOUT $l;
    while( my $subline = <INPUT>)
    {
      if ( $subline =~ /([0-9]*)\t/ ) {
        my $oldsrid = $1;
          my $newsrid = clamp_srid($oldsrid);
          $subline =~ s/^[0-9]*\t/${newsrid}\t/;
      }
      print STDOUT $subline;
      last if $subline =~ /^\\.$/;
    }
    next;
  }

  print STDOUT $l;

}

if ( defined $POSTGIS_SCHEMA ) {
  print STDOUT "SET search_path = \"" . $POSTGIS_SCHEMA . "\";\n";
}

if ( $hasTopology ) {

  # Re-enable topology.layer table triggers
  print STDOUT "ALTER TABLE topology.layer ENABLE TRIGGER ALL;\n";

  # Update topology SRID from geometry_columns view.
  # This is mainly to fix srids of -1
  # May be worth providing a "populate_topology_topology"
  print STDOUT "UPDATE topology.topology t set srid = g.srid "
             . "FROM geometry_columns g WHERE t.name = g.f_table_schema "
             . "AND g.f_table_name = 'face' and f_geometry_column = 'mbr';\n";

}

# Update spatial_ref_sys with entries found in new table
print STDOUT "UPDATE spatial_ref_sys o set auth_name = n.auth_name, "
           . "auth_srid = n.auth_srid, srtext = n.srtext, "
           . "proj4text = n.proj4text FROM "
           . "_pgis_restore_spatial_ref_sys n WHERE o.srid = n.srid;\n";
# Insert entries only found in new table
print STDOUT "INSERT INTO spatial_ref_sys SELECT * FROM "
           . "_pgis_restore_spatial_ref_sys n WHERE n.srid "
           . "NOT IN ( SELECT srid FROM spatial_ref_sys );\n";
# DROP TABLE _pgis_restore_spatial_ref_sys;
print STDOUT "DROP TABLE _pgis_restore_spatial_ref_sys;\n";

# Try re-enforcing spatial_ref_sys_srid_check, would fail if impossible
# but you'd still have your data
print STDOUT "ALTER TABLE spatial_ref_sys ADD constraint "
           . "spatial_ref_sys_srid_check check "
           . "( srid > 0 and srid < " . ($SRID_USER_MAXIMUM+1) ." ) ;\n";
# Try re-enforcing spatial_ref_sys primary key, would fail if impossible
# but you'd still have your data
print STDOUT "ALTER TABLE spatial_ref_sys ENABLE TRIGGER ALL;\n";
print STDOUT "ALTER TABLE spatial_ref_sys ADD PRIMARY KEY(srid);\n";


print STDERR "Done.\n";

######################################################################
# Strip a dump file manifest line down to the unique elements of
# type and signature.
#
sub linesignature {

  my $line = shift;
  my $sig;

  $line =~ s/\n$//;
  $line =~ s/\r$//;
  $line =~ s/OPERATOR CLASS/OPERATORCLASS/;
  $line =~ s/TABLE DATA/TABLEDATA/;
  $line =~ s/SHELL TYPE/SHELLTYPE/;
  $line =~ s/PROCEDURAL LANGUAGE/PROCEDURALLANGUAGE/;
  $line =~ s/SEQUENCE SET/SEQUENCE_SET/;

  if( $line =~ /^(\d+)\; (\d+) (\d+) FK (\w+) (\w+) (.*) (\w*)/ ) {
    $sig = "FK " . $4 . " " . $6;
  }
  elsif( $line =~ /^(\d+)\; (\d+) (\d+) (\w+) - (\w+) (.*) (\w*)/ ) {
    $sig = $4 . " " . $5 . " " . $6;
  }
  elsif( $line =~ /^(\d+)\; (\d+) (\d+) (\w+) (\w+) (.*) (\w*)/ ) {
    $sig = $4 . " " . $6;
  }
  elsif( $line =~ /PROCEDURALLANGUAGE.*plpgsql/ ) {
    $sig = "PROCEDURAL LANGUAGE plpgsql";
  }
  elsif ( $line =~ /SCHEMA - (\w+)/ ) {
    $sig = "SCHEMA $1";
  }
  elsif ( $line =~ /SEQUENCE - (\w+)/ ) {
    $sig = "SEQUENCE $1";
  }
  else {
    # TODO: something smarter here...
    $sig = $line
  }

  # Strip schema from signature
  # TODO: restrict to POSTGIS_SCHEMA
  $sig =~ s/[^\.(, ]*\.//g;

  return $sig;

}

#
# Canonicalize type names (they change between dump versions).
# Here we also strip schema qualification
#
sub
canonicalize_typename
{
	my $arg=shift;

	# Lower case
	$arg = lc($arg);

	# Trim whitespaces
	$arg =~ s/^\s*//;
	$arg =~ s/\s*$//;

	# Strip schema qualification
	#$arg =~ s/^public.//;
	$arg =~ s/^.*\.//;

	# Handle type name changes
	if ( $arg eq 'opaque' ) {
		$arg = 'internal';
	} elsif ( $arg eq 'boolean' ) {
		$arg = 'bool';
	} elsif ( $arg eq 'oldgeometry' ) {
		$arg = 'geometry';
	}

	# Timestamp with or without time zone
	if ( $arg =~ /timestamp .* time zone/ ) {
		$arg = 'timestamp';
	}

	return $arg;
}

# Change SRID to be within allowed ranges
sub
clamp_srid
{
  my $oldsrid = shift;
  my $newsrid = $oldsrid;

  if ( $oldsrid < 0 ) {
    $newsrid = 0;
    printf STDERR "  WARNING: SRID $oldsrid converted to $newsrid (official UNKNOWN)\n";
  } elsif ( $oldsrid > $SRID_MAXIMUM ) {
    $newsrid = $SRID_USER_MAXIMUM + 1 +
      # -1 is to reduce likelyhood of clashes
      # NOTE: must match core implementation (lwutil.c)
      ( $oldsrid % ( $SRID_MAXIMUM - $SRID_USER_MAXIMUM - 1 ) );
    printf STDERR "  WARNING: SRID $oldsrid converted to $newsrid (in reserved zone)\n";
  } elsif ( $oldsrid > $SRID_USER_MAXIMUM ) {
    printf STDERR "  WARNING: SRID $newsrid is in reserved zone\n";
  }

  return $newsrid;
}


######################################################################
# Here are all the signatures we want to skip but we cannot derive
# from current source
#
__END__
ACL SCHEMA topology
ACL TABLE geography_columns
ACL TABLE geometry_columns
ACL TABLE layer
ACL TABLE raster_columns
ACL TABLE raster_overviews
ACL TABLE spatial_ref_sys
ACL TABLE topology
AGGREGATE accum_old(geometry)
AGGREGATE collect(geometry)
AGGREGATE extent(geometry)
AGGREGATE extent3d(geometry)
AGGREGATE geomunion(geometry)
AGGREGATE makeline(geometry)
AGGREGATE memcollect(geometry)
AGGREGATE memgeomunion(geometry)
AGGREGATE polygonize(geometry)
AGGREGATE st_3dextent(geometry)
AGGREGATE st_3dunion(geometry)
AGGREGATE st_accum(geometry)
AGGREGATE st_accum_old(geometry)
AGGREGATE st_asflatgeobuf(anyelement)
AGGREGATE st_asflatgeobuf(anyelement, boolean)
AGGREGATE st_asflatgeobuf(anyelement, boolean, text)
AGGREGATE st_asgeobuf(anyelement)
AGGREGATE st_asgeobuf(anyelement, text)
AGGREGATE st_asmvt(anyelement)
AGGREGATE st_asmvt(anyelement, text)
AGGREGATE st_asmvt(anyelement, text, integer)
AGGREGATE st_asmvt(anyelement, text, integer, text)
AGGREGATE st_asmvt(anyelement, text, integer, text, text)
AGGREGATE st_astwkb_agg(geometry, integer)
AGGREGATE st_astwkb_agg(geometry, integer, bigint)
AGGREGATE st_astwkbagg(geometry, integer)
AGGREGATE st_astwkbagg(geometry, integer, bigint)
AGGREGATE st_astwkbagg(geometry, integer, bigint, boolean)
AGGREGATE st_astwkbagg(geometry, integer, bigint, boolean, boolean)
AGGREGATE st_clusterintersecting(geometry)
AGGREGATE st_clusterwithin(geometry, double precision)
AGGREGATE st_collect(geometry)
AGGREGATE st_countagg(raster, boolean)
AGGREGATE st_countagg(raster, integer, boolean)
AGGREGATE st_countagg(raster, integer, boolean, double precision)
AGGREGATE st_coverageunion(geometry)
AGGREGATE st_extent(geometry)
AGGREGATE st_extent3d(geometry)
AGGREGATE st_geomunion(geometry)
AGGREGATE st_makeline(geometry)
AGGREGATE st_memcollect(geometry)
AGGREGATE st_memunion(geometry)
AGGREGATE st_polygonize(geometry)
AGGREGATE st_samealignment(raster)
AGGREGATE st_summarystatsagg(raster, boolean, double precision)
AGGREGATE st_summarystatsagg(raster, integer, boolean)
AGGREGATE st_summarystatsagg(raster, integer, boolean, double precision)
AGGREGATE st_union(geometry)
AGGREGATE st_union(geometry, double precision)
AGGREGATE st_union(raster)
AGGREGATE st_union(raster, integer)
AGGREGATE st_union(raster, integer, text)
AGGREGATE st_union(raster, record[])
AGGREGATE st_union(raster, text)
AGGREGATE st_union(raster, text, text)
AGGREGATE st_union(raster, text, text, text)
AGGREGATE st_union(raster, text, text, text, double precision)
AGGREGATE st_union(raster, text, text, text, double precision, text, text, text, double precision)
AGGREGATE st_union(raster, text, text, text, double precision, text, text, text, double precision, text, text, text, double precision)
AGGREGATE st_union(raster, unionarg[])
AGGREGATE topoelementarray_agg(topoelement)
CAST (box2d AS box3d)
CAST (box2d AS geometry)
CAST (box3d AS box)
CAST (box3d AS box2d)
CAST (box3d AS geometry)
CAST (bytea AS geography)
CAST (bytea AS geometry)
CAST (geography AS bytea)
CAST (geography AS geography)
CAST (geography AS geometry)
CAST (geometry AS box)
CAST (geometry AS box2d)
CAST (geometry AS box3d)
CAST (geometry AS bytea)
CAST (geometry AS geography)
CAST (geometry AS geometry)
CAST (geometry AS json)
CAST (geometry AS jsonb)
CAST (geometry AS path)
CAST (geometry AS point)
CAST (geometry AS polygon)
CAST (geometry AS text)
CAST (path AS geometry)
CAST (point AS geometry)
CAST (polygon AS geometry)
CAST (text AS geometry)
CAST CAST (box2d AS box3d)
CAST CAST (box2d AS geometry)
CAST CAST (box3d AS box)
CAST CAST (box3d AS box2d)
CAST CAST (box3d AS geometry)
CAST CAST (bytea AS geography)
CAST CAST (bytea AS geometry)
CAST CAST (geography AS bytea)
CAST CAST (geography AS geography)
CAST CAST (geography AS geometry)
CAST CAST (geometry AS box)
CAST CAST (geometry AS box2d)
CAST CAST (geometry AS box3d)
CAST CAST (geometry AS bytea)
CAST CAST (geometry AS geography)
CAST CAST (geometry AS geometry)
CAST CAST (geometry AS json)
CAST CAST (geometry AS jsonb)
CAST CAST (geometry AS path)
CAST CAST (geometry AS point)
CAST CAST (geometry AS polygon)
CAST CAST (geometry AS text)
CAST CAST (path AS geometry)
CAST CAST (point AS geometry)
CAST CAST (polygon AS geometry)
CAST CAST (raster AS box3d)
CAST CAST (raster AS bytea)
CAST CAST (raster AS geometry)
CAST CAST (text AS geometry)
CAST CAST (topogeometry AS geometry)
CAST CAST (topogeometry AS integer[])
COMMENT AGGREGATE accum_old(geometry)
COMMENT AGGREGATE collect(geometry)
COMMENT AGGREGATE extent(geometry)
COMMENT AGGREGATE extent3d(geometry)
COMMENT AGGREGATE geomunion(geometry)
COMMENT AGGREGATE makeline(geometry)
COMMENT AGGREGATE memcollect(geometry)
COMMENT AGGREGATE memgeomunion(geometry)
COMMENT AGGREGATE polygonize(geometry)
COMMENT AGGREGATE st_3dextent(geometry)
COMMENT AGGREGATE st_3dunion(geometry)
COMMENT AGGREGATE st_accum(geometry)
COMMENT AGGREGATE st_accum_old(geometry)
COMMENT AGGREGATE st_asflatgeobuf(anyelement)
COMMENT AGGREGATE st_asflatgeobuf(anyelement, boolean)
COMMENT AGGREGATE st_asflatgeobuf(anyelement, boolean, text)
COMMENT AGGREGATE st_asgeobuf(anyelement)
COMMENT AGGREGATE st_asgeobuf(anyelement, text)
COMMENT AGGREGATE st_asmvt(anyelement)
COMMENT AGGREGATE st_asmvt(anyelement, text)
COMMENT AGGREGATE st_asmvt(anyelement, text, integer)
COMMENT AGGREGATE st_asmvt(anyelement, text, integer, text)
COMMENT AGGREGATE st_asmvt(anyelement, text, integer, text, text)
COMMENT AGGREGATE st_astwkb_agg(geometry, integer)
COMMENT AGGREGATE st_astwkb_agg(geometry, integer, bigint)
COMMENT AGGREGATE st_astwkbagg(geometry, integer)
COMMENT AGGREGATE st_astwkbagg(geometry, integer, bigint)
COMMENT AGGREGATE st_astwkbagg(geometry, integer, bigint, boolean)
COMMENT AGGREGATE st_astwkbagg(geometry, integer, bigint, boolean, boolean)
COMMENT AGGREGATE st_clusterintersecting(geometry)
COMMENT AGGREGATE st_clusterwithin(geometry, double precision)
COMMENT AGGREGATE st_collect(geometry)
COMMENT AGGREGATE st_countagg(raster, boolean)
COMMENT AGGREGATE st_countagg(raster, integer, boolean)
COMMENT AGGREGATE st_countagg(raster, integer, boolean, double precision)
COMMENT AGGREGATE st_coverageunion(geometry)
COMMENT AGGREGATE st_extent(geometry)
COMMENT AGGREGATE st_extent3d(geometry)
COMMENT AGGREGATE st_geomunion(geometry)
COMMENT AGGREGATE st_makeline(geometry)
COMMENT AGGREGATE st_memcollect(geometry)
COMMENT AGGREGATE st_memunion(geometry)
COMMENT AGGREGATE st_polygonize(geometry)
COMMENT AGGREGATE st_samealignment(raster)
COMMENT AGGREGATE st_summarystatsagg(raster, boolean, double precision)
COMMENT AGGREGATE st_summarystatsagg(raster, integer, boolean)
COMMENT AGGREGATE st_summarystatsagg(raster, integer, boolean, double precision)
COMMENT AGGREGATE st_union(geometry)
COMMENT AGGREGATE st_union(geometry, gridsize double precision)
COMMENT AGGREGATE st_union(raster)
COMMENT AGGREGATE st_union(raster, integer)
COMMENT AGGREGATE st_union(raster, integer, text)
COMMENT AGGREGATE st_union(raster, record[])
COMMENT AGGREGATE st_union(raster, text)
COMMENT AGGREGATE st_union(raster, text, text)
COMMENT AGGREGATE st_union(raster, text, text, text)
COMMENT AGGREGATE st_union(raster, text, text, text, double precision)
COMMENT AGGREGATE st_union(raster, text, text, text, double precision, text, text, text, double precision)
COMMENT AGGREGATE st_union(raster, text, text, text, double precision, text, text, text, double precision, text, text, text, double precision)
COMMENT AGGREGATE st_union(raster, unionarg[])
COMMENT AGGREGATE topoelementarray_agg(topoelement)
COMMENT DOMAIN topoelement
COMMENT DOMAIN topoelementarray
COMMENT FUNCTION "json"(geometry)
COMMENT FUNCTION "jsonb"(geometry)
COMMENT FUNCTION __st_countagg_transfn(agg agg_count, rast raster, nband integer, exclude_nodata_value boolean, sample_percent double precision)
COMMENT FUNCTION _add_overview_constraint(ovschema name, ovtable name, ovcolumn name, refschema name, reftable name, refcolumn name, factor integer)
COMMENT FUNCTION _add_raster_constraint(cn name, sql text)
COMMENT FUNCTION _add_raster_constraint_alignment(rastschema name, rasttable name, rastcolumn name)
COMMENT FUNCTION _add_raster_constraint_blocksize(rastschema name, rasttable name, rastcolumn name, axis text)
COMMENT FUNCTION _add_raster_constraint_coverage_tile(rastschema name, rasttable name, rastcolumn name)
COMMENT FUNCTION _add_raster_constraint_extent(rastschema name, rasttable name, rastcolumn name)
COMMENT FUNCTION _add_raster_constraint_nodata_values(rastschema name, rasttable name, rastcolumn name)
COMMENT FUNCTION _add_raster_constraint_num_bands(rastschema name, rasttable name, rastcolumn name)
COMMENT FUNCTION _add_raster_constraint_out_db(rastschema name, rasttable name, rastcolumn name)
COMMENT FUNCTION _add_raster_constraint_pixel_types(rastschema name, rasttable name, rastcolumn name)
COMMENT FUNCTION _add_raster_constraint_regular_blocking(name, name, name)
COMMENT FUNCTION _add_raster_constraint_scale(rastschema name, rasttable name, rastcolumn name, axis character)
COMMENT FUNCTION _add_raster_constraint_spatially_unique(rastschema name, rasttable name, rastcolumn name)
COMMENT FUNCTION _add_raster_constraint_srid(rastschema name, rasttable name, rastcolumn name)
COMMENT FUNCTION _asgmledge(edge_id integer, start_node integer, end_node integer, line geometry, visitedtable regclass, nsprefix_in text, prec integer, options integer, idprefix text, gmlver integer)
COMMENT FUNCTION _asgmlface(toponame text, face_id integer, visitedtable regclass, nsprefix_in text, prec integer, options integer, idprefix text, gmlver integer)
COMMENT FUNCTION _asgmlnode(id integer, point geometry, nsprefix_in text, prec integer, options integer, idprefix text, gmlver integer)
COMMENT FUNCTION _checkedgelinking(curedge_edge_id integer, prevedge_edge_id integer, prevedge_next_left_edge integer, prevedge_next_right_edge integer)
COMMENT FUNCTION _drop_overview_constraint(ovschema name, ovtable name, ovcolumn name)
COMMENT FUNCTION _drop_raster_constraint(rastschema name, rasttable name, cn name)
COMMENT FUNCTION _drop_raster_constraint_alignment(rastschema name, rasttable name, rastcolumn name)
COMMENT FUNCTION _drop_raster_constraint_blocksize(rastschema name, rasttable name, rastcolumn name, axis text)
COMMENT FUNCTION _drop_raster_constraint_coverage_tile(rastschema name, rasttable name, rastcolumn name)
COMMENT FUNCTION _drop_raster_constraint_extent(rastschema name, rasttable name, rastcolumn name)
COMMENT FUNCTION _drop_raster_constraint_nodata_values(rastschema name, rasttable name, rastcolumn name)
COMMENT FUNCTION _drop_raster_constraint_num_bands(rastschema name, rasttable name, rastcolumn name)
COMMENT FUNCTION _drop_raster_constraint_out_db(rastschema name, rasttable name, rastcolumn name)
COMMENT FUNCTION _drop_raster_constraint_pixel_types(rastschema name, rasttable name, rastcolumn name)
COMMENT FUNCTION _drop_raster_constraint_regular_blocking(rastschema name, rasttable name, rastcolumn name)
COMMENT FUNCTION _drop_raster_constraint_scale(rastschema name, rasttable name, rastcolumn name, axis character)
COMMENT FUNCTION _drop_raster_constraint_spatially_unique(rastschema name, rasttable name, rastcolumn name)
COMMENT FUNCTION _drop_raster_constraint_srid(rastschema name, rasttable name, rastcolumn name)
COMMENT FUNCTION _overview_constraint(ov raster, factor integer, refschema name, reftable name, refcolumn name)
COMMENT FUNCTION _overview_constraint_info(ovschema name, ovtable name, ovcolumn name, out refschema name, out reftable name, out refcolumn name, out factor integer)
COMMENT FUNCTION _postgis_deprecate(oldname text, newname text, version text)
COMMENT FUNCTION _postgis_index_extent(tbl regclass, col text)
COMMENT FUNCTION _postgis_join_selectivity(regclass, text, regclass, text, text)
COMMENT FUNCTION _postgis_pgsql_version()
COMMENT FUNCTION _postgis_scripts_pgsql_version()
COMMENT FUNCTION _postgis_selectivity(tbl regclass, att_name text, geom geometry, mode text)
COMMENT FUNCTION _postgis_stats(tbl regclass, att_name text, text)
COMMENT FUNCTION _raster_constraint_info_alignment(rastschema name, rasttable name, rastcolumn name)
COMMENT FUNCTION _raster_constraint_info_blocksize(rastschema name, rasttable name, rastcolumn name, axis text)
COMMENT FUNCTION _raster_constraint_info_coverage_tile(rastschema name, rasttable name, rastcolumn name)
COMMENT FUNCTION _raster_constraint_info_extent(rastschema name, rasttable name, rastcolumn name)
COMMENT FUNCTION _raster_constraint_info_index(rastschema name, rasttable name, rastcolumn name)
COMMENT FUNCTION _raster_constraint_info_nodata_values(rastschema name, rasttable name, rastcolumn name)
COMMENT FUNCTION _raster_constraint_info_num_bands(rastschema name, rasttable name, rastcolumn name)
COMMENT FUNCTION _raster_constraint_info_out_db(rastschema name, rasttable name, rastcolumn name)
COMMENT FUNCTION _raster_constraint_info_pixel_types(rastschema name, rasttable name, rastcolumn name)
COMMENT FUNCTION _raster_constraint_info_regular_blocking(rastschema name, rasttable name, rastcolumn name)
COMMENT FUNCTION _raster_constraint_info_scale(rastschema name, rasttable name, rastcolumn name, axis character)
COMMENT FUNCTION _raster_constraint_info_spatially_unique(rastschema name, rasttable name, rastcolumn name)
COMMENT FUNCTION _raster_constraint_info_srid(rastschema name, rasttable name, rastcolumn name)
COMMENT FUNCTION _raster_constraint_nodata_values(rast raster)
COMMENT FUNCTION _raster_constraint_out_db(rast raster)
COMMENT FUNCTION _raster_constraint_pixel_types(rast raster)
COMMENT FUNCTION _rename_raster_tables()
COMMENT FUNCTION _st_3ddfullywithin(geom1 geometry, geom2 geometry, double precision)
COMMENT FUNCTION _st_3ddwithin(geom1 geometry, geom2 geometry, double precision)
COMMENT FUNCTION _st_3dintersects(geom1 geometry, geom2 geometry)
COMMENT FUNCTION _st_addfacesplit(character varying, integer, integer, boolean)
COMMENT FUNCTION _st_adjacentedges(atopology character varying, anode integer, anedge integer)
COMMENT FUNCTION _st_asgeojson(integer, geography, integer, integer)
COMMENT FUNCTION _st_asgeojson(integer, geometry, integer, integer)
COMMENT FUNCTION _st_asgml(integer, geography, integer, integer, text)
COMMENT FUNCTION _st_asgml(integer, geography, integer, integer, text, text)
COMMENT FUNCTION _st_asgml(integer, geometry, integer, integer, text)
COMMENT FUNCTION _st_asgml(integer, geometry, integer, integer, text, text)
COMMENT FUNCTION _st_askml(integer, geography, integer, text)
COMMENT FUNCTION _st_askml(integer, geometry, integer, text)
COMMENT FUNCTION _st_aspect4ma(double precision[], text, text[])
COMMENT FUNCTION _st_aspect4ma(value double precision[][][], pos integer[][], variadic userargs text[])
COMMENT FUNCTION _st_asraster(geom geometry, scalex double precision, scaley double precision, width integer, height integer, pixeltype text[], value double precision[], nodataval double precision[], upperleftx double precision, upperlefty double precision, gridx double precision, gridy double precision, skewx double precision, skewy double precision, touched boolean)
COMMENT FUNCTION _st_asraster(geometry, double precision, double precision, integer, integer, text[], double precision[], double precision[], double precision, double precision, double precision, double precision, double precision, double precision, touched boolean)
COMMENT FUNCTION _st_asx3d(integer, geometry, integer, integer, text)
COMMENT FUNCTION _st_bestsrid(geography)
COMMENT FUNCTION _st_bestsrid(geography, geography)
COMMENT FUNCTION _st_buffer(geometry, double precision, cstring)
COMMENT FUNCTION _st_clip(rast raster, nband integer[], geom geometry, nodataval double precision[], crop boolean)
COMMENT FUNCTION _st_colormap(rast raster, nband integer, colormap text, method text)
COMMENT FUNCTION _st_concavehull(geometry)
COMMENT FUNCTION _st_contains(geom1 geometry, geom2 geometry)
COMMENT FUNCTION _st_contains(geometry, raster, integer)
COMMENT FUNCTION _st_contains(rast1 raster, nband1 integer, rast2 raster, nband2 integer)
COMMENT FUNCTION _st_contains(raster, geometry, integer)
COMMENT FUNCTION _st_containsproperly(geom1 geometry, geom2 geometry)
COMMENT FUNCTION _st_containsproperly(rast1 raster, nband1 integer, rast2 raster, nband2 integer)
COMMENT FUNCTION _st_convertarray4ma(value double precision[][])
COMMENT FUNCTION _st_count(rast raster, nband integer, exclude_nodata_value boolean, sample_percent double precision)
COMMENT FUNCTION _st_count(text, text, integer, boolean, double precision)
COMMENT FUNCTION _st_countagg_finalfn(agg agg_count)
COMMENT FUNCTION _st_countagg_transfn(agg agg_count, rast raster, exclude_nodata_value boolean)
COMMENT FUNCTION _st_countagg_transfn(agg agg_count, rast raster, nband integer, exclude_nodata_value boolean)
COMMENT FUNCTION _st_countagg_transfn(agg agg_count, rast raster, nband integer, exclude_nodata_value boolean, sample_percent double precision)
COMMENT FUNCTION _st_coveredby(geog1 geography, geog2 geography)
COMMENT FUNCTION _st_coveredby(geom1 geometry, geom2 geometry)
COMMENT FUNCTION _st_coveredby(rast1 raster, nband1 integer, rast2 raster, nband2 integer)
COMMENT FUNCTION _st_covers(geog1 geography, geog2 geography)
COMMENT FUNCTION _st_covers(geom1 geometry, geom2 geometry)
COMMENT FUNCTION _st_covers(rast1 raster, nband1 integer, rast2 raster, nband2 integer)
COMMENT FUNCTION _st_crosses(geom1 geometry, geom2 geometry)
COMMENT FUNCTION _st_dfullywithin(geom1 geometry, geom2 geometry, double precision)
COMMENT FUNCTION _st_dfullywithin(rast1 raster, nband1 integer, rast2 raster, nband2 integer, distance double precision)
COMMENT FUNCTION _st_distance(geography, geography, double precision, boolean)
COMMENT FUNCTION _st_distancerecttree(g1 geometry, g2 geometry)
COMMENT FUNCTION _st_distancerecttreecached(g1 geometry, g2 geometry)
COMMENT FUNCTION _st_distancetree(geography, geography)
COMMENT FUNCTION _st_distancetree(geography, geography, double precision, boolean)
COMMENT FUNCTION _st_distanceuncached(geography, geography)
COMMENT FUNCTION _st_distanceuncached(geography, geography, boolean)
COMMENT FUNCTION _st_distanceuncached(geography, geography, double precision, boolean)
COMMENT FUNCTION _st_dumpaswktpolygons(raster, integer)
COMMENT FUNCTION _st_dumppoints(geometry, integer[])
COMMENT FUNCTION _st_dwithin(geog1 geography, geog2 geography, tolerance double precision, use_spheroid boolean)
COMMENT FUNCTION _st_dwithin(geom1 geometry, geom2 geometry, double precision)
COMMENT FUNCTION _st_dwithin(rast1 raster, nband1 integer, rast2 raster, nband2 integer, distance double precision)
COMMENT FUNCTION _st_dwithinuncached(geography, geography, double precision)
COMMENT FUNCTION _st_dwithinuncached(geography, geography, double precision, boolean)
COMMENT FUNCTION _st_equals(geom1 geometry, geom2 geometry)
COMMENT FUNCTION _st_expand(geography, double precision)
COMMENT FUNCTION _st_gdalwarp(rast raster, algorithm text, maxerr double precision, srid integer, scalex double precision, scaley double precision, gridx double precision, gridy double precision, skewx double precision, skewy double precision, width integer, height integer)
COMMENT FUNCTION _st_geomfromgml(text, integer)
COMMENT FUNCTION _st_grayscale4ma(value double precision[][][], pos integer[][], variadic userargs text[])
COMMENT FUNCTION _st_hillshade4ma(double precision[], text, text[])
COMMENT FUNCTION _st_hillshade4ma(value double precision[][][], pos integer[][], variadic userargs text[])
COMMENT FUNCTION _st_histogram(rast raster, nband integer, exclude_nodata_value boolean, sample_percent double precision, bins integer, width double precision[], right boolean, min double precision, max double precision, out min double precision, out max double precision, out count bigint, out percent double precision)
COMMENT FUNCTION _st_histogram(raster, integer, boolean, double precision, integer, double precision[], boolean, double precision, double precision)
COMMENT FUNCTION _st_histogram(text, text, integer, boolean, double precision, integer, double precision[], boolean)
COMMENT FUNCTION _st_intersects(geom geometry, rast raster, nband integer)
COMMENT FUNCTION _st_intersects(geom1 geometry, geom2 geometry)
COMMENT FUNCTION _st_intersects(geometry, raster, integer)
COMMENT FUNCTION _st_intersects(rast1 raster, nband1 integer, rast2 raster, nband2 integer)
COMMENT FUNCTION _st_intersects(raster, geometry, integer)
COMMENT FUNCTION _st_intersects(raster, integer, raster, integer)
COMMENT FUNCTION _st_linecrossingdirection(line1 geometry, line2 geometry)
COMMENT FUNCTION _st_longestline(geom1 geometry, geom2 geometry)
COMMENT FUNCTION _st_mapalgebra(rastbandarg[], regprocedure, text, integer, integer, text, raster, text[])
COMMENT FUNCTION _st_mapalgebra(rastbandargset rastbandarg[], callbackfunc regprocedure, pixeltype text, distancex integer, distancey integer, extenttype text, customextent raster, mask double precision[][], weighted boolean, variadic userargs text[])
COMMENT FUNCTION _st_mapalgebra(rastbandargset rastbandarg[], expression text, pixeltype text, extenttype text, nodata1expr text, nodata2expr text, nodatanodataval double precision)
COMMENT FUNCTION _st_mapalgebra4unionfinal1(raster)
COMMENT FUNCTION _st_mapalgebra4unionstate(raster, raster)
COMMENT FUNCTION _st_mapalgebra4unionstate(raster, raster, integer)
COMMENT FUNCTION _st_mapalgebra4unionstate(raster, raster, integer, text)
COMMENT FUNCTION _st_mapalgebra4unionstate(raster, raster, text)
COMMENT FUNCTION _st_mapalgebra4unionstate(raster, raster, text, text, text, double precision, text, text, text, double precision)
COMMENT FUNCTION _st_maxdistance(geom1 geometry, geom2 geometry)
COMMENT FUNCTION _st_mintolerance(ageom geometry)
COMMENT FUNCTION _st_mintolerance(atopology character varying, ageom geometry)
COMMENT FUNCTION _st_neighborhood(rast raster, band integer, columnx integer, rowy integer, distancex integer, distancey integer, exclude_nodata_value boolean)
COMMENT FUNCTION _st_orderingequals(geom1 geometry, geom2 geometry)
COMMENT FUNCTION _st_overlaps(geom1 geometry, geom2 geometry)
COMMENT FUNCTION _st_overlaps(geometry, raster, integer)
COMMENT FUNCTION _st_overlaps(rast1 raster, nband1 integer, rast2 raster, nband2 integer)
COMMENT FUNCTION _st_overlaps(raster, geometry, integer)
COMMENT FUNCTION _st_pixelascentroids(rast raster, band integer, columnx integer, rowy integer, exclude_nodata_value boolean)
COMMENT FUNCTION _st_pixelaspolygons(rast raster, band integer, columnx integer, rowy integer, exclude_nodata_value boolean)
COMMENT FUNCTION _st_pointoutside(geography)
COMMENT FUNCTION _st_quantile(rast raster, nband integer, exclude_nodata_value boolean, sample_percent double precision, quantiles double precision[], out quantile double precision, out value double precision)
COMMENT FUNCTION _st_quantile(raster, integer, boolean, double precision, double precision[])
COMMENT FUNCTION _st_quantile(rastertable text, rastercolumn text, nband integer, exclude_nodata_value boolean, sample_percent double precision, quantiles double precision[], out quantile double precision, out value double precision)
COMMENT FUNCTION _st_quantile(text, text, integer, boolean, double precision, double precision[])
COMMENT FUNCTION _st_raster2worldcoord(raster, integer, integer)
COMMENT FUNCTION _st_rastertoworldcoord(rast raster, columnx integer, rowy integer, out longitude double precision, out latitude double precision)
COMMENT FUNCTION _st_reclass(rast raster, variadic reclassargset reclassarg[])
COMMENT FUNCTION _st_remedgecheck(character varying, integer, integer, integer, integer)
COMMENT FUNCTION _st_resample(raster, text, double precision, integer, double precision, double precision, double precision, double precision, double precision, double precision)
COMMENT FUNCTION _st_resample(raster, text, double precision, integer, double precision, double precision, double precision, double precision, double precision, double precision, integer, integer)
COMMENT FUNCTION _st_roughness4ma(value double precision[][][], pos integer[][], variadic userargs text[])
COMMENT FUNCTION _st_samealignment_finalfn(agg agg_samealignment)
COMMENT FUNCTION _st_samealignment_transfn(agg agg_samealignment, rast raster)
COMMENT FUNCTION _st_setvalues(rast raster, nband integer, x integer, y integer, newvalueset double precision[][], noset boolean[][], hasnosetvalue boolean, nosetvalue double precision, keepnodata boolean)
COMMENT FUNCTION _st_slope4ma(double precision[], text, text[])
COMMENT FUNCTION _st_slope4ma(value double precision[][][], pos integer[][], variadic userargs text[])
COMMENT FUNCTION _st_sortablehash(geom geometry)
COMMENT FUNCTION _st_summarystats(rast raster, nband integer, exclude_nodata_value boolean, sample_percent double precision)
COMMENT FUNCTION _st_summarystats(raster, integer, boolean, double precision)
COMMENT FUNCTION _st_summarystats(text, text, integer, boolean, double precision)
COMMENT FUNCTION _st_summarystats_finalfn(internal)
COMMENT FUNCTION _st_summarystats_transfn(internal, raster, boolean, double precision)
COMMENT FUNCTION _st_summarystats_transfn(internal, raster, integer, boolean)
COMMENT FUNCTION _st_summarystats_transfn(internal, raster, integer, boolean, double precision)
COMMENT FUNCTION _st_tile(rast raster, width integer, height integer, nband integer[], padwithnodata boolean, nodataval double precision)
COMMENT FUNCTION _st_tile(raster, integer, integer, integer[])
COMMENT FUNCTION _st_touches(geom1 geometry, geom2 geometry)
COMMENT FUNCTION _st_touches(geometry, raster, integer)
COMMENT FUNCTION _st_touches(rast1 raster, nband1 integer, rast2 raster, nband2 integer)
COMMENT FUNCTION _st_touches(raster, geometry, integer)
COMMENT FUNCTION _st_tpi4ma(value double precision[][][], pos integer[][], variadic userargs text[])
COMMENT FUNCTION _st_tri4ma(value double precision[][][], pos integer[][], variadic userargs text[])
COMMENT FUNCTION _st_union_finalfn(internal)
COMMENT FUNCTION _st_union_transfn(internal, raster)
COMMENT FUNCTION _st_union_transfn(internal, raster, integer)
COMMENT FUNCTION _st_union_transfn(internal, raster, integer, text)
COMMENT FUNCTION _st_union_transfn(internal, raster, text)
COMMENT FUNCTION _st_union_transfn(internal, raster, unionarg[])
COMMENT FUNCTION _st_valuecount(rast raster, nband integer, exclude_nodata_value boolean, searchvalues double precision[], roundto double precision, out value double precision, out count integer, out percent double precision)
COMMENT FUNCTION _st_valuecount(raster, integer, boolean, double precision[], double precision)
COMMENT FUNCTION _st_valuecount(rastertable text, rastercolumn text, nband integer, exclude_nodata_value boolean, searchvalues double precision[], roundto double precision, out value double precision, out count integer, out percent double precision)
COMMENT FUNCTION _st_valuecount(text, text, integer, boolean, double precision[], double precision)
COMMENT FUNCTION _st_voronoi(g1 geometry, clip geometry, tolerance double precision, return_polygons boolean)
COMMENT FUNCTION _st_within(geom1 geometry, geom2 geometry)
COMMENT FUNCTION _st_within(rast1 raster, nband1 integer, rast2 raster, nband2 integer)
COMMENT FUNCTION _st_world2rastercoord(raster, double precision, double precision)
COMMENT FUNCTION _st_worldtorastercoord(rast raster, longitude double precision, latitude double precision, out columnx integer, out rowy integer)
COMMENT FUNCTION _updaterastersrid(schema_name name, table_name name, column_name name, new_srid integer)
COMMENT FUNCTION _validatetopologyedgelinking(bbox geometry)
COMMENT FUNCTION _validatetopologygetfaceshellmaximaledgering(atopology character varying, aface integer)
COMMENT FUNCTION _validatetopologygetringedges(starting_edge integer)
COMMENT FUNCTION _validatetopologyrings(bbox geometry)
COMMENT FUNCTION addauth(text)
COMMENT FUNCTION addbbox(geometry)
COMMENT FUNCTION addedge(atopology character varying, aline geometry)
COMMENT FUNCTION addface(atopology character varying, apoly geometry, force_new boolean)
COMMENT FUNCTION addgeometrycolumn(catalog_name character varying, schema_name character varying, table_name character varying, column_name character varying, new_srid_in integer, new_type character varying, new_dim integer, use_typmod boolean)
COMMENT FUNCTION addgeometrycolumn(character varying, character varying, character varying, character varying, integer, character varying, integer)
COMMENT FUNCTION addgeometrycolumn(character varying, character varying, character varying, integer, character varying, integer)
COMMENT FUNCTION addgeometrycolumn(character varying, character varying, integer, character varying, integer)
COMMENT FUNCTION addgeometrycolumn(schema_name character varying, table_name character varying, column_name character varying, new_srid integer, new_type character varying, new_dim integer, use_typmod boolean)
COMMENT FUNCTION addgeometrycolumn(table_name character varying, column_name character varying, new_srid integer, new_type character varying, new_dim integer, use_typmod boolean)
COMMENT FUNCTION addnode(atopology character varying, apoint geometry, allowedgesplitting boolean, setcontainingface boolean)
COMMENT FUNCTION addnode(character varying, geometry)
COMMENT FUNCTION addnode(character varying, geometry, boolean, boolean)
COMMENT FUNCTION addoverviewconstraints(ovschema name, ovtable name, ovcolumn name, refschema name, reftable name, refcolumn name, ovfactor integer)
COMMENT FUNCTION addoverviewconstraints(ovtable name, ovcolumn name, reftable name, refcolumn name, ovfactor integer)
COMMENT FUNCTION addpoint(geometry, geometry)
COMMENT FUNCTION addpoint(geometry, geometry, integer)
COMMENT FUNCTION addrastercolumn(character varying, character varying, character varying, character varying, integer, character varying[], boolean, boolean, double precision[], double precision, double precision, integer, integer, geometry)
COMMENT FUNCTION addrastercolumn(character varying, character varying, character varying, integer, character varying[], boolean, boolean, double precision[], double precision, double precision, integer, integer, geometry)
COMMENT FUNCTION addrastercolumn(character varying, character varying, integer, character varying[], boolean, boolean, double precision[], double precision, double precision, integer, integer, geometry)
COMMENT FUNCTION addrasterconstraints(name, name, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean)
COMMENT FUNCTION addrasterconstraints(name, name, name, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean)
COMMENT FUNCTION addrasterconstraints(rastschema name, rasttable name, rastcolumn name, VARIADIC constraints text[])
COMMENT FUNCTION addrasterconstraints(rastschema name, rasttable name, rastcolumn name, srid boolean, scale_x boolean, scale_y boolean, blocksize_x boolean, blocksize_y boolean, same_alignment boolean, regular_blocking boolean, num_bands boolean, pixel_types boolean, nodata_values boolean, out_db boolean, extent boolean)
COMMENT FUNCTION addrasterconstraints(rastschema name, rasttable name, rastcolumn name, variadic constraints text[])
COMMENT FUNCTION addrasterconstraints(rasttable name, rastcolumn name, VARIADIC constraints text[])
COMMENT FUNCTION addrasterconstraints(rasttable name, rastcolumn name, srid boolean, scale_x boolean, scale_y boolean, blocksize_x boolean, blocksize_y boolean, same_alignment boolean, regular_blocking boolean, num_bands boolean, pixel_types boolean, nodata_values boolean, out_db boolean, extent boolean)
COMMENT FUNCTION addrasterconstraints(rasttable name, rastcolumn name, variadic constraints text[])
COMMENT FUNCTION addtopogeometrycolumn(character varying, character varying, character varying, character varying, character varying)
COMMENT FUNCTION addtopogeometrycolumn(toponame character varying, schema character varying, tbl character varying, col character varying, ltype character varying, child integer)
COMMENT FUNCTION addtosearchpath(a_schema_name character varying)
COMMENT FUNCTION affine(geometry, double precision, double precision, double precision, double precision, double precision, double precision)
COMMENT FUNCTION affine(geometry, double precision, double precision, double precision, double precision, double precision, double precision, double precision, double precision, double precision, double precision, double precision, double precision)
COMMENT FUNCTION area(geometry)
COMMENT FUNCTION area2d(geometry)
COMMENT FUNCTION asbinary(geometry)
COMMENT FUNCTION asbinary(geometry, text)
COMMENT FUNCTION asewkb(geometry)
COMMENT FUNCTION asewkb(geometry, text)
COMMENT FUNCTION asewkt(geometry)
COMMENT FUNCTION asgml(geometry)
COMMENT FUNCTION asgml(geometry, integer)
COMMENT FUNCTION asgml(tg topogeometry)
COMMENT FUNCTION asgml(tg topogeometry, nsprefix text)
COMMENT FUNCTION asgml(tg topogeometry, nsprefix text, prec integer, options integer, vis regclass)
COMMENT FUNCTION asgml(tg topogeometry, nsprefix text, prec integer, options integer, visitedtable regclass, idprefix text)
COMMENT FUNCTION asgml(tg topogeometry, nsprefix text, prec integer, opts integer)
COMMENT FUNCTION asgml(tg topogeometry, nsprefix_in text, precision_in integer, options_in integer, visitedtable regclass, idprefix text, gmlver integer)
COMMENT FUNCTION asgml(tg topogeometry, visitedtable regclass)
COMMENT FUNCTION asgml(tg topogeometry, visitedtable regclass, nsprefix text)
COMMENT FUNCTION ashexewkb(geometry)
COMMENT FUNCTION ashexewkb(geometry, text)
COMMENT FUNCTION askml(geometry)
COMMENT FUNCTION askml(geometry, integer)
COMMENT FUNCTION askml(integer, geometry, integer)
COMMENT FUNCTION assvg(geometry)
COMMENT FUNCTION assvg(geometry, integer)
COMMENT FUNCTION assvg(geometry, integer, integer)
COMMENT FUNCTION astext(geometry)
COMMENT FUNCTION astopojson(tg topogeometry, edgemaptable regclass)
COMMENT FUNCTION azimuth(geometry, geometry)
COMMENT FUNCTION bdmpolyfromtext(text, integer)
COMMENT FUNCTION bdpolyfromtext(text, integer)
COMMENT FUNCTION boundary(geometry)
COMMENT FUNCTION box(box3d)
COMMENT FUNCTION box(geometry)
COMMENT FUNCTION box2d(box3d)
COMMENT FUNCTION box2d(geometry)
COMMENT FUNCTION box2d(raster)
COMMENT FUNCTION box2d_contain(box2d, box2d)
COMMENT FUNCTION box2d_contained(box2d, box2d)
COMMENT FUNCTION box2d_in(cstring)
COMMENT FUNCTION box2d_intersects(box2d, box2d)
COMMENT FUNCTION box2d_left(box2d, box2d)
COMMENT FUNCTION box2d_out(box2d)
COMMENT FUNCTION box2d_overlap(box2d, box2d)
COMMENT FUNCTION box2d_overleft(box2d, box2d)
COMMENT FUNCTION box2d_overright(box2d, box2d)
COMMENT FUNCTION box2d_right(box2d, box2d)
COMMENT FUNCTION box2d_same(box2d, box2d)
COMMENT FUNCTION box2df_in(cstring)
COMMENT FUNCTION box2df_out(box2df)
COMMENT FUNCTION box3d(box2d)
COMMENT FUNCTION box3d(geometry)
COMMENT FUNCTION box3d(raster)
COMMENT FUNCTION box3d_in(cstring)
COMMENT FUNCTION box3d_out(box3d)
COMMENT FUNCTION box3dtobox(box3d)
COMMENT FUNCTION buffer(geometry, double precision)
COMMENT FUNCTION buffer(geometry, double precision, integer)
COMMENT FUNCTION buildarea(geometry)
COMMENT FUNCTION bytea(geography)
COMMENT FUNCTION bytea(geometry)
COMMENT FUNCTION bytea(raster)
COMMENT FUNCTION cache_bbox()
COMMENT FUNCTION centroid(geometry)
COMMENT FUNCTION checkauth(text, text)
COMMENT FUNCTION checkauth(text, text, text)
COMMENT FUNCTION checkauthtrigger()
COMMENT FUNCTION cleartopogeom(tg topogeometry)
COMMENT FUNCTION collect(geometry, geometry)
COMMENT FUNCTION collect_garray(geometry[])
COMMENT FUNCTION collector(geometry, geometry)
COMMENT FUNCTION combine_bbox(box2d, geometry)
COMMENT FUNCTION combine_bbox(box3d, geometry)
COMMENT FUNCTION contains(geometry, geometry)
COMMENT FUNCTION contains_2d(box2df, box2df)
COMMENT FUNCTION contains_2d(box2df, geometry)
COMMENT FUNCTION contains_2d(geometry, box2df)
COMMENT FUNCTION convexhull(geometry)
COMMENT FUNCTION copytopology(atopology character varying, newtopo character varying)
COMMENT FUNCTION createtopogeom(toponame character varying, tg_type integer, layer_id integer)
COMMENT FUNCTION createtopogeom(toponame character varying, tg_type integer, layer_id integer, tg_objs topoelementarray)
COMMENT FUNCTION createtopology(atopology character varying, srid integer, prec double precision, hasz boolean)
COMMENT FUNCTION createtopology(character varying)
COMMENT FUNCTION createtopology(character varying, integer)
COMMENT FUNCTION createtopology(toponame character varying, srid integer, prec double precision)
COMMENT FUNCTION crosses(geometry, geometry)
COMMENT FUNCTION difference(geometry, geometry)
COMMENT FUNCTION dimension(geometry)
COMMENT FUNCTION disablelongtransactions()
COMMENT FUNCTION disjoint(geometry, geometry)
COMMENT FUNCTION distance(geometry, geometry)
COMMENT FUNCTION distance_sphere(geometry, geometry)
COMMENT FUNCTION distance_spheroid(geometry, geometry, spheroid)
COMMENT FUNCTION dropbbox(geometry)
COMMENT FUNCTION dropgeometrycolumn(catalog_name character varying, schema_name character varying, table_name character varying, column_name character varying)
COMMENT FUNCTION dropgeometrycolumn(schema_name character varying, table_name character varying, column_name character varying)
COMMENT FUNCTION dropgeometrycolumn(table_name character varying, column_name character varying)
COMMENT FUNCTION dropgeometrytable(catalog_name character varying, schema_name character varying, table_name character varying)
COMMENT FUNCTION dropgeometrytable(schema_name character varying, table_name character varying)
COMMENT FUNCTION dropgeometrytable(table_name character varying)
COMMENT FUNCTION dropoverviewconstraints(ovschema name, ovtable name, ovcolumn name)
COMMENT FUNCTION dropoverviewconstraints(ovtable name, ovcolumn name)
COMMENT FUNCTION droprastercolumn(character varying, character varying)
COMMENT FUNCTION droprastercolumn(character varying, character varying, character varying)
COMMENT FUNCTION droprastercolumn(character varying, character varying, character varying, character varying)
COMMENT FUNCTION droprasterconstraints(name, name, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean)
COMMENT FUNCTION droprasterconstraints(name, name, name, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean)
COMMENT FUNCTION droprasterconstraints(rastschema name, rasttable name, rastcolumn name, VARIADIC constraints text[])
COMMENT FUNCTION droprasterconstraints(rastschema name, rasttable name, rastcolumn name, srid boolean, scale_x boolean, scale_y boolean, blocksize_x boolean, blocksize_y boolean, same_alignment boolean, regular_blocking boolean, num_bands boolean, pixel_types boolean, nodata_values boolean, out_db boolean, extent boolean)
COMMENT FUNCTION droprasterconstraints(rastschema name, rasttable name, rastcolumn name, variadic constraints text[])
COMMENT FUNCTION droprasterconstraints(rasttable name, rastcolumn name, srid boolean, scale_x boolean, scale_y boolean, blocksize_x boolean, blocksize_y boolean, same_alignment boolean, regular_blocking boolean, num_bands boolean, pixel_types boolean, nodata_values boolean, out_db boolean, extent boolean)
COMMENT FUNCTION droprasterconstraints(rasttable name, rastcolumn name, variadic constraints text[])
COMMENT FUNCTION droprastertable(character varying)
COMMENT FUNCTION droprastertable(character varying, character varying)
COMMENT FUNCTION droprastertable(character varying, character varying, character varying)
COMMENT FUNCTION droptopogeometrycolumn(schema character varying, tbl character varying, col character varying)
COMMENT FUNCTION droptopology(atopology character varying)
COMMENT FUNCTION dump(geometry)
COMMENT FUNCTION dumpaswktpolygons(raster, integer)
COMMENT FUNCTION dumprings(geometry)
COMMENT FUNCTION enablelongtransactions()
COMMENT FUNCTION endpoint(geometry)
COMMENT FUNCTION envelope(geometry)
COMMENT FUNCTION equals(geom1 geometry, geom2 geometry)
COMMENT FUNCTION equals(tg1 topogeometry, tg2 topogeometry)
COMMENT FUNCTION estimated_extent(text, text)
COMMENT FUNCTION estimated_extent(text, text, text)
COMMENT FUNCTION expand(box2d, double precision)
COMMENT FUNCTION expand(box3d, double precision)
COMMENT FUNCTION expand(geometry, double precision)
COMMENT FUNCTION exteriorring(geometry)
COMMENT FUNCTION find_extent(text, text)
COMMENT FUNCTION find_extent(text, text, text)
COMMENT FUNCTION find_srid(character varying, character varying, character varying)
COMMENT FUNCTION findlayer(layer_table regclass, feature_column name)
COMMENT FUNCTION findlayer(schema_name name, table_name name, feature_column name)
COMMENT FUNCTION findlayer(tg topogeometry)
COMMENT FUNCTION findlayer(topology_id integer, layer_id integer)
COMMENT FUNCTION findtopology(integer)
COMMENT FUNCTION findtopology(name, name, name)
COMMENT FUNCTION findtopology(regclass, name)
COMMENT FUNCTION findtopology(text)
COMMENT FUNCTION findtopology(topogeometry)
COMMENT FUNCTION fix_geometry_columns()
COMMENT FUNCTION force_2d(geometry)
COMMENT FUNCTION force_3d(geometry)
COMMENT FUNCTION force_3dm(geometry)
COMMENT FUNCTION force_3dz(geometry)
COMMENT FUNCTION force_4d(geometry)
COMMENT FUNCTION force_collection(geometry)
COMMENT FUNCTION forcerhr(geometry)
COMMENT FUNCTION geog_brin_inclusion_add_value(internal, internal, internal, internal)
COMMENT FUNCTION geography(bytea)
COMMENT FUNCTION geography(geography, integer, boolean)
COMMENT FUNCTION geography(geometry)
COMMENT FUNCTION geography_analyze(internal)
COMMENT FUNCTION geography_cmp(geography, geography)
COMMENT FUNCTION geography_distance_knn(geography, geography)
COMMENT FUNCTION geography_eq(geography, geography)
COMMENT FUNCTION geography_ge(geography, geography)
COMMENT FUNCTION geography_gist_compress(internal)
COMMENT FUNCTION geography_gist_consistent(internal, geography, integer)
COMMENT FUNCTION geography_gist_decompress(internal)
COMMENT FUNCTION geography_gist_distance(internal, geography, integer)
COMMENT FUNCTION geography_gist_join_selectivity(internal, oid, internal, smallint)
COMMENT FUNCTION geography_gist_penalty(internal, internal, internal)
COMMENT FUNCTION geography_gist_picksplit(internal, internal)
COMMENT FUNCTION geography_gist_same(box2d, box2d, internal)
COMMENT FUNCTION geography_gist_selectivity(internal, oid, internal, integer)
COMMENT FUNCTION geography_gist_union(bytea, internal)
COMMENT FUNCTION geography_gt(geography, geography)
COMMENT FUNCTION geography_in(cstring, oid, integer)
COMMENT FUNCTION geography_le(geography, geography)
COMMENT FUNCTION geography_lt(geography, geography)
COMMENT FUNCTION geography_out(geography)
COMMENT FUNCTION geography_overlaps(geography, geography)
COMMENT FUNCTION geography_recv(internal, oid, integer)
COMMENT FUNCTION geography_send(geography)
COMMENT FUNCTION geography_spgist_choose_nd(internal, internal)
COMMENT FUNCTION geography_spgist_compress_nd(internal)
COMMENT FUNCTION geography_spgist_config_nd(internal, internal)
COMMENT FUNCTION geography_spgist_inner_consistent_nd(internal, internal)
COMMENT FUNCTION geography_spgist_leaf_consistent_nd(internal, internal)
COMMENT FUNCTION geography_spgist_picksplit_nd(internal, internal)
COMMENT FUNCTION geography_typmod_in(cstring[])
COMMENT FUNCTION geography_typmod_out(integer)
COMMENT FUNCTION geom2d_brin_inclusion_add_value(internal, internal, internal, internal)
COMMENT FUNCTION geom3d_brin_inclusion_add_value(internal, internal, internal, internal)
COMMENT FUNCTION geom4d_brin_inclusion_add_value(internal, internal, internal, internal)
COMMENT FUNCTION geom_accum(geometry[], geometry)
COMMENT FUNCTION geomcollfromtext(text)
COMMENT FUNCTION geomcollfromtext(text, integer)
COMMENT FUNCTION geomcollfromwkb(bytea)
COMMENT FUNCTION geomcollfromwkb(bytea, integer)
COMMENT FUNCTION geometry(box2d)
COMMENT FUNCTION geometry(box3d)
COMMENT FUNCTION geometry(bytea)
COMMENT FUNCTION geometry(geography)
COMMENT FUNCTION geometry(geometry, integer, boolean)
COMMENT FUNCTION geometry(path)
COMMENT FUNCTION geometry(point)
COMMENT FUNCTION geometry(polygon)
COMMENT FUNCTION geometry(text)
COMMENT FUNCTION geometry(topogeom topogeometry)
COMMENT FUNCTION geometry_above(geom1 geometry, geom2 geometry)
COMMENT FUNCTION geometry_analyze(internal)
COMMENT FUNCTION geometry_below(geom1 geometry, geom2 geometry)
COMMENT FUNCTION geometry_cmp(geom1 geometry, geom2 geometry)
COMMENT FUNCTION geometry_contained_3d(geom1 geometry, geom2 geometry)
COMMENT FUNCTION geometry_contained_by_raster(geometry, raster)
COMMENT FUNCTION geometry_contains(geom1 geometry, geom2 geometry)
COMMENT FUNCTION geometry_contains_3d(geom1 geometry, geom2 geometry)
COMMENT FUNCTION geometry_contains_nd(geometry, geometry)
COMMENT FUNCTION geometry_distance_box(geom1 geometry, geom2 geometry)
COMMENT FUNCTION geometry_distance_box_nd(geometry, geometry)
COMMENT FUNCTION geometry_distance_centroid(geom1 geometry, geom2 geometry)
COMMENT FUNCTION geometry_distance_centroid_nd(geometry, geometry)
COMMENT FUNCTION geometry_distance_cpa(geometry, geometry)
COMMENT FUNCTION geometry_eq(geom1 geometry, geom2 geometry)
COMMENT FUNCTION geometry_ge(geom1 geometry, geom2 geometry)
COMMENT FUNCTION geometry_gist_compress_2d(internal)
COMMENT FUNCTION geometry_gist_compress_nd(internal)
COMMENT FUNCTION geometry_gist_consistent_2d(internal, geometry, integer)
COMMENT FUNCTION geometry_gist_consistent_nd(internal, geometry, integer)
COMMENT FUNCTION geometry_gist_decompress_2d(internal)
COMMENT FUNCTION geometry_gist_decompress_nd(internal)
COMMENT FUNCTION geometry_gist_distance_2d(internal, geometry, integer)
COMMENT FUNCTION geometry_gist_distance_nd(internal, geometry, integer)
COMMENT FUNCTION geometry_gist_joinsel_2d(internal, oid, internal, smallint)
COMMENT FUNCTION geometry_gist_penalty_2d(internal, internal, internal)
COMMENT FUNCTION geometry_gist_penalty_nd(internal, internal, internal)
COMMENT FUNCTION geometry_gist_picksplit_2d(internal, internal)
COMMENT FUNCTION geometry_gist_picksplit_nd(internal, internal)
COMMENT FUNCTION geometry_gist_same_2d(geom1 geometry, geom2 geometry, internal)
COMMENT FUNCTION geometry_gist_same_nd(geometry, geometry, internal)
COMMENT FUNCTION geometry_gist_sel_2d(internal, oid, internal, integer)
COMMENT FUNCTION geometry_gist_sortsupport_2d(internal)
COMMENT FUNCTION geometry_gist_union_2d(bytea, internal)
COMMENT FUNCTION geometry_gist_union_nd(bytea, internal)
COMMENT FUNCTION geometry_gt(geom1 geometry, geom2 geometry)
COMMENT FUNCTION geometry_hash(geometry)
COMMENT FUNCTION geometry_in(cstring)
COMMENT FUNCTION geometry_le(geom1 geometry, geom2 geometry)
COMMENT FUNCTION geometry_left(geom1 geometry, geom2 geometry)
COMMENT FUNCTION geometry_lt(geom1 geometry, geom2 geometry)
COMMENT FUNCTION geometry_out(geometry)
COMMENT FUNCTION geometry_overabove(geom1 geometry, geom2 geometry)
COMMENT FUNCTION geometry_overbelow(geom1 geometry, geom2 geometry)
COMMENT FUNCTION geometry_overlaps(geom1 geometry, geom2 geometry)
COMMENT FUNCTION geometry_overlaps_3d(geom1 geometry, geom2 geometry)
COMMENT FUNCTION geometry_overlaps_nd(geometry, geometry)
COMMENT FUNCTION geometry_overleft(geom1 geometry, geom2 geometry)
COMMENT FUNCTION geometry_overright(geom1 geometry, geom2 geometry)
COMMENT FUNCTION geometry_raster_contain(geometry, raster)
COMMENT FUNCTION geometry_raster_overlap(geometry, raster)
COMMENT FUNCTION geometry_recv(internal)
COMMENT FUNCTION geometry_right(geom1 geometry, geom2 geometry)
COMMENT FUNCTION geometry_same(geom1 geometry, geom2 geometry)
COMMENT FUNCTION geometry_same_3d(geom1 geometry, geom2 geometry)
COMMENT FUNCTION geometry_same_nd(geometry, geometry)
COMMENT FUNCTION geometry_send(geometry)
COMMENT FUNCTION geometry_sortsupport(internal)
COMMENT FUNCTION geometry_spgist_choose_2d(internal, internal)
COMMENT FUNCTION geometry_spgist_choose_3d(internal, internal)
COMMENT FUNCTION geometry_spgist_choose_nd(internal, internal)
COMMENT FUNCTION geometry_spgist_compress_2d(internal)
COMMENT FUNCTION geometry_spgist_compress_3d(internal)
COMMENT FUNCTION geometry_spgist_compress_nd(internal)
COMMENT FUNCTION geometry_spgist_config_2d(internal, internal)
COMMENT FUNCTION geometry_spgist_config_3d(internal, internal)
COMMENT FUNCTION geometry_spgist_config_nd(internal, internal)
COMMENT FUNCTION geometry_spgist_inner_consistent_2d(internal, internal)
COMMENT FUNCTION geometry_spgist_inner_consistent_3d(internal, internal)
COMMENT FUNCTION geometry_spgist_inner_consistent_nd(internal, internal)
COMMENT FUNCTION geometry_spgist_leaf_consistent_2d(internal, internal)
COMMENT FUNCTION geometry_spgist_leaf_consistent_3d(internal, internal)
COMMENT FUNCTION geometry_spgist_leaf_consistent_nd(internal, internal)
COMMENT FUNCTION geometry_spgist_picksplit_2d(internal, internal)
COMMENT FUNCTION geometry_spgist_picksplit_3d(internal, internal)
COMMENT FUNCTION geometry_spgist_picksplit_nd(internal, internal)
COMMENT FUNCTION geometry_typmod_in(cstring[])
COMMENT FUNCTION geometry_typmod_out(integer)
COMMENT FUNCTION geometry_within(geom1 geometry, geom2 geometry)
COMMENT FUNCTION geometry_within_nd(geometry, geometry)
COMMENT FUNCTION geometryfromtext(text)
COMMENT FUNCTION geometryfromtext(text, integer)
COMMENT FUNCTION geometryn(geometry, integer)
COMMENT FUNCTION geometrytype(geography)
COMMENT FUNCTION geometrytype(geometry)
COMMENT FUNCTION geometrytype(tg topogeometry)
COMMENT FUNCTION geomfromewkb(bytea)
COMMENT FUNCTION geomfromewkt(text)
COMMENT FUNCTION geomfromtext(text)
COMMENT FUNCTION geomfromtext(text, integer)
COMMENT FUNCTION geomfromwkb(bytea)
COMMENT FUNCTION geomfromwkb(bytea, integer)
COMMENT FUNCTION geomunion(geometry, geometry)
COMMENT FUNCTION geosnoop(geometry)
COMMENT FUNCTION get_proj4_from_srid(integer)
COMMENT FUNCTION getbbox(geometry)
COMMENT FUNCTION getedgebypoint(atopology character varying, apoint geometry, tol1 double precision)
COMMENT FUNCTION getfacebypoint(atopology character varying, apoint geometry, tol1 double precision)
COMMENT FUNCTION getfacecontainingpoint(atopology text, apoint geometry)
COMMENT FUNCTION getnodebypoint(atopology character varying, apoint geometry, tol1 double precision)
COMMENT FUNCTION getnodeedges(atopology character varying, anode integer)
COMMENT FUNCTION getringedges(atopology character varying, anedge integer, maxedges integer)
COMMENT FUNCTION getsrid(geometry)
COMMENT FUNCTION gettopogeomelementarray(tg topogeometry)
COMMENT FUNCTION gettopogeomelementarray(toponame character varying, layer_id integer, tgid integer)
COMMENT FUNCTION gettopogeomelements(tg topogeometry)
COMMENT FUNCTION gettopogeomelements(toponame character varying, layerid integer, tgid integer)
COMMENT FUNCTION gettopologyid(toponame character varying)
COMMENT FUNCTION gettopologyname(topoid integer)
COMMENT FUNCTION gettopologysrid(toponame character varying)
COMMENT FUNCTION gettransactionid()
COMMENT FUNCTION gidx_in(cstring)
COMMENT FUNCTION gidx_out(gidx)
COMMENT FUNCTION gserialized_gist_joinsel_2d(internal, oid, internal, smallint)
COMMENT FUNCTION gserialized_gist_joinsel_nd(internal, oid, internal, smallint)
COMMENT FUNCTION gserialized_gist_sel_2d(internal, oid, internal, integer)
COMMENT FUNCTION gserialized_gist_sel_nd(internal, oid, internal, integer)
COMMENT FUNCTION hasbbox(geometry)
COMMENT FUNCTION interiorringn(geometry, integer)
COMMENT FUNCTION intersection(geometry, geometry)
COMMENT FUNCTION intersects(geometry, geometry)
COMMENT FUNCTION intersects(tg1 topogeometry, tg2 topogeometry)
COMMENT FUNCTION is_contained_2d(box2df, box2df)
COMMENT FUNCTION is_contained_2d(box2df, geometry)
COMMENT FUNCTION is_contained_2d(geometry, box2df)
COMMENT FUNCTION isclosed(geometry)
COMMENT FUNCTION isempty(geometry)
COMMENT FUNCTION isring(geometry)
COMMENT FUNCTION issimple(geometry)
COMMENT FUNCTION isvalid(geometry)
COMMENT FUNCTION jtsnoop(geometry)
COMMENT FUNCTION layertrigger()
COMMENT FUNCTION length(geometry)
COMMENT FUNCTION length2d(geometry)
COMMENT FUNCTION length2d_spheroid(geometry, spheroid)
COMMENT FUNCTION length3d(geometry)
COMMENT FUNCTION length3d_spheroid(geometry, spheroid)
COMMENT FUNCTION length_spheroid(geometry, spheroid)
COMMENT FUNCTION line_interpolate_point(geometry, double precision)
COMMENT FUNCTION line_locate_point(geometry, geometry)
COMMENT FUNCTION line_substring(geometry, double precision, double precision)
COMMENT FUNCTION linefrommultipoint(geometry)
COMMENT FUNCTION linefromtext(text)
COMMENT FUNCTION linefromtext(text, integer)
COMMENT FUNCTION linefromwkb(bytea)
COMMENT FUNCTION linefromwkb(bytea, integer)
COMMENT FUNCTION linemerge(geometry)
COMMENT FUNCTION linestringfromtext(text)
COMMENT FUNCTION linestringfromtext(text, integer)
COMMENT FUNCTION linestringfromwkb(bytea)
COMMENT FUNCTION linestringfromwkb(bytea, integer)
COMMENT FUNCTION locate_along_measure(geometry, double precision)
COMMENT FUNCTION locate_between_measures(geometry, double precision, double precision)
COMMENT FUNCTION lockrow(text, text, text)
COMMENT FUNCTION lockrow(text, text, text, text)
COMMENT FUNCTION lockrow(text, text, text, text, timestamp without time zone)
COMMENT FUNCTION lockrow(text, text, text, text, timestamp)
COMMENT FUNCTION lockrow(text, text, text, timestamp without time zone)
COMMENT FUNCTION lockrow(text, text, text, timestamp)
COMMENT FUNCTION longtransactionsenabled()
COMMENT FUNCTION m(geometry)
COMMENT FUNCTION makebox2d(geometry, geometry)
COMMENT FUNCTION makebox3d(geometry, geometry)
COMMENT FUNCTION makeline(geometry, geometry)
COMMENT FUNCTION makeline_garray(geometry[])
COMMENT FUNCTION makepoint(double precision, double precision)
COMMENT FUNCTION makepoint(double precision, double precision, double precision)
COMMENT FUNCTION makepoint(double precision, double precision, double precision, double precision)
COMMENT FUNCTION makepointm(double precision, double precision, double precision)
COMMENT FUNCTION makepolygon(geometry)
COMMENT FUNCTION makepolygon(geometry, geometry[])
COMMENT FUNCTION max_distance(geometry, geometry)
COMMENT FUNCTION mem_size(geometry)
COMMENT FUNCTION mlinefromtext(text)
COMMENT FUNCTION mlinefromtext(text, integer)
COMMENT FUNCTION mlinefromwkb(bytea)
COMMENT FUNCTION mlinefromwkb(bytea, integer)
COMMENT FUNCTION mpointfromtext(text)
COMMENT FUNCTION mpointfromtext(text, integer)
COMMENT FUNCTION mpointfromwkb(bytea)
COMMENT FUNCTION mpointfromwkb(bytea, integer)
COMMENT FUNCTION mpolyfromtext(text)
COMMENT FUNCTION mpolyfromtext(text, integer)
COMMENT FUNCTION mpolyfromwkb(bytea)
COMMENT FUNCTION mpolyfromwkb(bytea, integer)
COMMENT FUNCTION multi(geometry)
COMMENT FUNCTION multilinefromwkb(bytea)
COMMENT FUNCTION multilinefromwkb(bytea, integer)
COMMENT FUNCTION multilinestringfromtext(text)
COMMENT FUNCTION multilinestringfromtext(text, integer)
COMMENT FUNCTION multipointfromtext(text)
COMMENT FUNCTION multipointfromtext(text, integer)
COMMENT FUNCTION multipointfromwkb(bytea)
COMMENT FUNCTION multipointfromwkb(bytea, integer)
COMMENT FUNCTION multipolyfromwkb(bytea)
COMMENT FUNCTION multipolyfromwkb(bytea, integer)
COMMENT FUNCTION multipolygonfromtext(text)
COMMENT FUNCTION multipolygonfromtext(text, integer)
COMMENT FUNCTION ndims(geometry)
COMMENT FUNCTION noop(geometry)
COMMENT FUNCTION npoints(geometry)
COMMENT FUNCTION nrings(geometry)
COMMENT FUNCTION numgeometries(geometry)
COMMENT FUNCTION numinteriorring(geometry)
COMMENT FUNCTION numinteriorrings(geometry)
COMMENT FUNCTION numpoints(geometry)
COMMENT FUNCTION overlaps(geometry, geometry)
COMMENT FUNCTION overlaps_2d(box2df, box2df)
COMMENT FUNCTION overlaps_2d(box2df, geometry)
COMMENT FUNCTION overlaps_2d(geometry, box2df)
COMMENT FUNCTION overlaps_geog(geography, gidx)
COMMENT FUNCTION overlaps_geog(gidx, geography)
COMMENT FUNCTION overlaps_geog(gidx, gidx)
COMMENT FUNCTION overlaps_nd(geometry, gidx)
COMMENT FUNCTION overlaps_nd(gidx, geometry)
COMMENT FUNCTION overlaps_nd(gidx, gidx)
COMMENT FUNCTION path(geometry)
COMMENT FUNCTION perimeter2d(geometry)
COMMENT FUNCTION perimeter3d(geometry)
COMMENT FUNCTION pgis_asflatgeobuf_finalfn(internal)
COMMENT FUNCTION pgis_asflatgeobuf_transfn(internal, anyelement)
COMMENT FUNCTION pgis_asflatgeobuf_transfn(internal, anyelement, boolean)
COMMENT FUNCTION pgis_asflatgeobuf_transfn(internal, anyelement, boolean, text)
COMMENT FUNCTION pgis_asgeobuf_finalfn(internal)
COMMENT FUNCTION pgis_asgeobuf_transfn(internal, anyelement)
COMMENT FUNCTION pgis_asgeobuf_transfn(internal, anyelement, text)
COMMENT FUNCTION pgis_asmvt_combinefn(internal, internal)
COMMENT FUNCTION pgis_asmvt_deserialfn(bytea, internal)
COMMENT FUNCTION pgis_asmvt_finalfn(internal)
COMMENT FUNCTION pgis_asmvt_serialfn(internal)
COMMENT FUNCTION pgis_asmvt_transfn(internal, anyelement)
COMMENT FUNCTION pgis_asmvt_transfn(internal, anyelement, text)
COMMENT FUNCTION pgis_asmvt_transfn(internal, anyelement, text, integer)
COMMENT FUNCTION pgis_asmvt_transfn(internal, anyelement, text, integer, text)
COMMENT FUNCTION pgis_asmvt_transfn(internal, anyelement, text, integer, text, text)
COMMENT FUNCTION pgis_geometry_accum_finalfn(internal)
COMMENT FUNCTION pgis_geometry_accum_transfn(internal, geometry)
COMMENT FUNCTION pgis_geometry_accum_transfn(internal, geometry, double precision)
COMMENT FUNCTION pgis_geometry_accum_transfn(internal, geometry, double precision, integer)
COMMENT FUNCTION pgis_geometry_clusterintersecting_finalfn(internal)
COMMENT FUNCTION pgis_geometry_clusterwithin_finalfn(internal)
COMMENT FUNCTION pgis_geometry_collect_finalfn(internal)
COMMENT FUNCTION pgis_geometry_coverageunion_finalfn(internal)
COMMENT FUNCTION pgis_geometry_makeline_finalfn(internal)
COMMENT FUNCTION pgis_geometry_polygonize_finalfn(internal)
COMMENT FUNCTION pgis_geometry_union_finalfn(internal)
COMMENT FUNCTION pgis_geometry_union_parallel_combinefn(internal, internal)
COMMENT FUNCTION pgis_geometry_union_parallel_deserialfn(bytea, internal)
COMMENT FUNCTION pgis_geometry_union_parallel_finalfn(internal)
COMMENT FUNCTION pgis_geometry_union_parallel_serialfn(internal)
COMMENT FUNCTION pgis_geometry_union_parallel_transfn(internal, geometry)
COMMENT FUNCTION pgis_geometry_union_parallel_transfn(internal, geometry, double precision)
COMMENT FUNCTION pgis_geometry_union_transfn(internal, geometry)
COMMENT FUNCTION pgis_twkb_accum_finalfn(internal)
COMMENT FUNCTION pgis_twkb_accum_transfn(internal, geometry, integer)
COMMENT FUNCTION pgis_twkb_accum_transfn(internal, geometry, integer, bigint)
COMMENT FUNCTION pgis_twkb_accum_transfn(internal, geometry, integer, bigint, boolean)
COMMENT FUNCTION pgis_twkb_accum_transfn(internal, geometry, integer, bigint, boolean, boolean)
COMMENT FUNCTION point(geometry)
COMMENT FUNCTION point_inside_circle(geometry, double precision, double precision, double precision)
COMMENT FUNCTION pointfromtext(text)
COMMENT FUNCTION pointfromtext(text, integer)
COMMENT FUNCTION pointfromwkb(bytea)
COMMENT FUNCTION pointfromwkb(bytea, integer)
COMMENT FUNCTION pointn(geometry, integer)
COMMENT FUNCTION pointonsurface(geometry)
COMMENT FUNCTION polyfromtext(text)
COMMENT FUNCTION polyfromtext(text, integer)
COMMENT FUNCTION polyfromwkb(bytea)
COMMENT FUNCTION polyfromwkb(bytea, integer)
COMMENT FUNCTION polygon(geometry)
COMMENT FUNCTION polygonfromtext(text)
COMMENT FUNCTION polygonfromtext(text, integer)
COMMENT FUNCTION polygonfromwkb(bytea)
COMMENT FUNCTION polygonfromwkb(bytea, integer)
COMMENT FUNCTION polygonize(toponame character varying)
COMMENT FUNCTION polygonize_garray(geometry[])
COMMENT FUNCTION populate_geometry_columns()
COMMENT FUNCTION populate_geometry_columns(oid)
COMMENT FUNCTION populate_geometry_columns(tbl_oid oid, use_typmod boolean)
COMMENT FUNCTION populate_geometry_columns(use_typmod boolean)
COMMENT FUNCTION populate_topology_layer()
COMMENT FUNCTION postgis_addbbox(geometry)
COMMENT FUNCTION postgis_cache_bbox()
COMMENT FUNCTION postgis_constraint_dims(geomschema text, geomtable text, geomcolumn text)
COMMENT FUNCTION postgis_constraint_srid(geomschema text, geomtable text, geomcolumn text)
COMMENT FUNCTION postgis_constraint_type(geomschema text, geomtable text, geomcolumn text)
COMMENT FUNCTION postgis_dropbbox(geometry)
COMMENT FUNCTION postgis_extensions_upgrade()
COMMENT FUNCTION postgis_extensions_upgrade(target_version text)
COMMENT FUNCTION postgis_full_version()
COMMENT FUNCTION postgis_gdal_version()
COMMENT FUNCTION postgis_geos_compiled_version()
COMMENT FUNCTION postgis_geos_noop(geometry)
COMMENT FUNCTION postgis_geos_version()
COMMENT FUNCTION postgis_getbbox(geometry)
COMMENT FUNCTION postgis_hasbbox(geometry)
COMMENT FUNCTION postgis_index_supportfn(internal)
COMMENT FUNCTION postgis_lib_build_date()
COMMENT FUNCTION postgis_lib_revision()
COMMENT FUNCTION postgis_lib_version()
COMMENT FUNCTION postgis_libjson_version()
COMMENT FUNCTION postgis_liblwgeom_version()
COMMENT FUNCTION postgis_libprotobuf_version()
COMMENT FUNCTION postgis_libxml_version()
COMMENT FUNCTION postgis_noop(geometry)
COMMENT FUNCTION postgis_noop(raster)
COMMENT FUNCTION postgis_proj_version()
COMMENT FUNCTION postgis_raster_lib_build_date()
COMMENT FUNCTION postgis_raster_lib_version()
COMMENT FUNCTION postgis_raster_scripts_installed()
COMMENT FUNCTION postgis_scripts_build_date()
COMMENT FUNCTION postgis_scripts_installed()
COMMENT FUNCTION postgis_scripts_released()
COMMENT FUNCTION postgis_sfcgal_full_version()
COMMENT FUNCTION postgis_sfcgal_noop(geometry)
COMMENT FUNCTION postgis_sfcgal_scripts_installed()
COMMENT FUNCTION postgis_sfcgal_version()
COMMENT FUNCTION postgis_srs(auth_name text, auth_srid text)
COMMENT FUNCTION postgis_srs_all()
COMMENT FUNCTION postgis_srs_codes(auth_name text)
COMMENT FUNCTION postgis_srs_search(bounds geometry, authname text)
COMMENT FUNCTION postgis_svn_version()
COMMENT FUNCTION postgis_topology_scripts_installed()
COMMENT FUNCTION postgis_transform_geometry(geom geometry, text, text, integer)
COMMENT FUNCTION postgis_transform_pipeline_geometry(geom geometry, pipeline text, forward boolean, to_srid integer)
COMMENT FUNCTION postgis_type_name(geomname character varying, coord_dimension integer, use_new_name boolean)
COMMENT FUNCTION postgis_typmod_dims(integer)
COMMENT FUNCTION postgis_typmod_srid(integer)
COMMENT FUNCTION postgis_typmod_type(integer)
COMMENT FUNCTION postgis_uses_stats()
COMMENT FUNCTION postgis_version()
COMMENT FUNCTION postgis_wagyu_version()
COMMENT FUNCTION probe_geometry_columns()
COMMENT FUNCTION raster_above(raster, raster)
COMMENT FUNCTION raster_below(raster, raster)
COMMENT FUNCTION raster_contain(raster, raster)
COMMENT FUNCTION raster_contained(raster, raster)
COMMENT FUNCTION raster_contained_by_geometry(raster, geometry)
COMMENT FUNCTION raster_eq(raster, raster)
COMMENT FUNCTION raster_geometry_contain(raster, geometry)
COMMENT FUNCTION raster_geometry_overlap(raster, geometry)
COMMENT FUNCTION raster_hash(raster)
COMMENT FUNCTION raster_in(cstring)
COMMENT FUNCTION raster_left(raster, raster)
COMMENT FUNCTION raster_out(raster)
COMMENT FUNCTION raster_overabove(raster, raster)
COMMENT FUNCTION raster_overbelow(raster, raster)
COMMENT FUNCTION raster_overlap(raster, raster)
COMMENT FUNCTION raster_overleft(raster, raster)
COMMENT FUNCTION raster_overright(raster, raster)
COMMENT FUNCTION raster_right(raster, raster)
COMMENT FUNCTION raster_same(raster, raster)
COMMENT FUNCTION relate(geometry, geometry)
COMMENT FUNCTION relate(geometry, geometry, text)
COMMENT FUNCTION relationtrigger()
COMMENT FUNCTION removepoint(geometry, integer)
COMMENT FUNCTION removeunusedprimitives(atopology text, bbox geometry)
COMMENT FUNCTION rename_geometry_table_constraints()
COMMENT FUNCTION renametopogeometrycolumn(layer_table regclass, feature_column name, new_name name)
COMMENT FUNCTION renametopology(old_name character varying, new_name character varying)
COMMENT FUNCTION reverse(geometry)
COMMENT FUNCTION rotate(geometry, double precision)
COMMENT FUNCTION rotatex(geometry, double precision)
COMMENT FUNCTION rotatey(geometry, double precision)
COMMENT FUNCTION rotatez(geometry, double precision)
COMMENT FUNCTION scale(geometry, double precision, double precision)
COMMENT FUNCTION scale(geometry, double precision, double precision, double precision)
COMMENT FUNCTION se_envelopesintersect(geometry, geometry)
COMMENT FUNCTION se_is3d(geometry)
COMMENT FUNCTION se_ismeasured(geometry)
COMMENT FUNCTION se_locatealong(geometry, double precision)
COMMENT FUNCTION se_locatebetween(geometry, double precision, double precision)
COMMENT FUNCTION se_m(geometry)
COMMENT FUNCTION se_z(geometry)
COMMENT FUNCTION segmentize(geometry, double precision)
COMMENT FUNCTION setpoint(geometry, integer, geometry)
COMMENT FUNCTION setsrid(geometry, integer)
COMMENT FUNCTION shift_longitude(geometry)
COMMENT FUNCTION simplify(geometry, double precision)
COMMENT FUNCTION snaptogrid(geometry, double precision)
COMMENT FUNCTION snaptogrid(geometry, double precision, double precision)
COMMENT FUNCTION snaptogrid(geometry, double precision, double precision, double precision, double precision)
COMMENT FUNCTION snaptogrid(geometry, geometry, double precision, double precision, double precision, double precision)
COMMENT FUNCTION spheroid_in(cstring)
COMMENT FUNCTION spheroid_out(spheroid)
COMMENT FUNCTION srid(geometry)
COMMENT FUNCTION st_3darea(geometry)
COMMENT FUNCTION st_3dclosestpoint(geom1 geometry, geom2 geometry)
COMMENT FUNCTION st_3dconvexhull(geometry)
COMMENT FUNCTION st_3ddfullywithin(geom1 geometry, geom2 geometry, double precision)
COMMENT FUNCTION st_3ddifference(geom1 geometry, geom2 geometry)
COMMENT FUNCTION st_3ddistance(geom1 geometry, geom2 geometry)
COMMENT FUNCTION st_3ddwithin(geom1 geometry, geom2 geometry, double precision)
COMMENT FUNCTION st_3dintersection(geom1 geometry, geom2 geometry)
COMMENT FUNCTION st_3dintersects(geom1 geometry, geom2 geometry)
COMMENT FUNCTION st_3dlength(geometry)
COMMENT FUNCTION st_3dlength_spheroid(geometry, spheroid)
COMMENT FUNCTION st_3dlineinterpolatepoint(geometry, double precision)
COMMENT FUNCTION st_3dlongestline(geom1 geometry, geom2 geometry)
COMMENT FUNCTION st_3dmakebox(geom1 geometry, geom2 geometry)
COMMENT FUNCTION st_3dmaxdistance(geom1 geometry, geom2 geometry)
COMMENT FUNCTION st_3dperimeter(geometry)
COMMENT FUNCTION st_3dshortestline(geom1 geometry, geom2 geometry)
COMMENT FUNCTION st_3dunion(geom1 geometry, geom2 geometry)
COMMENT FUNCTION st_above(raster, raster)
COMMENT FUNCTION st_addband(rast raster, addbandargset addbandarg[])
COMMENT FUNCTION st_addband(rast raster, index integer, outdbfile text, outdbindex integer[], nodataval double precision)
COMMENT FUNCTION st_addband(rast raster, index integer, pixeltype text, initialvalue double precision, nodataval double precision)
COMMENT FUNCTION st_addband(rast raster, outdbfile text, outdbindex integer[], index integer, nodataval double precision)
COMMENT FUNCTION st_addband(rast raster, pixeltype text, initialvalue double precision, nodataval double precision)
COMMENT FUNCTION st_addband(raster, integer, text)
COMMENT FUNCTION st_addband(raster, integer, text, double precision)
COMMENT FUNCTION st_addband(raster, integer, text, double precision, double precision)
COMMENT FUNCTION st_addband(raster, raster)
COMMENT FUNCTION st_addband(raster, raster, integer)
COMMENT FUNCTION st_addband(raster, raster, integer, integer)
COMMENT FUNCTION st_addband(raster, raster[], integer)
COMMENT FUNCTION st_addband(raster, text)
COMMENT FUNCTION st_addband(raster, text, double precision)
COMMENT FUNCTION st_addband(raster, text, double precision, double precision)
COMMENT FUNCTION st_addband(torast raster, fromrast raster, fromband integer, torastindex integer)
COMMENT FUNCTION st_addband(torast raster, fromrasts raster[], fromband integer, torastindex integer)
COMMENT FUNCTION st_addbbox(geometry)
COMMENT FUNCTION st_addedgemodface(atopology character varying, anode integer, anothernode integer, acurve geometry)
COMMENT FUNCTION st_addedgenewfaces(atopology character varying, anode integer, anothernode integer, acurve geometry)
COMMENT FUNCTION st_addisoedge(atopology character varying, anode integer, anothernode integer, acurve geometry)
COMMENT FUNCTION st_addisonode(atopology character varying, aface integer, apoint geometry)
COMMENT FUNCTION st_addmeasure(geometry, double precision, double precision)
COMMENT FUNCTION st_addpoint(geom1 geometry, geom2 geometry)
COMMENT FUNCTION st_addpoint(geom1 geometry, geom2 geometry, integer)
COMMENT FUNCTION st_affine(geometry, double precision, double precision, double precision, double precision, double precision, double precision)
COMMENT FUNCTION st_affine(geometry, double precision, double precision, double precision, double precision, double precision, double precision, double precision, double precision, double precision, double precision, double precision, double precision)
COMMENT FUNCTION st_alphashape(g1 geometry, alpha double precision, allow_holes boolean)
COMMENT FUNCTION st_angle(line1 geometry, line2 geometry)
COMMENT FUNCTION st_angle(pt1 geometry, pt2 geometry, pt3 geometry, pt4 geometry)
COMMENT FUNCTION st_approxcount(rast raster, exclude_nodata_value boolean, sample_percent double precision)
COMMENT FUNCTION st_approxcount(rast raster, nband integer, exclude_nodata_value boolean, sample_percent double precision)
COMMENT FUNCTION st_approxcount(rast raster, nband integer, sample_percent double precision)
COMMENT FUNCTION st_approxcount(rast raster, sample_percent double precision)
COMMENT FUNCTION st_approxcount(text, text, boolean, double precision)
COMMENT FUNCTION st_approxcount(text, text, double precision)
COMMENT FUNCTION st_approxcount(text, text, integer, boolean, double precision)
COMMENT FUNCTION st_approxcount(text, text, integer, double precision)
COMMENT FUNCTION st_approxhistogram(rast raster, nband integer, exclude_nodata_value boolean, sample_percent double precision, bins integer, right boolean, out min double precision, out max double precision, out count bigint, out percent double precision)
COMMENT FUNCTION st_approxhistogram(rast raster, nband integer, exclude_nodata_value boolean, sample_percent double precision, bins integer, width double precision[], right boolean, out min double precision, out max double precision, out count bigint, out percent double precision)
COMMENT FUNCTION st_approxhistogram(rast raster, nband integer, sample_percent double precision, bins integer, right boolean, out min double precision, out max double precision, out count bigint, out percent double precision)
COMMENT FUNCTION st_approxhistogram(rast raster, nband integer, sample_percent double precision, bins integer, width double precision[], right boolean, out min double precision, out max double precision, out count bigint, out percent double precision)
COMMENT FUNCTION st_approxhistogram(rast raster, nband integer, sample_percent double precision, out min double precision, out max double precision, out count bigint, out percent double precision)
COMMENT FUNCTION st_approxhistogram(rast raster, sample_percent double precision, out min double precision, out max double precision, out count bigint, out percent double precision)
COMMENT FUNCTION st_approxhistogram(raster, double precision)
COMMENT FUNCTION st_approxhistogram(raster, integer, boolean, double precision, integer, boolean)
COMMENT FUNCTION st_approxhistogram(raster, integer, boolean, double precision, integer, double precision[], boolean)
COMMENT FUNCTION st_approxhistogram(raster, integer, double precision)
COMMENT FUNCTION st_approxhistogram(raster, integer, double precision, integer, boolean)
COMMENT FUNCTION st_approxhistogram(raster, integer, double precision, integer, double precision[], boolean)
COMMENT FUNCTION st_approxhistogram(text, text, double precision)
COMMENT FUNCTION st_approxhistogram(text, text, integer, boolean, double precision, integer, boolean)
COMMENT FUNCTION st_approxhistogram(text, text, integer, boolean, double precision, integer, double precision[], boolean)
COMMENT FUNCTION st_approxhistogram(text, text, integer, double precision)
COMMENT FUNCTION st_approxhistogram(text, text, integer, double precision, integer, boolean)
COMMENT FUNCTION st_approxhistogram(text, text, integer, double precision, integer, double precision[], boolean)
COMMENT FUNCTION st_approximatemedialaxis(geometry)
COMMENT FUNCTION st_approxquantile(rast raster, exclude_nodata_value boolean, quantile double precision)
COMMENT FUNCTION st_approxquantile(rast raster, nband integer, exclude_nodata_value boolean, sample_percent double precision, quantile double precision)
COMMENT FUNCTION st_approxquantile(rast raster, nband integer, exclude_nodata_value boolean, sample_percent double precision, quantiles double precision[], out quantile double precision, out value double precision)
COMMENT FUNCTION st_approxquantile(rast raster, nband integer, sample_percent double precision, quantile double precision)
COMMENT FUNCTION st_approxquantile(rast raster, nband integer, sample_percent double precision, quantiles double precision[], out quantile double precision, out value double precision)
COMMENT FUNCTION st_approxquantile(rast raster, quantile double precision)
COMMENT FUNCTION st_approxquantile(rast raster, quantiles double precision[], out quantile double precision, out value double precision)
COMMENT FUNCTION st_approxquantile(rast raster, sample_percent double precision, quantile double precision)
COMMENT FUNCTION st_approxquantile(rast raster, sample_percent double precision, quantiles double precision[], out quantile double precision, out value double precision)
COMMENT FUNCTION st_approxquantile(raster, double precision, double precision[])
COMMENT FUNCTION st_approxquantile(raster, double precision[])
COMMENT FUNCTION st_approxquantile(raster, integer, boolean, double precision, double precision[])
COMMENT FUNCTION st_approxquantile(raster, integer, double precision, double precision[])
COMMENT FUNCTION st_approxquantile(rastertable text, rastercolumn text, exclude_nodata_value boolean, quantile double precision)
COMMENT FUNCTION st_approxquantile(rastertable text, rastercolumn text, nband integer, exclude_nodata_value boolean, sample_percent double precision, quantile double precision)
COMMENT FUNCTION st_approxquantile(rastertable text, rastercolumn text, nband integer, exclude_nodata_value boolean, sample_percent double precision, quantiles double precision[], out quantile double precision, out value double precision)
COMMENT FUNCTION st_approxquantile(rastertable text, rastercolumn text, nband integer, sample_percent double precision, quantile double precision)
COMMENT FUNCTION st_approxquantile(rastertable text, rastercolumn text, nband integer, sample_percent double precision, quantiles double precision[], out quantile double precision, out value double precision)
COMMENT FUNCTION st_approxquantile(rastertable text, rastercolumn text, quantile double precision)
COMMENT FUNCTION st_approxquantile(rastertable text, rastercolumn text, quantiles double precision[], out quantile double precision, out value double precision)
COMMENT FUNCTION st_approxquantile(rastertable text, rastercolumn text, sample_percent double precision, quantile double precision)
COMMENT FUNCTION st_approxquantile(rastertable text, rastercolumn text, sample_percent double precision, quantiles double precision[], out quantile double precision, out value double precision)
COMMENT FUNCTION st_approxquantile(text, text, double precision, double precision[])
COMMENT FUNCTION st_approxquantile(text, text, double precision[])
COMMENT FUNCTION st_approxquantile(text, text, integer, boolean, double precision, double precision[])
COMMENT FUNCTION st_approxquantile(text, text, integer, double precision, double precision[])
COMMENT FUNCTION st_approxsummarystats(rast raster, exclude_nodata_value boolean, sample_percent double precision)
COMMENT FUNCTION st_approxsummarystats(rast raster, nband integer, exclude_nodata_value boolean, sample_percent double precision)
COMMENT FUNCTION st_approxsummarystats(rast raster, nband integer, sample_percent double precision)
COMMENT FUNCTION st_approxsummarystats(rast raster, sample_percent double precision)
COMMENT FUNCTION st_approxsummarystats(raster, boolean, double precision)
COMMENT FUNCTION st_approxsummarystats(raster, double precision)
COMMENT FUNCTION st_approxsummarystats(raster, integer, boolean, double precision)
COMMENT FUNCTION st_approxsummarystats(raster, integer, double precision)
COMMENT FUNCTION st_approxsummarystats(text, text, boolean)
COMMENT FUNCTION st_approxsummarystats(text, text, double precision)
COMMENT FUNCTION st_approxsummarystats(text, text, integer, boolean, double precision)
COMMENT FUNCTION st_approxsummarystats(text, text, integer, double precision)
COMMENT FUNCTION st_area(geog geography, use_spheroid boolean)
COMMENT FUNCTION st_area(geography)
COMMENT FUNCTION st_area(geometry)
COMMENT FUNCTION st_area(text)
COMMENT FUNCTION st_area2d(geometry)
COMMENT FUNCTION st_asbinary(geography)
COMMENT FUNCTION st_asbinary(geography, text)
COMMENT FUNCTION st_asbinary(geometry)
COMMENT FUNCTION st_asbinary(geometry, text)
COMMENT FUNCTION st_asbinary(raster)
COMMENT FUNCTION st_asbinary(raster, outasin boolean)
COMMENT FUNCTION st_asbinary(text)
COMMENT FUNCTION st_asencodedpolyline(geom geometry, nprecision integer)
COMMENT FUNCTION st_asewkb(geometry)
COMMENT FUNCTION st_asewkb(geometry, text)
COMMENT FUNCTION st_asewkt(geography)
COMMENT FUNCTION st_asewkt(geography, integer)
COMMENT FUNCTION st_asewkt(geometry)
COMMENT FUNCTION st_asewkt(geometry, integer)
COMMENT FUNCTION st_asewkt(text)
COMMENT FUNCTION st_asgdalraster(rast raster, format text, options text[], srid integer)
COMMENT FUNCTION st_asgeojson(geog geography, maxdecimaldigits integer, options integer)
COMMENT FUNCTION st_asgeojson(geography)
COMMENT FUNCTION st_asgeojson(geography, integer)
COMMENT FUNCTION st_asgeojson(geom geometry, maxdecimaldigits integer, options integer)
COMMENT FUNCTION st_asgeojson(geometry)
COMMENT FUNCTION st_asgeojson(geometry, integer)
COMMENT FUNCTION st_asgeojson(integer, geography)
COMMENT FUNCTION st_asgeojson(integer, geography, integer)
COMMENT FUNCTION st_asgeojson(integer, geography, integer, integer)
COMMENT FUNCTION st_asgeojson(integer, geometry)
COMMENT FUNCTION st_asgeojson(integer, geometry, integer)
COMMENT FUNCTION st_asgeojson(integer, geometry, integer, integer)
COMMENT FUNCTION st_asgeojson(r record, geom_column text, maxdecimaldigits integer, pretty_bool boolean)
COMMENT FUNCTION st_asgeojson(text)
COMMENT FUNCTION st_asgeojson(version integer, geog geography, maxdecimaldigits integer, options integer)
COMMENT FUNCTION st_asgeojson(version integer, geog geometry, maxdecimaldigits integer, options integer)
COMMENT FUNCTION st_asgml(geog geography, maxdecimaldigits integer, options integer, nprefix text, id text)
COMMENT FUNCTION st_asgml(geography)
COMMENT FUNCTION st_asgml(geography, integer)
COMMENT FUNCTION st_asgml(geography, integer, integer)
COMMENT FUNCTION st_asgml(geom geometry, maxdecimaldigits integer, options integer)
COMMENT FUNCTION st_asgml(geometry)
COMMENT FUNCTION st_asgml(geometry, integer)
COMMENT FUNCTION st_asgml(integer, geography)
COMMENT FUNCTION st_asgml(integer, geography, integer)
COMMENT FUNCTION st_asgml(integer, geography, integer, integer)
COMMENT FUNCTION st_asgml(integer, geography, integer, integer, text)
COMMENT FUNCTION st_asgml(integer, geometry)
COMMENT FUNCTION st_asgml(integer, geometry, integer)
COMMENT FUNCTION st_asgml(integer, geometry, integer, integer)
COMMENT FUNCTION st_asgml(integer, geometry, integer, integer, text)
COMMENT FUNCTION st_asgml(text)
COMMENT FUNCTION st_asgml(version integer, geog geography, maxdecimaldigits integer, options integer, nprefix text, id text)
COMMENT FUNCTION st_asgml(version integer, geom geometry, maxdecimaldigits integer, options integer, nprefix text, id text)
COMMENT FUNCTION st_ashexewkb(geometry)
COMMENT FUNCTION st_ashexewkb(geometry, text)
COMMENT FUNCTION st_ashexwkb(raster, outasin boolean)
COMMENT FUNCTION st_asjpeg(rast raster, nband integer, options text[])
COMMENT FUNCTION st_asjpeg(rast raster, nband integer, quality integer)
COMMENT FUNCTION st_asjpeg(rast raster, nbands integer[], options text[])
COMMENT FUNCTION st_asjpeg(rast raster, nbands integer[], quality integer)
COMMENT FUNCTION st_asjpeg(rast raster, options text[])
COMMENT FUNCTION st_askml(geog geography, maxdecimaldigits integer, nprefix text)
COMMENT FUNCTION st_askml(geography)
COMMENT FUNCTION st_askml(geom geometry, maxdecimaldigits integer, nprefix text)
COMMENT FUNCTION st_askml(geometry)
COMMENT FUNCTION st_askml(integer, geography, integer)
COMMENT FUNCTION st_askml(integer, geography, integer, text)
COMMENT FUNCTION st_askml(integer, geometry, integer)
COMMENT FUNCTION st_askml(integer, geometry, integer, text)
COMMENT FUNCTION st_askml(text)
COMMENT FUNCTION st_askml(version integer, geom geography, maxdecimaldigits integer, nprefix text)
COMMENT FUNCTION st_askml(version integer, geom geometry, maxdecimaldigits integer, nprefix text)
COMMENT FUNCTION st_aslatlontext(geom geometry, tmpl text)
COMMENT FUNCTION st_aslatlontext(geometry)
COMMENT FUNCTION st_asmarc21(geom geometry, format text)
COMMENT FUNCTION st_asmvtgeom(geom geometry, bounds box2d, extent integer, buffer integer, clip_geom boolean)
COMMENT FUNCTION st_aspect(rast raster, nband integer, customextent raster, pixeltype text, units text, interpolate_nodata boolean)
COMMENT FUNCTION st_aspect(rast raster, nband integer, pixeltype text, units text, interpolate_nodata boolean)
COMMENT FUNCTION st_aspect(raster, integer, text)
COMMENT FUNCTION st_aspect(raster, integer, text, boolean)
COMMENT FUNCTION st_aspect(raster, integer, text, text, boolean)
COMMENT FUNCTION st_aspng(rast raster, nband integer, compression integer)
COMMENT FUNCTION st_aspng(rast raster, nband integer, options text[])
COMMENT FUNCTION st_aspng(rast raster, nbands integer[], compression integer)
COMMENT FUNCTION st_aspng(rast raster, nbands integer[], options text[])
COMMENT FUNCTION st_aspng(rast raster, options text[])
COMMENT FUNCTION st_asraster(geom geometry, ref raster, pixeltype text, value double precision, nodataval double precision, touched boolean)
COMMENT FUNCTION st_asraster(geom geometry, ref raster, pixeltype text[], value double precision[], nodataval double precision[], touched boolean)
COMMENT FUNCTION st_asraster(geom geometry, scalex double precision, scaley double precision, gridx double precision, gridy double precision, pixeltype text, value double precision, nodataval double precision, skewx double precision, skewy double precision, touched boolean)
COMMENT FUNCTION st_asraster(geom geometry, scalex double precision, scaley double precision, gridx double precision, gridy double precision, pixeltype text[], value double precision[], nodataval double precision[], skewx double precision, skewy double precision, touched boolean)
COMMENT FUNCTION st_asraster(geom geometry, scalex double precision, scaley double precision, pixeltype text, value double precision, nodataval double precision, upperleftx double precision, upperlefty double precision, skewx double precision, skewy double precision, touched boolean)
COMMENT FUNCTION st_asraster(geom geometry, scalex double precision, scaley double precision, pixeltype text[], value double precision[], nodataval double precision[], upperleftx double precision, upperlefty double precision, skewx double precision, skewy double precision, touched boolean)
COMMENT FUNCTION st_asraster(geom geometry, width integer, height integer, gridx double precision, gridy double precision, pixeltype text, value double precision, nodataval double precision, skewx double precision, skewy double precision, touched boolean)
COMMENT FUNCTION st_asraster(geom geometry, width integer, height integer, gridx double precision, gridy double precision, pixeltype text[], value double precision[], nodataval double precision[], skewx double precision, skewy double precision, touched boolean)
COMMENT FUNCTION st_asraster(geom geometry, width integer, height integer, pixeltype text, value double precision, nodataval double precision, upperleftx double precision, upperlefty double precision, skewx double precision, skewy double precision, touched boolean)
COMMENT FUNCTION st_asraster(geom geometry, width integer, height integer, pixeltype text[], value double precision[], nodataval double precision[], upperleftx double precision, upperlefty double precision, skewx double precision, skewy double precision, touched boolean)
COMMENT FUNCTION st_asraster(geometry, double precision, double precision, text, double precision, double precision, double precision, double precision, double precision, double precision)
COMMENT FUNCTION st_asraster(geometry, integer, integer, double precision, double precision, text, double precision, double precision, double precision, double precision)
COMMENT FUNCTION st_asraster(geometry, integer, integer, double precision, double precision, text[], double precision[], double precision[], double precision, double precision)
COMMENT FUNCTION st_asraster(geometry, integer, integer, text, double precision, double precision, double precision, double precision, double precision, double precision)
COMMENT FUNCTION st_asraster(geometry, integer, integer, text[], double precision[], double precision[], double precision, double precision, double precision, double precision)
COMMENT FUNCTION st_asraster(geometry, raster, text, double precision, double precision)
COMMENT FUNCTION st_assvg(geog geography, rel integer, maxdecimaldigits integer)
COMMENT FUNCTION st_assvg(geography)
COMMENT FUNCTION st_assvg(geography, integer)
COMMENT FUNCTION st_assvg(geom geometry, rel integer, maxdecimaldigits integer)
COMMENT FUNCTION st_assvg(geometry)
COMMENT FUNCTION st_assvg(geometry, integer)
COMMENT FUNCTION st_assvg(text)
COMMENT FUNCTION st_astext(bytea)
COMMENT FUNCTION st_astext(geography)
COMMENT FUNCTION st_astext(geography, integer)
COMMENT FUNCTION st_astext(geometry)
COMMENT FUNCTION st_astext(geometry, integer)
COMMENT FUNCTION st_astext(text)
COMMENT FUNCTION st_astiff(rast raster, compression text, srid integer)
COMMENT FUNCTION st_astiff(rast raster, nbands integer[], compression text, srid integer)
COMMENT FUNCTION st_astiff(rast raster, nbands integer[], options text[], srid integer)
COMMENT FUNCTION st_astiff(rast raster, options text[], srid integer)
COMMENT FUNCTION st_astwkb(geom geometry, prec integer, prec_z integer, prec_m integer, with_sizes boolean, with_boxes boolean)
COMMENT FUNCTION st_astwkb(geom geometry[], ids bigint[], prec integer, prec_z integer, prec_m integer, with_sizes boolean, with_boxes boolean)
COMMENT FUNCTION st_astwkb(geometry, integer, bigint, boolean, boolean)
COMMENT FUNCTION st_aswkb(raster, outasin boolean)
COMMENT FUNCTION st_asx3d(geom geometry, maxdecimaldigits integer, options integer)
COMMENT FUNCTION st_asx3d(geometry)
COMMENT FUNCTION st_asx3d(geometry, integer)
COMMENT FUNCTION st_azimuth(geog1 geography, geog2 geography)
COMMENT FUNCTION st_azimuth(geom1 geometry, geom2 geometry)
COMMENT FUNCTION st_band(rast raster, nband integer)
COMMENT FUNCTION st_band(rast raster, nbands integer[])
COMMENT FUNCTION st_band(rast raster, nbands text, delimiter character)
COMMENT FUNCTION st_bandfilesize(rast raster, band integer)
COMMENT FUNCTION st_bandfiletimestamp(rast raster, band integer)
COMMENT FUNCTION st_bandisnodata(rast raster, band integer, forcechecking boolean)
COMMENT FUNCTION st_bandisnodata(rast raster, forcechecking boolean)
COMMENT FUNCTION st_bandisnodata(raster)
COMMENT FUNCTION st_bandisnodata(raster, integer)
COMMENT FUNCTION st_bandisnodata(raster, integer, boolean)
COMMENT FUNCTION st_bandmetadata(rast raster, band integer)
COMMENT FUNCTION st_bandmetadata(rast raster, band integer[])
COMMENT FUNCTION st_bandmetadata(raster, integer)
COMMENT FUNCTION st_bandmetadata(raster, integer[])
COMMENT FUNCTION st_bandmetadata(raster, variadic integer[])
COMMENT FUNCTION st_bandnodatavalue(rast raster, band integer)
COMMENT FUNCTION st_bandnodatavalue(raster)
COMMENT FUNCTION st_bandnodatavalue(raster, integer)
COMMENT FUNCTION st_bandpath(rast raster, band integer)
COMMENT FUNCTION st_bandpath(raster)
COMMENT FUNCTION st_bandpath(raster, integer)
COMMENT FUNCTION st_bandpixeltype(rast raster, band integer)
COMMENT FUNCTION st_bandpixeltype(raster)
COMMENT FUNCTION st_bandpixeltype(raster, integer)
COMMENT FUNCTION st_bandsurface(raster, integer)
COMMENT FUNCTION st_bdmpolyfromtext(text, integer)
COMMENT FUNCTION st_bdpolyfromtext(text, integer)
COMMENT FUNCTION st_below(raster, raster)
COMMENT FUNCTION st_boundary(geometry)
COMMENT FUNCTION st_boundingdiagonal(geom geometry, fits boolean)
COMMENT FUNCTION st_box(box3d)
COMMENT FUNCTION st_box(geometry)
COMMENT FUNCTION st_box2d(box3d)
COMMENT FUNCTION st_box2d(geometry)
COMMENT FUNCTION st_box2d_contain(box2d, box2d)
COMMENT FUNCTION st_box2d_contained(box2d, box2d)
COMMENT FUNCTION st_box2d_in(cstring)
COMMENT FUNCTION st_box2d_intersects(box2d, box2d)
COMMENT FUNCTION st_box2d_left(box2d, box2d)
COMMENT FUNCTION st_box2d_out(box2d)
COMMENT FUNCTION st_box2d_overlap(box2d, box2d)
COMMENT FUNCTION st_box2d_overleft(box2d, box2d)
COMMENT FUNCTION st_box2d_overright(box2d, box2d)
COMMENT FUNCTION st_box2d_right(box2d, box2d)
COMMENT FUNCTION st_box2d_same(box2d, box2d)
COMMENT FUNCTION st_box2dfromgeohash(text, integer)
COMMENT FUNCTION st_box3d(box2d)
COMMENT FUNCTION st_box3d(geometry)
COMMENT FUNCTION st_box3d_in(cstring)
COMMENT FUNCTION st_box3d_out(box3d)
COMMENT FUNCTION st_buffer(geography, double precision)
COMMENT FUNCTION st_buffer(geography, double precision, integer)
COMMENT FUNCTION st_buffer(geography, double precision, text)
COMMENT FUNCTION st_buffer(geom geometry, radius double precision, options text)
COMMENT FUNCTION st_buffer(geom geometry, radius double precision, quadsegs integer)
COMMENT FUNCTION st_buffer(geometry, double precision)
COMMENT FUNCTION st_buffer(geometry, double precision, cstring)
COMMENT FUNCTION st_buffer(text, double precision)
COMMENT FUNCTION st_buffer(text, double precision, integer)
COMMENT FUNCTION st_buffer(text, double precision, text)
COMMENT FUNCTION st_buildarea(geometry)
COMMENT FUNCTION st_bytea(geometry)
COMMENT FUNCTION st_bytea(raster)
COMMENT FUNCTION st_cache_bbox()
COMMENT FUNCTION st_centroid(geography, use_spheroid boolean)
COMMENT FUNCTION st_centroid(geometry)
COMMENT FUNCTION st_centroid(text)
COMMENT FUNCTION st_chaikinsmoothing(geometry, integer, boolean)
COMMENT FUNCTION st_changeedgegeom(atopology character varying, anedge integer, acurve geometry)
COMMENT FUNCTION st_cleangeometry(geometry)
COMMENT FUNCTION st_clip(rast raster, geom geometry, crop boolean)
COMMENT FUNCTION st_clip(rast raster, geom geometry, nodataval double precision, crop boolean)
COMMENT FUNCTION st_clip(rast raster, geom geometry, nodataval double precision[], crop boolean)
COMMENT FUNCTION st_clip(rast raster, nband integer, geom geometry, crop boolean)
COMMENT FUNCTION st_clip(rast raster, nband integer, geom geometry, nodataval double precision, crop boolean)
COMMENT FUNCTION st_clip(rast raster, nband integer[], geom geometry, nodataval double precision[], crop boolean)
COMMENT FUNCTION st_clip(raster, geometry, boolean)
COMMENT FUNCTION st_clip(raster, geometry, double precision, boolean)
COMMENT FUNCTION st_clip(raster, geometry, double precision[], boolean)
COMMENT FUNCTION st_clip(raster, integer, geometry, boolean)
COMMENT FUNCTION st_clip(raster, integer, geometry, double precision, boolean)
COMMENT FUNCTION st_clip(raster, integer, geometry, double precision[], boolean)
COMMENT FUNCTION st_clipbybox2d(geom geometry, box box2d)
COMMENT FUNCTION st_closestpoint(geography, geography, use_spheroid boolean)
COMMENT FUNCTION st_closestpoint(geom1 geometry, geom2 geometry)
COMMENT FUNCTION st_closestpoint(text, text)
COMMENT FUNCTION st_closestpointofapproach(geometry, geometry)
COMMENT FUNCTION st_clusterdbscan(geometry, eps double precision, minpoints integer)
COMMENT FUNCTION st_clusterintersecting(geometry[])
COMMENT FUNCTION st_clusterintersectingwin(geometry)
COMMENT FUNCTION st_clusterkmeans(geom geometry, k integer)
COMMENT FUNCTION st_clusterkmeans(geom geometry, k integer, max_radius double precision)
COMMENT FUNCTION st_clusterwithin(geometry[], double precision)
COMMENT FUNCTION st_clusterwithinwin(geometry, distance double precision)
COMMENT FUNCTION st_collect(geom1 geometry, geom2 geometry)
COMMENT FUNCTION st_collect(geometry[])
COMMENT FUNCTION st_collect_garray(geometry[])
COMMENT FUNCTION st_collectionextract(geometry)
COMMENT FUNCTION st_collectionextract(geometry, integer)
COMMENT FUNCTION st_collectionhomogenize(geometry)
COMMENT FUNCTION st_collector(geometry, geometry)
COMMENT FUNCTION st_colormap(rast raster, colormap text, method text)
COMMENT FUNCTION st_colormap(rast raster, nband integer, colormap text, method text)
COMMENT FUNCTION st_combine_bbox(box2d, geometry)
COMMENT FUNCTION st_combine_bbox(box3d, geometry)
COMMENT FUNCTION st_combinebbox(box2d, geometry)
COMMENT FUNCTION st_combinebbox(box3d, box3d)
COMMENT FUNCTION st_combinebbox(box3d, geometry)
COMMENT FUNCTION st_concavehull(geometry, float)
COMMENT FUNCTION st_concavehull(param_geom geometry, param_pctconvex double precision, param_allow_holes boolean)
COMMENT FUNCTION st_concavehull(param_geom geometry, param_pctconvex float, param_allow_holes boolean)
COMMENT FUNCTION st_constraineddelaunaytriangles(geometry)
COMMENT FUNCTION st_contain(raster, raster)
COMMENT FUNCTION st_contained(raster, raster)
COMMENT FUNCTION st_contains(geom1 geometry, geom2 geometry)
COMMENT FUNCTION st_contains(geometry, raster, integer)
COMMENT FUNCTION st_contains(rast1 raster, nband1 integer, rast2 raster, nband2 integer)
COMMENT FUNCTION st_contains(rast1 raster, rast2 raster)
COMMENT FUNCTION st_contains(raster, geometry, integer)
COMMENT FUNCTION st_contains(raster, integer, geometry)
COMMENT FUNCTION st_containsproperly(geom1 geometry, geom2 geometry)
COMMENT FUNCTION st_containsproperly(rast1 raster, nband1 integer, rast2 raster, nband2 integer)
COMMENT FUNCTION st_containsproperly(rast1 raster, rast2 raster)
COMMENT FUNCTION st_contour(rast raster, bandnumber integer, level_interval double precision, level_base double precision, fixed_levels double precision[], polygonize boolean)
COMMENT FUNCTION st_convexhull(geometry)
COMMENT FUNCTION st_convexhull(raster)
COMMENT FUNCTION st_coorddim(geometry geometry)
COMMENT FUNCTION st_count(rast raster, exclude_nodata_value boolean)
COMMENT FUNCTION st_count(rast raster, nband integer, exclude_nodata_value boolean)
COMMENT FUNCTION st_count(text, text, boolean)
COMMENT FUNCTION st_count(text, text, integer, boolean)
COMMENT FUNCTION st_coverageinvalidedges(geom geometry, tolerance double precision)
COMMENT FUNCTION st_coverageinvalidlocations(geometry, double precision)
COMMENT FUNCTION st_coveragesimplify(geom geometry, tolerance double precision, simplifyboundary boolean)
COMMENT FUNCTION st_coverageunion(geometry[])
COMMENT FUNCTION st_coveredby(geog1 geography, geog2 geography)
COMMENT FUNCTION st_coveredby(geom1 geometry, geom2 geometry)
COMMENT FUNCTION st_coveredby(rast1 raster, nband1 integer, rast2 raster, nband2 integer)
COMMENT FUNCTION st_coveredby(rast1 raster, rast2 raster)
COMMENT FUNCTION st_coveredby(text, text)
COMMENT FUNCTION st_covers(geog1 geography, geog2 geography)
COMMENT FUNCTION st_covers(geom1 geometry, geom2 geometry)
COMMENT FUNCTION st_covers(rast1 raster, nband1 integer, rast2 raster, nband2 integer)
COMMENT FUNCTION st_covers(rast1 raster, rast2 raster)
COMMENT FUNCTION st_covers(text, text)
COMMENT FUNCTION st_cpawithin(geometry, geometry, double precision)
COMMENT FUNCTION st_createoverview(tab regclass, col name, factor integer, algo text)
COMMENT FUNCTION st_createtopogeo(atopology character varying, acollection geometry)
COMMENT FUNCTION st_crosses(geom1 geometry, geom2 geometry)
COMMENT FUNCTION st_curvetoline(geom geometry, tol double precision, toltype integer, flags integer)
COMMENT FUNCTION st_curvetoline(geometry)
COMMENT FUNCTION st_curvetoline(geometry, integer)
COMMENT FUNCTION st_delaunaytriangles(g1 geometry, tolerance double precision, flags integer)
COMMENT FUNCTION st_dfullywithin(geom1 geometry, geom2 geometry, double precision)
COMMENT FUNCTION st_dfullywithin(rast1 raster, nband1 integer, rast2 raster, nband2 integer, distance double precision)
COMMENT FUNCTION st_dfullywithin(rast1 raster, rast2 raster, distance double precision)
COMMENT FUNCTION st_difference(geom1 geometry, geom2 geometry)
COMMENT FUNCTION st_difference(geom1 geometry, geom2 geometry, gridsize double precision)
COMMENT FUNCTION st_dimension(geometry)
COMMENT FUNCTION st_disjoint(geom1 geometry, geom2 geometry)
COMMENT FUNCTION st_disjoint(rast1 raster, nband1 integer, rast2 raster, nband2 integer)
COMMENT FUNCTION st_disjoint(rast1 raster, rast2 raster)
COMMENT FUNCTION st_distance(geog1 geography, geog2 geography, use_spheroid boolean)
COMMENT FUNCTION st_distance(geography, geography)
COMMENT FUNCTION st_distance(geography, geography, double precision, boolean)
COMMENT FUNCTION st_distance(geom1 geometry, geom2 geometry)
COMMENT FUNCTION st_distance(text, text)
COMMENT FUNCTION st_distance_sphere(geom1 geometry, geom2 geometry)
COMMENT FUNCTION st_distance_sphere(geometry, geometry)
COMMENT FUNCTION st_distance_spheroid(geom1 geometry, geom2 geometry, spheroid)
COMMENT FUNCTION st_distance_spheroid(geometry, geometry, spheroid)
COMMENT FUNCTION st_distancecpa(geometry, geometry)
COMMENT FUNCTION st_distancesphere(geom1 geometry, geom2 geometry)
COMMENT FUNCTION st_distancesphere(geom1 geometry, geom2 geometry, radius double precision)
COMMENT FUNCTION st_distancespheroid(geom1 geometry, geom2 geometry)
COMMENT FUNCTION st_distancespheroid(geom1 geometry, geom2 geometry, spheroid)
COMMENT FUNCTION st_distinct4ma(matrix double precision[], nodatamode text, VARIADIC args text[])
COMMENT FUNCTION st_distinct4ma(matrix float[][], nodatamode text, variadic args text[])
COMMENT FUNCTION st_distinct4ma(value double precision[], pos integer[], VARIADIC userargs text[])
COMMENT FUNCTION st_distinct4ma(value double precision[][][], pos integer[][], variadic userargs text[])
COMMENT FUNCTION st_dropbbox(geometry)
COMMENT FUNCTION st_dump(geometry)
COMMENT FUNCTION st_dumpaspolygons(rast raster, band integer, exclude_nodata_value boolean)
COMMENT FUNCTION st_dumpaspolygons(raster)
COMMENT FUNCTION st_dumpaspolygons(raster, integer)
COMMENT FUNCTION st_dumppoints(geometry)
COMMENT FUNCTION st_dumprings(geometry)
COMMENT FUNCTION st_dumpsegments(geometry)
COMMENT FUNCTION st_dumpvalues(rast raster, nband integer, exclude_nodata_value boolean)
COMMENT FUNCTION st_dumpvalues(rast raster, nband integer[], exclude_nodata_value boolean)
COMMENT FUNCTION st_dwithin(geog1 geography, geog2 geography, tolerance double precision, use_spheroid boolean)
COMMENT FUNCTION st_dwithin(geom1 geometry, geom2 geometry, double precision)
COMMENT FUNCTION st_dwithin(rast1 raster, nband1 integer, rast2 raster, nband2 integer, distance double precision)
COMMENT FUNCTION st_dwithin(rast1 raster, rast2 raster, distance double precision)
COMMENT FUNCTION st_dwithin(text, text, double precision)
COMMENT FUNCTION st_endpoint(geometry)
COMMENT FUNCTION st_envelope(geometry)
COMMENT FUNCTION st_envelope(raster)
COMMENT FUNCTION st_equals(geom1 geometry, geom2 geometry)
COMMENT FUNCTION st_estimated_extent(text, text)
COMMENT FUNCTION st_estimated_extent(text, text, text)
COMMENT FUNCTION st_estimatedextent(text, text)
COMMENT FUNCTION st_estimatedextent(text, text, text)
COMMENT FUNCTION st_estimatedextent(text, text, text, boolean)
COMMENT FUNCTION st_expand(box box2d, dx double precision, dy double precision)
COMMENT FUNCTION st_expand(box box3d, dx double precision, dy double precision, dz double precision)
COMMENT FUNCTION st_expand(box2d, double precision)
COMMENT FUNCTION st_expand(box3d, double precision)
COMMENT FUNCTION st_expand(geom geometry, dx double precision, dy double precision, dz double precision, dm double precision)
COMMENT FUNCTION st_expand(geometry, double precision)
COMMENT FUNCTION st_exteriorring(geometry)
COMMENT FUNCTION st_extrude(geometry, double precision, double precision, double precision)
COMMENT FUNCTION st_filterbym(geometry, double precision, double precision, boolean)
COMMENT FUNCTION st_find_extent(text, text)
COMMENT FUNCTION st_find_extent(text, text, text)
COMMENT FUNCTION st_findextent(text, text)
COMMENT FUNCTION st_findextent(text, text, text)
COMMENT FUNCTION st_flipcoordinates(geometry)
COMMENT FUNCTION st_force2d(geometry)
COMMENT FUNCTION st_force3d(geom geometry, zvalue double precision)
COMMENT FUNCTION st_force3dm(geom geometry, mvalue double precision)
COMMENT FUNCTION st_force3dz(geom geometry, zvalue double precision)
COMMENT FUNCTION st_force4d(geom geometry, zvalue double precision, mvalue double precision)
COMMENT FUNCTION st_force_2d(geometry)
COMMENT FUNCTION st_force_3d(geometry)
COMMENT FUNCTION st_force_3dm(geometry)
COMMENT FUNCTION st_force_3dz(geometry)
COMMENT FUNCTION st_force_4d(geometry)
COMMENT FUNCTION st_force_collection(geometry)
COMMENT FUNCTION st_forcecollection(geometry)
COMMENT FUNCTION st_forcecurve(geometry)
COMMENT FUNCTION st_forcelhr(geometry)
COMMENT FUNCTION st_forcepolygonccw(geometry)
COMMENT FUNCTION st_forcepolygoncw(geometry)
COMMENT FUNCTION st_forcerhr(geometry)
COMMENT FUNCTION st_forcesfs(geometry)
COMMENT FUNCTION st_forcesfs(geometry, version text)
COMMENT FUNCTION st_frechetdistance(geom1 geometry, geom2 geometry, double precision)
COMMENT FUNCTION st_fromflatgeobuf(anyelement, bytea)
COMMENT FUNCTION st_fromflatgeobuftotable(text, text, bytea)
COMMENT FUNCTION st_fromgdalraster(gdaldata bytea, srid integer)
COMMENT FUNCTION st_gdaldrivers()
COMMENT FUNCTION st_gdaldrivers(OUT idx integer, OUT short_name text, OUT long_name text, OUT can_read boolean, OUT can_write boolean, OUT create_options text)
COMMENT FUNCTION st_gdaldrivers(out idx integer, out short_name text, out long_name text, out can_read boolean, out can_write boolean, out create_options text)
COMMENT FUNCTION st_gdalopenoptions(opts text[])
COMMENT FUNCTION st_generatepoints(area geometry, npoints integer)
COMMENT FUNCTION st_generatepoints(area geometry, npoints integer, seed integer)
COMMENT FUNCTION st_generatepoints(geometry, numeric)
COMMENT FUNCTION st_geogfromtext(text)
COMMENT FUNCTION st_geogfromwkb(bytea)
COMMENT FUNCTION st_geographyfromtext(text)
COMMENT FUNCTION st_geohash(geog geography, maxchars integer)
COMMENT FUNCTION st_geohash(geom geometry, maxchars integer)
COMMENT FUNCTION st_geohash(geometry)
COMMENT FUNCTION st_geom_accum(geometry[], geometry)
COMMENT FUNCTION st_geomcollfromtext(text)
COMMENT FUNCTION st_geomcollfromtext(text, integer)
COMMENT FUNCTION st_geomcollfromwkb(bytea)
COMMENT FUNCTION st_geomcollfromwkb(bytea, integer)
COMMENT FUNCTION st_geometricmedian(g geometry, tolerance double precision, max_iter integer, fail_if_not_converged boolean)
COMMENT FUNCTION st_geometry(box2d)
COMMENT FUNCTION st_geometry(box3d)
COMMENT FUNCTION st_geometry(bytea)
COMMENT FUNCTION st_geometry(text)
COMMENT FUNCTION st_geometry_analyze(internal)
COMMENT FUNCTION st_geometry_cmp(geometry, geometry)
COMMENT FUNCTION st_geometry_eq(geometry, geometry)
COMMENT FUNCTION st_geometry_ge(geometry, geometry)
COMMENT FUNCTION st_geometry_gt(geometry, geometry)
COMMENT FUNCTION st_geometry_in(cstring)
COMMENT FUNCTION st_geometry_le(geometry, geometry)
COMMENT FUNCTION st_geometry_lt(geometry, geometry)
COMMENT FUNCTION st_geometry_out(geometry)
COMMENT FUNCTION st_geometry_recv(internal)
COMMENT FUNCTION st_geometry_send(geometry)
COMMENT FUNCTION st_geometryfromtext(text)
COMMENT FUNCTION st_geometryfromtext(text, integer)
COMMENT FUNCTION st_geometryn(geometry, integer)
COMMENT FUNCTION st_geometrytype(geometry)
COMMENT FUNCTION st_geometrytype(tg topogeometry)
COMMENT FUNCTION st_geomfromewkb(bytea)
COMMENT FUNCTION st_geomfromewkt(text)
COMMENT FUNCTION st_geomfromgeohash(text, integer)
COMMENT FUNCTION st_geomfromgeojson(json)
COMMENT FUNCTION st_geomfromgeojson(jsonb)
COMMENT FUNCTION st_geomfromgeojson(text)
COMMENT FUNCTION st_geomfromgml(text)
COMMENT FUNCTION st_geomfromgml(text, integer)
COMMENT FUNCTION st_geomfromkml(text)
COMMENT FUNCTION st_geomfrommarc21(marc21xml text)
COMMENT FUNCTION st_geomfromtext(text)
COMMENT FUNCTION st_geomfromtext(text, integer)
COMMENT FUNCTION st_geomfromtwkb(bytea)
COMMENT FUNCTION st_geomfromwkb(bytea)
COMMENT FUNCTION st_geomfromwkb(bytea, integer)
COMMENT FUNCTION st_georeference(rast raster, format text)
COMMENT FUNCTION st_georeference(raster)
COMMENT FUNCTION st_georeference(raster, text)
COMMENT FUNCTION st_geotransform(raster, out imag double precision, out jmag double precision, out theta_i double precision, out theta_ij double precision, out xoffset double precision, out yoffset double precision)
COMMENT FUNCTION st_getfaceedges(toponame character varying, face_id integer)
COMMENT FUNCTION st_getfacegeometry(toponame character varying, aface integer)
COMMENT FUNCTION st_gmltosql(text)
COMMENT FUNCTION st_gmltosql(text, integer)
COMMENT FUNCTION st_grayscale(rast raster, redband integer, greenband integer, blueband integer, extenttype text)
COMMENT FUNCTION st_grayscale(rastbandargset rastbandarg[], extenttype text)
COMMENT FUNCTION st_hasarc(geometry geometry)
COMMENT FUNCTION st_hasbbox(geometry)
COMMENT FUNCTION st_hasnoband(rast raster, nband integer)
COMMENT FUNCTION st_hasnoband(raster)
COMMENT FUNCTION st_hausdorffdistance(geom1 geometry, geom2 geometry)
COMMENT FUNCTION st_hausdorffdistance(geom1 geometry, geom2 geometry, double precision)
COMMENT FUNCTION st_height(raster)
COMMENT FUNCTION st_hexagon(size double precision, cell_i integer, cell_j integer, origin geometry)
COMMENT FUNCTION st_hexagongrid(size double precision, bounds geometry, OUT geom geometry, OUT i integer, OUT j integer)
COMMENT FUNCTION st_hexagongrid(size double precision, bounds geometry, out geom geometry, out i integer, out j integer)
COMMENT FUNCTION st_hillshade(rast raster, nband integer, customextent raster, pixeltype text, azimuth double precision, altitude double precision, max_bright double precision, scale double precision, interpolate_nodata boolean)
COMMENT FUNCTION st_hillshade(rast raster, nband integer, pixeltype text, azimuth double precision, altitude double precision, max_bright double precision, scale double precision, interpolate_nodata boolean)
COMMENT FUNCTION st_hillshade(raster, integer, text, double precision, double precision, double precision, double precision, boolean)
COMMENT FUNCTION st_hillshade(raster, integer, text, float, float, float, float)
COMMENT FUNCTION st_hillshade(raster, integer, text, float, float, float, float, boolean)
COMMENT FUNCTION st_histogram(ext, text, integer, integer, boolean)
COMMENT FUNCTION st_histogram(rast raster, nband integer, bins integer, "right" boolean, OUT min double precision, OUT max double precision, OUT count bigint, OUT percent double precision)
COMMENT FUNCTION st_histogram(rast raster, nband integer, bins integer, right boolean, out min double precision, out max double precision, out count bigint, out percent double precision)
COMMENT FUNCTION st_histogram(rast raster, nband integer, bins integer, width double precision[], "right" boolean, OUT min double precision, OUT max double precision, OUT count bigint, OUT percent double precision)
COMMENT FUNCTION st_histogram(rast raster, nband integer, bins integer, width double precision[], right boolean, out min double precision, out max double precision, out count bigint, out percent double precision)
COMMENT FUNCTION st_histogram(rast raster, nband integer, exclude_nodata_value boolean, bins integer, "right" boolean, OUT min double precision, OUT max double precision, OUT count bigint, OUT percent double precision)
COMMENT FUNCTION st_histogram(rast raster, nband integer, exclude_nodata_value boolean, bins integer, right boolean, out min double precision, out max double precision, out count bigint, out percent double precision)
COMMENT FUNCTION st_histogram(rast raster, nband integer, exclude_nodata_value boolean, bins integer, width double precision[], "right" boolean, OUT min double precision, OUT max double precision, OUT count bigint, OUT percent double precision)
COMMENT FUNCTION st_histogram(rast raster, nband integer, exclude_nodata_value boolean, bins integer, width double precision[], right boolean, out min double precision, out max double precision, out count bigint, out percent double precision)
COMMENT FUNCTION st_histogram(raster, integer, boolean, integer, boolean)
COMMENT FUNCTION st_histogram(raster, integer, boolean, integer, double precision[], boolean)
COMMENT FUNCTION st_histogram(raster, integer, integer, boolean)
COMMENT FUNCTION st_histogram(raster, integer, integer, double precision[], boolean)
COMMENT FUNCTION st_histogram(text, text, integer, boolean, integer, boolean)
COMMENT FUNCTION st_histogram(text, text, integer, boolean, integer, double precision[], boolean)
COMMENT FUNCTION st_histogram(text, text, integer, integer, boolean)
COMMENT FUNCTION st_histogram(text, text, integer, integer, double precision[], boolean)
COMMENT FUNCTION st_inittopogeo(atopology character varying)
COMMENT FUNCTION st_interiorringn(geometry, integer)
COMMENT FUNCTION st_interpolatepoint(line geometry, point geometry)
COMMENT FUNCTION st_interpolateraster(geom geometry, options text, rast raster, bandnumber integer)
COMMENT FUNCTION st_intersection(geography, geography)
COMMENT FUNCTION st_intersection(geom1 geometry, geom2 geometry)
COMMENT FUNCTION st_intersection(geom1 geometry, geom2 geometry, gridsize double precision)
COMMENT FUNCTION st_intersection(geometry, raster)
COMMENT FUNCTION st_intersection(geomin geometry, rast raster, band integer)
COMMENT FUNCTION st_intersection(rast raster, band integer, geomin geometry)
COMMENT FUNCTION st_intersection(rast raster, geomin geometry)
COMMENT FUNCTION st_intersection(rast1 raster, band1 integer, rast2 raster, band2 integer, nodataval double precision)
COMMENT FUNCTION st_intersection(rast1 raster, band1 integer, rast2 raster, band2 integer, nodataval double precision[])
COMMENT FUNCTION st_intersection(rast1 raster, band1 integer, rast2 raster, band2 integer, returnband text, nodataval double precision)
COMMENT FUNCTION st_intersection(rast1 raster, band1 integer, rast2 raster, band2 integer, returnband text, nodataval double precision[])
COMMENT FUNCTION st_intersection(rast1 raster, rast2 raster, nodataval double precision)
COMMENT FUNCTION st_intersection(rast1 raster, rast2 raster, nodataval double precision[])
COMMENT FUNCTION st_intersection(rast1 raster, rast2 raster, returnband text, nodataval double precision)
COMMENT FUNCTION st_intersection(rast1 raster, rast2 raster, returnband text, nodataval double precision[])
COMMENT FUNCTION st_intersection(raster, geometry)
COMMENT FUNCTION st_intersection(raster, geometry, regprocedure)
COMMENT FUNCTION st_intersection(raster, geometry, text, regprocedure)
COMMENT FUNCTION st_intersection(raster, integer, geometry)
COMMENT FUNCTION st_intersection(raster, integer, geometry, regprocedure)
COMMENT FUNCTION st_intersection(raster, integer, geometry, text, regprocedure)
COMMENT FUNCTION st_intersection(raster, integer, raster, integer, regprocedure)
COMMENT FUNCTION st_intersection(raster, integer, raster, integer, text, regprocedure)
COMMENT FUNCTION st_intersection(raster, raster, integer, integer)
COMMENT FUNCTION st_intersection(raster, raster, regprocedure)
COMMENT FUNCTION st_intersection(raster, raster, text, regprocedure)
COMMENT FUNCTION st_intersection(text, text)
COMMENT FUNCTION st_intersects(geog1 geography, geog2 geography)
COMMENT FUNCTION st_intersects(geom geometry, rast raster, nband integer)
COMMENT FUNCTION st_intersects(geom1 geometry, geom2 geometry)
COMMENT FUNCTION st_intersects(geometry, raster)
COMMENT FUNCTION st_intersects(geometry, raster, boolean)
COMMENT FUNCTION st_intersects(geometry, raster, integer)
COMMENT FUNCTION st_intersects(geometry, raster, integer, boolean)
COMMENT FUNCTION st_intersects(rast raster, geom geometry, nband integer)
COMMENT FUNCTION st_intersects(rast raster, nband integer, geom geometry)
COMMENT FUNCTION st_intersects(rast1 raster, nband1 integer, rast2 raster, nband2 integer)
COMMENT FUNCTION st_intersects(rast1 raster, rast2 raster)
COMMENT FUNCTION st_intersects(raster, boolean, geometry)
COMMENT FUNCTION st_intersects(raster, geometry)
COMMENT FUNCTION st_intersects(raster, geometry, integer)
COMMENT FUNCTION st_intersects(raster, integer, boolean, geometry)
COMMENT FUNCTION st_intersects(raster, integer, geometry)
COMMENT FUNCTION st_intersects(raster, integer, raster, integer)
COMMENT FUNCTION st_intersects(raster, raster)
COMMENT FUNCTION st_intersects(text, text)
COMMENT FUNCTION st_invdistweight4ma(value double precision[], pos integer[], VARIADIC userargs text[])
COMMENT FUNCTION st_invdistweight4ma(value double precision[][][], pos integer[][], variadic userargs text[])
COMMENT FUNCTION st_inversetransformpipeline(geom geometry, pipeline text, to_srid integer)
COMMENT FUNCTION st_isclosed(geometry)
COMMENT FUNCTION st_iscollection(geometry)
COMMENT FUNCTION st_iscoveragetile(rast raster, coverage raster, tilewidth integer, tileheight integer)
COMMENT FUNCTION st_isempty(geometry)
COMMENT FUNCTION st_isempty(rast raster)
COMMENT FUNCTION st_isplanar(geometry)
COMMENT FUNCTION st_ispolygonccw(geometry)
COMMENT FUNCTION st_ispolygoncw(geometry)
COMMENT FUNCTION st_isring(geometry)
COMMENT FUNCTION st_issimple(geometry)
COMMENT FUNCTION st_issolid(geometry)
COMMENT FUNCTION st_isvalid(geometry)
COMMENT FUNCTION st_isvalid(geometry, integer)
COMMENT FUNCTION st_isvaliddetail(geom geometry, flags integer)
COMMENT FUNCTION st_isvaliddetail(geometry)
COMMENT FUNCTION st_isvalidreason(geometry)
COMMENT FUNCTION st_isvalidreason(geometry, integer)
COMMENT FUNCTION st_isvalidtrajectory(geometry)
COMMENT FUNCTION st_largestemptycircle(geom geometry, tolerance double precision, boundary geometry, out center geometry, out nearest geometry, out radius double precision)
COMMENT FUNCTION st_left(raster, raster)
COMMENT FUNCTION st_length(geog geography, use_spheroid boolean)
COMMENT FUNCTION st_length(geography)
COMMENT FUNCTION st_length(geometry)
COMMENT FUNCTION st_length(text)
COMMENT FUNCTION st_length2d(geometry)
COMMENT FUNCTION st_length2d_spheroid(geometry, spheroid)
COMMENT FUNCTION st_length2dspheroid(geometry, spheroid)
COMMENT FUNCTION st_length3d(geometry)
COMMENT FUNCTION st_length_spheroid(geometry, spheroid)
COMMENT FUNCTION st_length_spheroid3d(geometry, spheroid)
COMMENT FUNCTION st_lengthspheroid(geometry, spheroid)
COMMENT FUNCTION st_letters(letters text, font json)
COMMENT FUNCTION st_line_interpolate_point(geometry, double precision)
COMMENT FUNCTION st_line_locate_point(geom1 geometry, geom2 geometry)
COMMENT FUNCTION st_line_locate_point(geometry, geometry)
COMMENT FUNCTION st_line_substring(geometry, double precision, double precision)
COMMENT FUNCTION st_linecrossingdirection(line1 geometry, line2 geometry)
COMMENT FUNCTION st_lineextend(geom geometry, distance_forward double precision, distance_backward double precision)
COMMENT FUNCTION st_linefromencodedpolyline(txtin text, nprecision integer)
COMMENT FUNCTION st_linefrommultipoint(geometry)
COMMENT FUNCTION st_linefromtext(text)
COMMENT FUNCTION st_linefromtext(text, integer)
COMMENT FUNCTION st_linefromwkb(bytea)
COMMENT FUNCTION st_linefromwkb(bytea, integer)
COMMENT FUNCTION st_lineinterpolatepoint(geography, double precision, use_spheroid boolean)
COMMENT FUNCTION st_lineinterpolatepoint(geometry, double precision)
COMMENT FUNCTION st_lineinterpolatepoint(text, double precision)
COMMENT FUNCTION st_lineinterpolatepoints(geography, double precision, use_spheroid boolean, repeat boolean)
COMMENT FUNCTION st_lineinterpolatepoints(geometry, double precision, repeat boolean)
COMMENT FUNCTION st_lineinterpolatepoints(text, double precision)
COMMENT FUNCTION st_linelocatepoint(geography, geography, use_spheroid boolean)
COMMENT FUNCTION st_linelocatepoint(geom1 geometry, geom2 geometry)
COMMENT FUNCTION st_linelocatepoint(text, text)
COMMENT FUNCTION st_linemerge(geometry)
COMMENT FUNCTION st_linemerge(geometry, boolean)
COMMENT FUNCTION st_linestringfromwkb(bytea)
COMMENT FUNCTION st_linestringfromwkb(bytea, integer)
COMMENT FUNCTION st_linesubstring(geography, double precision, double precision)
COMMENT FUNCTION st_linesubstring(geometry, double precision, double precision)
COMMENT FUNCTION st_linesubstring(text, double precision, double precision)
COMMENT FUNCTION st_linetocurve(geometry geometry)
COMMENT FUNCTION st_locate_along_measure(geometry, double precision)
COMMENT FUNCTION st_locate_between_measures(geometry, double precision, double precision)
COMMENT FUNCTION st_locatealong(geometry geometry, measure double precision, leftrightoffset double precision)
COMMENT FUNCTION st_locatebetween(geometry geometry, frommeasure double precision, tomeasure double precision, leftrightoffset double precision)
COMMENT FUNCTION st_locatebetweenelevations(geometry geometry, fromelevation double precision, toelevation double precision)
COMMENT FUNCTION st_longestline(geom1 geometry, geom2 geometry)
COMMENT FUNCTION st_m(geometry)
COMMENT FUNCTION st_makebox2d(geom1 geometry, geom2 geometry)
COMMENT FUNCTION st_makebox3d(geometry, geometry)
COMMENT FUNCTION st_makeemptycoverage(tilewidth integer, tileheight integer, width integer, height integer, upperleftx double precision, upperlefty double precision, scalex double precision, scaley double precision, skewx double precision, skewy double precision, srid integer)
COMMENT FUNCTION st_makeemptyraster(integer, integer, double precision, double precision, double precision, double precision, double precision, double precision)
COMMENT FUNCTION st_makeemptyraster(integer, integer, double precision, double precision, double precision, double precision, double precision, double precision, integer)
COMMENT FUNCTION st_makeemptyraster(rast raster)
COMMENT FUNCTION st_makeemptyraster(width integer, height integer, upperleftx double precision, upperlefty double precision, pixelsize double precision)
COMMENT FUNCTION st_makeemptyraster(width integer, height integer, upperleftx double precision, upperlefty double precision, scalex double precision, scaley double precision, skewx double precision, skewy double precision, srid integer)
COMMENT FUNCTION st_makeenvelope(double precision, double precision, double precision, double precision, integer)
COMMENT FUNCTION st_makeline(geom1 geometry, geom2 geometry)
COMMENT FUNCTION st_makeline(geometry[])
COMMENT FUNCTION st_makeline_garray(geometry[])
COMMENT FUNCTION st_makepoint(double precision, double precision)
COMMENT FUNCTION st_makepoint(double precision, double precision, double precision)
COMMENT FUNCTION st_makepoint(double precision, double precision, double precision, double precision)
COMMENT FUNCTION st_makepointm(double precision, double precision, double precision)
COMMENT FUNCTION st_makepolygon(geometry)
COMMENT FUNCTION st_makepolygon(geometry, geometry[])
COMMENT FUNCTION st_makesolid(geometry)
COMMENT FUNCTION st_makevalid(geom geometry, params text)
COMMENT FUNCTION st_makevalid(geometry)
COMMENT FUNCTION st_mapalgebra(rast raster, nband integer, callbackfunc regprocedure, mask double precision [][], weighted boolean, pixeltype text, extenttype text, customextent raster, variadic userargs text[])
COMMENT FUNCTION st_mapalgebra(rast raster, nband integer, callbackfunc regprocedure, mask double precision[], weighted boolean, pixeltype text, extenttype text, customextent raster, VARIADIC userargs text[])
COMMENT FUNCTION st_mapalgebra(rast raster, nband integer, callbackfunc regprocedure, pixeltype text, extenttype text, customextent raster, distancex integer, distancey integer, VARIADIC userargs text[])
COMMENT FUNCTION st_mapalgebra(rast raster, nband integer, callbackfunc regprocedure, pixeltype text, extenttype text, customextent raster, distancex integer, distancey integer, variadic userargs text[])
COMMENT FUNCTION st_mapalgebra(rast raster, nband integer, pixeltype text, expression text, nodataval double precision)
COMMENT FUNCTION st_mapalgebra(rast raster, nband integer[], callbackfunc regprocedure, pixeltype text, extenttype text, customextent raster, distancex integer, distancey integer, VARIADIC userargs text[])
COMMENT FUNCTION st_mapalgebra(rast raster, nband integer[], callbackfunc regprocedure, pixeltype text, extenttype text, customextent raster, distancex integer, distancey integer, variadic userargs text[])
COMMENT FUNCTION st_mapalgebra(rast raster, pixeltype text, expression text, nodataval double precision)
COMMENT FUNCTION st_mapalgebra(rast1 raster, band1 integer, rast2 raster, band2 integer, expression text, pixeltype text, extenttype text, nodata1expr text, nodata2expr text, nodatanodataval double precision)
COMMENT FUNCTION st_mapalgebra(rast1 raster, nband1 integer, rast2 raster, nband2 integer, callbackfunc regprocedure, pixeltype text, extenttype text, customextent raster, distancex integer, distancey integer, VARIADIC userargs text[])
COMMENT FUNCTION st_mapalgebra(rast1 raster, nband1 integer, rast2 raster, nband2 integer, callbackfunc regprocedure, pixeltype text, extenttype text, customextent raster, distancex integer, distancey integer, variadic userargs text[])
COMMENT FUNCTION st_mapalgebra(rast1 raster, rast2 raster, expression text, pixeltype text, extenttype text, nodata1expr text, nodata2expr text, nodatanodataval double precision)
COMMENT FUNCTION st_mapalgebra(rastbandargset rastbandarg[], callbackfunc regprocedure, pixeltype text, extenttype text, customextent raster, distancex integer, distancey integer, VARIADIC userargs text[])
COMMENT FUNCTION st_mapalgebra(rastbandargset rastbandarg[], callbackfunc regprocedure, pixeltype text, extenttype text, customextent raster, distancex integer, distancey integer, variadic userargs text[])
COMMENT FUNCTION st_mapalgebra(raster, integer, text, text, nodatavaluerepl text)
COMMENT FUNCTION st_mapalgebra(raster, pixeltype text, expression text, nodatavaluerepl text)
COMMENT FUNCTION st_mapalgebraexpr(rast raster, band integer, pixeltype text, expression text, nodataval double precision)
COMMENT FUNCTION st_mapalgebraexpr(rast raster, pixeltype text, expression text, nodataval double precision)
COMMENT FUNCTION st_mapalgebraexpr(rast1 raster, band1 integer, rast2 raster, band2 integer, expression text, pixeltype text, extenttype text, nodata1expr text, nodata2expr text, nodatanodataval double precision)
COMMENT FUNCTION st_mapalgebraexpr(rast1 raster, rast2 raster, expression text, pixeltype text, extenttype text, nodata1expr text, nodata2expr text, nodatanodataval double precision)
COMMENT FUNCTION st_mapalgebraexpr(raster, integer, text, text, text)
COMMENT FUNCTION st_mapalgebraexpr(raster, text, text, text)
COMMENT FUNCTION st_mapalgebrafct(rast raster, band integer, onerastuserfunc regprocedure)
COMMENT FUNCTION st_mapalgebrafct(rast raster, band integer, onerastuserfunc regprocedure, VARIADIC args text[])
COMMENT FUNCTION st_mapalgebrafct(rast raster, band integer, onerastuserfunc regprocedure, variadic args text[])
COMMENT FUNCTION st_mapalgebrafct(rast raster, band integer, pixeltype text, onerastuserfunc regprocedure)
COMMENT FUNCTION st_mapalgebrafct(rast raster, band integer, pixeltype text, onerastuserfunc regprocedure, VARIADIC args text[])
COMMENT FUNCTION st_mapalgebrafct(rast raster, band integer, pixeltype text, onerastuserfunc regprocedure, variadic args text[])
COMMENT FUNCTION st_mapalgebrafct(rast raster, onerastuserfunc regprocedure)
COMMENT FUNCTION st_mapalgebrafct(rast raster, onerastuserfunc regprocedure, VARIADIC args text[])
COMMENT FUNCTION st_mapalgebrafct(rast raster, onerastuserfunc regprocedure, variadic args text[])
COMMENT FUNCTION st_mapalgebrafct(rast raster, pixeltype text, onerastuserfunc regprocedure)
COMMENT FUNCTION st_mapalgebrafct(rast raster, pixeltype text, onerastuserfunc regprocedure, VARIADIC args text[])
COMMENT FUNCTION st_mapalgebrafct(rast raster, pixeltype text, onerastuserfunc regprocedure, variadic args text[])
COMMENT FUNCTION st_mapalgebrafct(rast1 raster, band1 integer, rast2 raster, band2 integer, tworastuserfunc regprocedure, pixeltype text, extenttype text, VARIADIC userargs text[])
COMMENT FUNCTION st_mapalgebrafct(rast1 raster, band1 integer, rast2 raster, band2 integer, tworastuserfunc regprocedure, pixeltype text, extenttype text, variadic userargs text[])
COMMENT FUNCTION st_mapalgebrafct(rast1 raster, rast2 raster, tworastuserfunc regprocedure, pixeltype text, extenttype text, VARIADIC userargs text[])
COMMENT FUNCTION st_mapalgebrafct(rast1 raster, rast2 raster, tworastuserfunc regprocedure, pixeltype text, extenttype text, variadic userargs text[])
COMMENT FUNCTION st_mapalgebrafct(raster, integer, raster, integer, regprocedure, text, text, variadic text[])
COMMENT FUNCTION st_mapalgebrafct(raster, integer, regprocedure)
COMMENT FUNCTION st_mapalgebrafct(raster, integer, regprocedure, variadic text[])
COMMENT FUNCTION st_mapalgebrafct(raster, integer, text, regprocedure)
COMMENT FUNCTION st_mapalgebrafct(raster, integer, text, regprocedure, variadic text[])
COMMENT FUNCTION st_mapalgebrafct(raster, raster, regprocedure, text, text, variadic text[])
COMMENT FUNCTION st_mapalgebrafct(raster, raster, regprocedure, variadic text[])
COMMENT FUNCTION st_mapalgebrafct(raster, regprocedure)
COMMENT FUNCTION st_mapalgebrafct(raster, regprocedure, variadic text[])
COMMENT FUNCTION st_mapalgebrafct(raster, text, regprocedure)
COMMENT FUNCTION st_mapalgebrafct(raster, text, regprocedure, variadic text[])
COMMENT FUNCTION st_mapalgebrafctngb(rast raster, band integer, pixeltype text, ngbwidth integer, ngbheight integer, onerastngbuserfunc regprocedure, nodatamode text, VARIADIC args text[])
COMMENT FUNCTION st_mapalgebrafctngb(rast raster, band integer, pixeltype text, ngbwidth integer, ngbheight integer, onerastngbuserfunc regprocedure, nodatamode text, variadic args text[])
COMMENT FUNCTION st_mapalgebrafctngb(raster, integer, text, integer, integer, regprocedure, text, variadic text[])
COMMENT FUNCTION st_max4ma(matrix double precision[], nodatamode text, VARIADIC args text[])
COMMENT FUNCTION st_max4ma(matrix float[][], nodatamode text, variadic args text[])
COMMENT FUNCTION st_max4ma(value double precision[], pos integer[], VARIADIC userargs text[])
COMMENT FUNCTION st_max4ma(value double precision[][][], pos integer[][], variadic userargs text[])
COMMENT FUNCTION st_max_distance(geometry, geometry)
COMMENT FUNCTION st_maxdistance(geom1 geometry, geom2 geometry)
COMMENT FUNCTION st_maximuminscribedcircle(geometry, OUT center geometry, OUT nearest geometry, OUT radius double precision)
COMMENT FUNCTION st_maximuminscribedcircle(geometry, out center geometry, out nearest geometry, out radius double precision)
COMMENT FUNCTION st_mean4ma(matrix double precision[], nodatamode text, VARIADIC args text[])
COMMENT FUNCTION st_mean4ma(matrix float[][], nodatamode text, variadic args text[])
COMMENT FUNCTION st_mean4ma(value double precision[], pos integer[], VARIADIC userargs text[])
COMMENT FUNCTION st_mean4ma(value double precision[][][], pos integer[][], variadic userargs text[])
COMMENT FUNCTION st_mem_size(geometry)
COMMENT FUNCTION st_memsize(geometry)
COMMENT FUNCTION st_memsize(raster)
COMMENT FUNCTION st_metadata(rast raster, OUT upperleftx double precision, OUT upperlefty double precision, OUT width integer, OUT height integer, OUT scalex double precision, OUT scaley double precision, OUT skewx double precision, OUT skewy double precision, OUT srid integer, OUT numbands integer)
COMMENT FUNCTION st_metadata(rast raster, out upperleftx double precision, out upperlefty double precision, out width integer, out height integer, out scalex double precision, out scaley double precision, out skewx double precision, out skewy double precision, out srid integer, out numbands integer)
COMMENT FUNCTION st_min4ma(matrix double precision[], nodatamode text, VARIADIC args text[])
COMMENT FUNCTION st_min4ma(matrix float[][], nodatamode text, variadic args text[])
COMMENT FUNCTION st_min4ma(value double precision[], pos integer[], VARIADIC userargs text[])
COMMENT FUNCTION st_min4ma(value double precision[][][], pos integer[][], variadic userargs text[])
COMMENT FUNCTION st_minconvexhull(rast raster, nband integer)
COMMENT FUNCTION st_mindist4ma(value double precision[], pos integer[], VARIADIC userargs text[])
COMMENT FUNCTION st_mindist4ma(value double precision[][][], pos integer[][], variadic userargs text[])
COMMENT FUNCTION st_minimumboundingcircle(geometry)
COMMENT FUNCTION st_minimumboundingcircle(inputgeom geometry, segs_per_quarter integer)
COMMENT FUNCTION st_minimumboundingradius(geometry, OUT center geometry, OUT radius double precision)
COMMENT FUNCTION st_minimumboundingradius(geometry, out center geometry, out radius double precision)
COMMENT FUNCTION st_minimumclearance(geometry)
COMMENT FUNCTION st_minimumclearanceline(geometry)
COMMENT FUNCTION st_minkowskisum(geometry, geometry)
COMMENT FUNCTION st_minpossibleval(text)
COMMENT FUNCTION st_minpossiblevalue(pixeltype text)
COMMENT FUNCTION st_mlinefromtext(text)
COMMENT FUNCTION st_mlinefromtext(text, integer)
COMMENT FUNCTION st_mlinefromwkb(bytea)
COMMENT FUNCTION st_mlinefromwkb(bytea, integer)
COMMENT FUNCTION st_modedgeheal(toponame character varying, e1id integer, e2id integer)
COMMENT FUNCTION st_modedgesplit(atopology character varying, anedge integer, apoint geometry)
COMMENT FUNCTION st_moveisonode(atopology character varying, anode integer, apoint geometry)
COMMENT FUNCTION st_mpointfromtext(text)
COMMENT FUNCTION st_mpointfromtext(text, integer)
COMMENT FUNCTION st_mpointfromwkb(bytea)
COMMENT FUNCTION st_mpointfromwkb(bytea, integer)
COMMENT FUNCTION st_mpolyfromtext(text)
COMMENT FUNCTION st_mpolyfromtext(text, integer)
COMMENT FUNCTION st_mpolyfromwkb(bytea)
COMMENT FUNCTION st_mpolyfromwkb(bytea, integer)
COMMENT FUNCTION st_multi(geometry)
COMMENT FUNCTION st_multilinefromwkb(bytea)
COMMENT FUNCTION st_multilinestringfromtext(text)
COMMENT FUNCTION st_multilinestringfromtext(text, integer)
COMMENT FUNCTION st_multipointfromtext(text)
COMMENT FUNCTION st_multipointfromwkb(bytea)
COMMENT FUNCTION st_multipointfromwkb(bytea, integer)
COMMENT FUNCTION st_multipolyfromwkb(bytea)
COMMENT FUNCTION st_multipolyfromwkb(bytea, integer)
COMMENT FUNCTION st_multipolygonfromtext(text)
COMMENT FUNCTION st_multipolygonfromtext(text, integer)
COMMENT FUNCTION st_ndims(geometry)
COMMENT FUNCTION st_nearestvalue(rast raster, band integer, columnx integer, rowy integer, exclude_nodata_value boolean)
COMMENT FUNCTION st_nearestvalue(rast raster, band integer, pt geometry, exclude_nodata_value boolean)
COMMENT FUNCTION st_nearestvalue(rast raster, columnx integer, rowy integer, exclude_nodata_value boolean)
COMMENT FUNCTION st_nearestvalue(rast raster, pt geometry, exclude_nodata_value boolean)
COMMENT FUNCTION st_nearestvalue(raster, integer, integer, boolean)
COMMENT FUNCTION st_nearestvalue(raster, integer, integer, integer, boolean)
COMMENT FUNCTION st_neighborhood(rast raster, band integer, columnx integer, rowy integer, distancex integer, distancey integer, exclude_nodata_value boolean)
COMMENT FUNCTION st_neighborhood(rast raster, band integer, pt geometry, distancex integer, distancey integer, exclude_nodata_value boolean)
COMMENT FUNCTION st_neighborhood(rast raster, columnx integer, rowy integer, distancex integer, distancey integer, exclude_nodata_value boolean)
COMMENT FUNCTION st_neighborhood(rast raster, pt geometry, distancex integer, distancey integer, exclude_nodata_value boolean)
COMMENT FUNCTION st_neighborhood(raster, geometry, integer, boolean)
COMMENT FUNCTION st_neighborhood(raster, integer, geometry, integer, boolean)
COMMENT FUNCTION st_neighborhood(raster, integer, integer, integer, boolean)
COMMENT FUNCTION st_neighborhood(raster, integer, integer, integer, integer, boolean)
COMMENT FUNCTION st_newedgeheal(toponame character varying, e1id integer, e2id integer)
COMMENT FUNCTION st_newedgessplit(atopology character varying, anedge integer, apoint geometry)
COMMENT FUNCTION st_node(g geometry)
COMMENT FUNCTION st_noop(geometry)
COMMENT FUNCTION st_normalize(geom geometry)
COMMENT FUNCTION st_notsamealignmentreason(rast1 raster, rast2 raster)
COMMENT FUNCTION st_npoints(geometry)
COMMENT FUNCTION st_nrings(geometry)
COMMENT FUNCTION st_numbands(raster)
COMMENT FUNCTION st_numgeometries(geometry)
COMMENT FUNCTION st_numinteriorring(geometry)
COMMENT FUNCTION st_numinteriorrings(geometry)
COMMENT FUNCTION st_numpatches(geometry)
COMMENT FUNCTION st_numpoints(geometry)
COMMENT FUNCTION st_offsetcurve(line geometry, distance double precision, params text)
COMMENT FUNCTION st_optimalalphashape(g1 geometry, allow_holes boolean, nb_components integer)
COMMENT FUNCTION st_orderingequals(geom1 geometry, geom2 geometry)
COMMENT FUNCTION st_orientation(geometry)
COMMENT FUNCTION st_orientedenvelope(geometry)
COMMENT FUNCTION st_overabove(raster, raster)
COMMENT FUNCTION st_overbelow(raster, raster)
COMMENT FUNCTION st_overlap(raster, raster)
COMMENT FUNCTION st_overlaps(geom1 geometry, geom2 geometry)
COMMENT FUNCTION st_overlaps(geometry, raster, integer)
COMMENT FUNCTION st_overlaps(rast1 raster, nband1 integer, rast2 raster, nband2 integer)
COMMENT FUNCTION st_overlaps(rast1 raster, rast2 raster)
COMMENT FUNCTION st_overlaps(raster, geometry, integer)
COMMENT FUNCTION st_overlaps(raster, integer, geometry)
COMMENT FUNCTION st_overleft(raster, raster)
COMMENT FUNCTION st_overright(raster, raster)
COMMENT FUNCTION st_patchn(geometry, integer)
COMMENT FUNCTION st_perimeter(geog geography, use_spheroid boolean)
COMMENT FUNCTION st_perimeter(geography)
COMMENT FUNCTION st_perimeter(geometry)
COMMENT FUNCTION st_perimeter2d(geometry)
COMMENT FUNCTION st_perimeter3d(geometry)
COMMENT FUNCTION st_pixelascentroid(rast raster, x integer, y integer)
COMMENT FUNCTION st_pixelascentroids(rast raster, band integer, exclude_nodata_value boolean)
COMMENT FUNCTION st_pixelaspoint(rast raster, x integer, y integer)
COMMENT FUNCTION st_pixelaspoints(rast raster, band integer, exclude_nodata_value boolean)
COMMENT FUNCTION st_pixelaspolygon(rast raster, x integer, y integer)
COMMENT FUNCTION st_pixelaspolygon(raster, integer, integer, integer)
COMMENT FUNCTION st_pixelaspolygons(rast raster, band integer, exclude_nodata_value boolean)
COMMENT FUNCTION st_pixelaspolygons(raster)
COMMENT FUNCTION st_pixelaspolygons(raster, integer)
COMMENT FUNCTION st_pixelheight(raster)
COMMENT FUNCTION st_pixelofvalue(rast raster, nband integer, search double precision, exclude_nodata_value boolean)
COMMENT FUNCTION st_pixelofvalue(rast raster, nband integer, search double precision[], exclude_nodata_value boolean)
COMMENT FUNCTION st_pixelofvalue(rast raster, search double precision, exclude_nodata_value boolean)
COMMENT FUNCTION st_pixelofvalue(rast raster, search double precision[], exclude_nodata_value boolean)
COMMENT FUNCTION st_pixelwidth(raster)
COMMENT FUNCTION st_point(double precision, double precision)
COMMENT FUNCTION st_point(double precision, double precision, srid integer)
COMMENT FUNCTION st_point_inside_circle(geometry, double precision, double precision, double precision)
COMMENT FUNCTION st_pointfromgeohash(text, integer)
COMMENT FUNCTION st_pointfromtext(text)
COMMENT FUNCTION st_pointfromtext(text, integer)
COMMENT FUNCTION st_pointfromwkb(bytea)
COMMENT FUNCTION st_pointfromwkb(bytea, integer)
COMMENT FUNCTION st_pointinsidecircle(geometry, double precision, double precision, double precision)
COMMENT FUNCTION st_pointm(xcoordinate double precision, ycoordinate double precision, mcoordinate double precision, srid integer)
COMMENT FUNCTION st_pointn(geometry, integer)
COMMENT FUNCTION st_pointonsurface(geometry)
COMMENT FUNCTION st_points(geometry)
COMMENT FUNCTION st_pointz(xcoordinate double precision, ycoordinate double precision, zcoordinate double precision, srid integer)
COMMENT FUNCTION st_pointzm(xcoordinate double precision, ycoordinate double precision, zcoordinate double precision, mcoordinate double precision, srid integer)
COMMENT FUNCTION st_polyfromtext(text)
COMMENT FUNCTION st_polyfromtext(text, integer)
COMMENT FUNCTION st_polyfromwkb(bytea)
COMMENT FUNCTION st_polyfromwkb(bytea, integer)
COMMENT FUNCTION st_polygon(geometry, integer)
COMMENT FUNCTION st_polygon(rast raster, band integer)
COMMENT FUNCTION st_polygon(raster)
COMMENT FUNCTION st_polygon(raster, integer)
COMMENT FUNCTION st_polygonfromtext(text)
COMMENT FUNCTION st_polygonfromtext(text, integer)
COMMENT FUNCTION st_polygonfromwkb(bytea)
COMMENT FUNCTION st_polygonfromwkb(bytea, integer)
COMMENT FUNCTION st_polygonize(geometry[])
COMMENT FUNCTION st_polygonize_garray(geometry[])
COMMENT FUNCTION st_project(geog geography, distance double precision, azimuth double precision)
COMMENT FUNCTION st_project(geog_from geography, geog_to geography, distance double precision)
COMMENT FUNCTION st_project(geom1 geometry, distance double precision, azimuth double precision)
COMMENT FUNCTION st_project(geom1 geometry, geom2 geometry, distance double precision)
COMMENT FUNCTION st_quantile(rast raster, exclude_nodata_value boolean, quantile double precision)
COMMENT FUNCTION st_quantile(rast raster, nband integer, exclude_nodata_value boolean, quantile double precision)
COMMENT FUNCTION st_quantile(rast raster, nband integer, exclude_nodata_value boolean, quantiles double precision[], OUT quantile double precision, OUT value double precision)
COMMENT FUNCTION st_quantile(rast raster, nband integer, exclude_nodata_value boolean, quantiles double precision[], out quantile double precision, out value double precision)
COMMENT FUNCTION st_quantile(rast raster, nband integer, quantile double precision)
COMMENT FUNCTION st_quantile(rast raster, nband integer, quantiles double precision[], OUT quantile double precision, OUT value double precision)
COMMENT FUNCTION st_quantile(rast raster, nband integer, quantiles double precision[], out quantile double precision, out value double precision)
COMMENT FUNCTION st_quantile(rast raster, quantile double precision)
COMMENT FUNCTION st_quantile(rast raster, quantiles double precision[], OUT quantile double precision, OUT value double precision)
COMMENT FUNCTION st_quantile(rast raster, quantiles double precision[], out quantile double precision, out value double precision)
COMMENT FUNCTION st_quantile(raster, double precision[])
COMMENT FUNCTION st_quantile(raster, integer, boolean, double precision[])
COMMENT FUNCTION st_quantile(raster, integer, double precision[])
COMMENT FUNCTION st_quantile(rastertable text, rastercolumn text, exclude_nodata_value boolean, quantile double precision)
COMMENT FUNCTION st_quantile(rastertable text, rastercolumn text, nband integer, exclude_nodata_value boolean, quantile double precision)
COMMENT FUNCTION st_quantile(rastertable text, rastercolumn text, nband integer, exclude_nodata_value boolean, quantiles double precision[], out quantile double precision, out value double precision)
COMMENT FUNCTION st_quantile(rastertable text, rastercolumn text, nband integer, quantile double precision)
COMMENT FUNCTION st_quantile(rastertable text, rastercolumn text, nband integer, quantiles double precision[], out quantile double precision, out value double precision)
COMMENT FUNCTION st_quantile(rastertable text, rastercolumn text, quantile double precision)
COMMENT FUNCTION st_quantile(rastertable text, rastercolumn text, quantiles double precision[], out quantile double precision, out value double precision)
COMMENT FUNCTION st_quantile(text, text, double precision[])
COMMENT FUNCTION st_quantile(text, text, integer, boolean, double precision[])
COMMENT FUNCTION st_quantile(text, text, integer, double precision[])
COMMENT FUNCTION st_quantizecoordinates(g geometry, prec_x integer, prec_y integer, prec_z integer, prec_m integer)
COMMENT FUNCTION st_range4ma(matrix double precision[], nodatamode text, VARIADIC args text[])
COMMENT FUNCTION st_range4ma(matrix float[][], nodatamode text, variadic args text[])
COMMENT FUNCTION st_range4ma(value double precision[], pos integer[], VARIADIC userargs text[])
COMMENT FUNCTION st_range4ma(value double precision[][][], pos integer[][], variadic userargs text[])
COMMENT FUNCTION st_raster2worldcoord(raster, integer, integer)
COMMENT FUNCTION st_raster2worldcoordx(raster, integer)
COMMENT FUNCTION st_raster2worldcoordx(raster, integer, integer)
COMMENT FUNCTION st_raster2worldcoordy(raster, integer)
COMMENT FUNCTION st_raster2worldcoordy(raster, integer, integer)
COMMENT FUNCTION st_rastertoworldcoord(rast raster, columnx integer, rowy integer, OUT longitude double precision, OUT latitude double precision)
COMMENT FUNCTION st_rastertoworldcoord(rast raster, columnx integer, rowy integer, out	longitude double precision, out latitude double precision)
COMMENT FUNCTION st_rastertoworldcoordx(rast raster, xr integer)
COMMENT FUNCTION st_rastertoworldcoordx(rast raster, xr integer, yr integer)
COMMENT FUNCTION st_rastertoworldcoordy(rast raster, xr integer, yr integer)
COMMENT FUNCTION st_rastertoworldcoordy(rast raster, yr integer)
COMMENT FUNCTION st_rastfromhexwkb(text)
COMMENT FUNCTION st_rastfromwkb(bytea)
COMMENT FUNCTION st_reclass(rast raster, VARIADIC reclassargset reclassarg[])
COMMENT FUNCTION st_reclass(rast raster, nband integer, reclassexpr text, pixeltype text, nodataval double precision)
COMMENT FUNCTION st_reclass(rast raster, reclassexpr text, pixeltype text)
COMMENT FUNCTION st_reclass(rast raster, variadic reclassargset reclassarg[])
COMMENT FUNCTION st_reduceprecision(geom geometry, gridsize double precision)
COMMENT FUNCTION st_relate(geom1 geometry, geom2 geometry)
COMMENT FUNCTION st_relate(geom1 geometry, geom2 geometry, integer)
COMMENT FUNCTION st_relate(geom1 geometry, geom2 geometry, text)
COMMENT FUNCTION st_relatematch(text, text)
COMMENT FUNCTION st_remedgemodface(toponame character varying, e1id integer)
COMMENT FUNCTION st_remedgenewface(toponame character varying, e1id integer)
COMMENT FUNCTION st_remisonode(character varying, integer)
COMMENT FUNCTION st_removeisoedge(atopology character varying, anedge integer)
COMMENT FUNCTION st_removeisonode(atopology character varying, anode integer)
COMMENT FUNCTION st_removepoint(geometry, integer)
COMMENT FUNCTION st_removerepeatedpoints(geom geometry, tolerance double precision)
COMMENT FUNCTION st_removerepeatedpoints(geometry)
COMMENT FUNCTION st_resample(rast raster, ref raster, algorithm text, maxerr double precision, usescale boolean)
COMMENT FUNCTION st_resample(rast raster, ref raster, usescale boolean, algorithm text, maxerr double precision)
COMMENT FUNCTION st_resample(rast raster, scalex double precision, scaley double precision, gridx double precision, gridy double precision, skewx double precision, skewy double precision, algorithm text, maxerr double precision)
COMMENT FUNCTION st_resample(rast raster, width integer, height integer, gridx double precision, gridy double precision, skewx double precision, skewy double precision, algorithm text, maxerr double precision)
COMMENT FUNCTION st_resample(raster, integer, double precision, double precision, double precision, double precision, double precision, double precision, text, double precision)
COMMENT FUNCTION st_resample(raster, integer, integer, integer, double precision, double precision, double precision, double precision, text, double precision)
COMMENT FUNCTION st_resample(raster, raster, text, double precision)
COMMENT FUNCTION st_rescale(rast raster, scalex double precision, scaley double precision, algorithm text, maxerr double precision)
COMMENT FUNCTION st_rescale(rast raster, scalexy double precision, algorithm text, maxerr double precision)
COMMENT FUNCTION st_resize(rast raster, percentwidth double precision, percentheight double precision, algorithm text, maxerr double precision)
COMMENT FUNCTION st_resize(rast raster, width integer, height integer, algorithm text, maxerr double precision)
COMMENT FUNCTION st_resize(rast raster, width text, height text, algorithm text, maxerr double precision)
COMMENT FUNCTION st_reskew(rast raster, skewx double precision, skewy double precision, algorithm text, maxerr double precision)
COMMENT FUNCTION st_reskew(rast raster, skewxy double precision, algorithm text, maxerr double precision)
COMMENT FUNCTION st_retile(tab regclass, col name, ext geometry, sfx double precision, sfy double precision, tw integer, th integer, algo text)
COMMENT FUNCTION st_reverse(geometry)
COMMENT FUNCTION st_right(raster, raster)
COMMENT FUNCTION st_rotate(geometry, double precision)
COMMENT FUNCTION st_rotate(geometry, double precision, double precision, double precision)
COMMENT FUNCTION st_rotate(geometry, double precision, geometry)
COMMENT FUNCTION st_rotatex(geometry, double precision)
COMMENT FUNCTION st_rotatey(geometry, double precision)
COMMENT FUNCTION st_rotatez(geometry, double precision)
COMMENT FUNCTION st_rotation(raster)
COMMENT FUNCTION st_roughness(rast raster, nband integer, customextent raster, pixeltype text, interpolate_nodata boolean)
COMMENT FUNCTION st_roughness(rast raster, nband integer, pixeltype text, interpolate_nodata boolean)
COMMENT FUNCTION st_same(raster, raster)
COMMENT FUNCTION st_samealignment(rast1 raster, rast2 raster)
COMMENT FUNCTION st_samealignment(ulx1 double precision, uly1 double precision, scalex1 double precision, scaley1 double precision, skewx1 double precision, skewy1 double precision, ulx2 double precision, uly2 double precision, scalex2 double precision, scaley2 double precision, skewx2 double precision, skewy2 double precision)
COMMENT FUNCTION st_scale(geometry, double precision, double precision)
COMMENT FUNCTION st_scale(geometry, double precision, double precision, double precision)
COMMENT FUNCTION st_scale(geometry, geometry)
COMMENT FUNCTION st_scale(geometry, geometry, origin geometry)
COMMENT FUNCTION st_scalex(raster)
COMMENT FUNCTION st_scaley(raster)
COMMENT FUNCTION st_scroll(geometry, geometry)
COMMENT FUNCTION st_segmentize(geog geography, max_segment_length double precision)
COMMENT FUNCTION st_segmentize(geometry, double precision)
COMMENT FUNCTION st_setbandindex(rast raster, band integer, outdbindex integer, force boolean)
COMMENT FUNCTION st_setbandisnodata(rast raster, band integer)
COMMENT FUNCTION st_setbandisnodata(raster)
COMMENT FUNCTION st_setbandisnodata(raster, integer)
COMMENT FUNCTION st_setbandnodatavalue(rast raster, band integer, nodatavalue double precision, forcechecking boolean)
COMMENT FUNCTION st_setbandnodatavalue(rast raster, nodatavalue double precision)
COMMENT FUNCTION st_setbandnodatavalue(raster, integer, double precision)
COMMENT FUNCTION st_setbandnodatavalue(raster, integer, double precision, boolean)
COMMENT FUNCTION st_setbandpath(rast raster, band integer, outdbpath text, outdbindex integer, force boolean)
COMMENT FUNCTION st_seteffectivearea(geometry, double precision)
COMMENT FUNCTION st_seteffectivearea(geometry, double precision, integer)
COMMENT FUNCTION st_setgeoreference(rast raster, georef text, format text)
COMMENT FUNCTION st_setgeoreference(rast raster, upperleftx double precision, upperlefty double precision, scalex double precision, scaley double precision, skewx double precision, skewy double precision)
COMMENT FUNCTION st_setgeoreference(raster, text)
COMMENT FUNCTION st_setgeoreference(raster, text, text)
COMMENT FUNCTION st_setgeotransform(rast raster, imag double precision, jmag double precision, theta_i double precision, theta_ij double precision, xoffset double precision, yoffset double precision)
COMMENT FUNCTION st_setm(rast raster, geom geometry, resample text, band integer)
COMMENT FUNCTION st_setpoint(geometry, integer, geometry)
COMMENT FUNCTION st_setrotation(rast raster, rotation double precision)
COMMENT FUNCTION st_setscale(rast raster, scale double precision)
COMMENT FUNCTION st_setscale(rast raster, scalex double precision, scaley double precision)
COMMENT FUNCTION st_setskew(rast raster, skew double precision)
COMMENT FUNCTION st_setskew(rast raster, skewx double precision, skewy double precision)
COMMENT FUNCTION st_setsrid(geog geography, srid integer)
COMMENT FUNCTION st_setsrid(geom geometry, srid integer)
COMMENT FUNCTION st_setsrid(rast raster, srid integer)
COMMENT FUNCTION st_setupperleft(rast raster, upperleftx double precision, upperlefty double precision)
COMMENT FUNCTION st_setvalue(rast raster, band integer, x integer, y integer, newvalue double precision)
COMMENT FUNCTION st_setvalue(rast raster, geom geometry, newvalue double precision)
COMMENT FUNCTION st_setvalue(rast raster, nband integer, geom geometry, newvalue double precision)
COMMENT FUNCTION st_setvalue(rast raster, x integer, y integer, newvalue double precision)
COMMENT FUNCTION st_setvalue(raster, geometry, double precision)
COMMENT FUNCTION st_setvalue(raster, integer, geometry, double precision)
COMMENT FUNCTION st_setvalues(rast raster, nband integer, geomvalset geomval[], keepnodata boolean)
COMMENT FUNCTION st_setvalues(rast raster, nband integer, x integer, y integer, newvalueset double precision[], noset boolean[], keepnodata boolean)
COMMENT FUNCTION st_setvalues(rast raster, nband integer, x integer, y integer, newvalueset double precision[], nosetvalue double precision, keepnodata boolean)
COMMENT FUNCTION st_setvalues(rast raster, nband integer, x integer, y integer, newvalueset double precision[][], noset boolean[][], keepnodata boolean)
COMMENT FUNCTION st_setvalues(rast raster, nband integer, x integer, y integer, newvalueset double precision[][], nosetvalue double precision, keepnodata boolean)
COMMENT FUNCTION st_setvalues(rast raster, nband integer, x integer, y integer, width integer, height integer, newvalue double precision, keepnodata boolean)
COMMENT FUNCTION st_setvalues(rast raster, x integer, y integer, width integer, height integer, newvalue double precision, keepnodata boolean)
COMMENT FUNCTION st_setz(rast raster, geom geometry, resample text, band integer)
COMMENT FUNCTION st_sharedpaths(geom1 geometry, geom2 geometry)
COMMENT FUNCTION st_shift_longitude(geometry)
COMMENT FUNCTION st_shiftlongitude(geometry)
COMMENT FUNCTION st_shortestline(geography, geography, use_spheroid boolean)
COMMENT FUNCTION st_shortestline(geom1 geometry, geom2 geometry)
COMMENT FUNCTION st_shortestline(text, text)
COMMENT FUNCTION st_simplify(geometry, double precision)
COMMENT FUNCTION st_simplify(geometry, double precision, boolean)
COMMENT FUNCTION st_simplify(tg topogeometry, tolerance double precision)
COMMENT FUNCTION st_simplifypolygonhull(geom geometry, vertex_fraction double precision, is_outer boolean)
COMMENT FUNCTION st_simplifypreservetopology(geometry, double precision)
COMMENT FUNCTION st_simplifyvw(geometry, double precision)
COMMENT FUNCTION st_skewx(raster)
COMMENT FUNCTION st_skewy(raster)
COMMENT FUNCTION st_slope(rast raster, nband integer, customextent raster, pixeltype text, units text, scale double precision, interpolate_nodata boolean)
COMMENT FUNCTION st_slope(rast raster, nband integer, pixeltype text, units text, scale double precision, interpolate_nodata boolean)
COMMENT FUNCTION st_slope(raster, integer, text)
COMMENT FUNCTION st_slope(raster, integer, text, boolean)
COMMENT FUNCTION st_slope(raster, integer, text, text, double precision, boolean)
COMMENT FUNCTION st_snap(geom1 geometry, geom2 geometry, double precision)
COMMENT FUNCTION st_snaptogrid(geom1 geometry, geom2 geometry, double precision, double precision, double precision, double precision)
COMMENT FUNCTION st_snaptogrid(geometry, double precision)
COMMENT FUNCTION st_snaptogrid(geometry, double precision, double precision)
COMMENT FUNCTION st_snaptogrid(geometry, double precision, double precision, double precision, double precision)
COMMENT FUNCTION st_snaptogrid(rast raster, gridx double precision, gridy double precision, algorithm text, maxerr double precision, scalex double precision, scaley double precision)
COMMENT FUNCTION st_snaptogrid(rast raster, gridx double precision, gridy double precision, scalex double precision, scaley double precision, algorithm text, maxerr double precision)
COMMENT FUNCTION st_snaptogrid(rast raster, gridx double precision, gridy double precision, scalexy double precision, algorithm text, maxerr double precision)
COMMENT FUNCTION st_spheroid_in(cstring)
COMMENT FUNCTION st_spheroid_out(spheroid)
COMMENT FUNCTION st_split(geom1 geometry, geom2 geometry)
COMMENT FUNCTION st_square(size double precision, cell_i integer, cell_j integer, origin geometry)
COMMENT FUNCTION st_squaregrid(size double precision, bounds geometry, OUT geom geometry, OUT i integer, OUT j integer)
COMMENT FUNCTION st_squaregrid(size double precision, bounds geometry, out geom geometry, out i integer, out j integer)
COMMENT FUNCTION st_srid(geog geography)
COMMENT FUNCTION st_srid(geom geometry)
COMMENT FUNCTION st_srid(raster)
COMMENT FUNCTION st_srid(tg topogeometry)
COMMENT FUNCTION st_startpoint(geometry)
COMMENT FUNCTION st_stddev4ma(matrix double precision[], nodatamode text, VARIADIC args text[])
COMMENT FUNCTION st_stddev4ma(matrix float[][], nodatamode text, variadic args text[])
COMMENT FUNCTION st_stddev4ma(value double precision[], pos integer[], VARIADIC userargs text[])
COMMENT FUNCTION st_stddev4ma(value double precision[][][], pos integer[][], variadic userargs text[])
COMMENT FUNCTION st_straightskeleton(geometry)
COMMENT FUNCTION st_subdivide(geom geometry, maxvertices integer)
COMMENT FUNCTION st_subdivide(geom geometry, maxvertices integer, gridsize double precision)
COMMENT FUNCTION st_sum4ma(matrix double precision[], nodatamode text, VARIADIC args text[])
COMMENT FUNCTION st_sum4ma(matrix float[][], nodatamode text, variadic args text[])
COMMENT FUNCTION st_sum4ma(value double precision[], pos integer[], VARIADIC userargs text[])
COMMENT FUNCTION st_sum4ma(value double precision[][][], pos integer[][], variadic userargs text[])
COMMENT FUNCTION st_summary(geography)
COMMENT FUNCTION st_summary(geometry)
COMMENT FUNCTION st_summary(rast raster)
COMMENT FUNCTION st_summarystats(rast raster, exclude_nodata_value boolean)
COMMENT FUNCTION st_summarystats(rast raster, nband integer, exclude_nodata_value boolean)
COMMENT FUNCTION st_summarystats(raster, boolean)
COMMENT FUNCTION st_summarystats(raster, integer, boolean)
COMMENT FUNCTION st_summarystats(text, text, boolean)
COMMENT FUNCTION st_summarystats(text, text, integer, boolean)
COMMENT FUNCTION st_swapordinates(geom geometry, ords cstring)
COMMENT FUNCTION st_symdifference(geom1 geometry, geom2 geometry)
COMMENT FUNCTION st_symdifference(geom1 geometry, geom2 geometry, gridsize double precision)
COMMENT FUNCTION st_symmetricdifference(geom1 geometry, geom2 geometry)
COMMENT FUNCTION st_tesselate(geometry)
COMMENT FUNCTION st_text(geometry)
COMMENT FUNCTION st_tile(rast raster, nband integer, width integer, height integer, padwithnodata boolean, nodataval double precision)
COMMENT FUNCTION st_tile(rast raster, nband integer[], width integer, height integer, padwithnodata boolean, nodataval double precision)
COMMENT FUNCTION st_tile(rast raster, width integer, height integer, padwithnodata boolean, nodataval double precision)
COMMENT FUNCTION st_tile(raster, integer, integer)
COMMENT FUNCTION st_tile(raster, integer, integer, integer)
COMMENT FUNCTION st_tile(raster, integer, integer, integer[])
COMMENT FUNCTION st_tile(raster, integer[], integer, integer)
COMMENT FUNCTION st_tileenvelope(zoom integer, x integer, y integer, bounds geometry, margin double precision)
COMMENT FUNCTION st_touches(geom1 geometry, geom2 geometry)
COMMENT FUNCTION st_touches(geometry, raster, integer)
COMMENT FUNCTION st_touches(rast1 raster, nband1 integer, rast2 raster, nband2 integer)
COMMENT FUNCTION st_touches(rast1 raster, rast2 raster)
COMMENT FUNCTION st_touches(raster, geometry, integer)
COMMENT FUNCTION st_touches(raster, integer, geometry)
COMMENT FUNCTION st_tpi(rast raster, nband integer, customextent raster, pixeltype text, interpolate_nodata boolean)
COMMENT FUNCTION st_tpi(rast raster, nband integer, pixeltype text, interpolate_nodata boolean)
COMMENT FUNCTION st_transform(geom geometry, from_proj text, to_proj text)
COMMENT FUNCTION st_transform(geom geometry, from_proj text, to_srid integer)
COMMENT FUNCTION st_transform(geom geometry, to_proj text)
COMMENT FUNCTION st_transform(geometry, integer)
COMMENT FUNCTION st_transform(rast raster, alignto raster, algorithm text, maxerr double precision)
COMMENT FUNCTION st_transform(rast raster, srid integer, algorithm text, maxerr double precision, scalex double precision, scaley double precision)
COMMENT FUNCTION st_transform(rast raster, srid integer, scalex double precision, scaley double precision, algorithm text, maxerr double precision)
COMMENT FUNCTION st_transform(rast raster, srid integer, scalexy double precision, algorithm text, maxerr double precision)
COMMENT FUNCTION st_transformpipeline(geom geometry, pipeline text, to_srid integer)
COMMENT FUNCTION st_translate(geometry, double precision, double precision)
COMMENT FUNCTION st_translate(geometry, double precision, double precision, double precision)
COMMENT FUNCTION st_transscale(geometry, double precision, double precision, double precision, double precision)
COMMENT FUNCTION st_tri(rast raster, nband integer, customextent raster, pixeltype text, interpolate_nodata boolean)
COMMENT FUNCTION st_tri(rast raster, nband integer, pixeltype text, interpolate_nodata boolean)
COMMENT FUNCTION st_triangulatepolygon(g1 geometry)
COMMENT FUNCTION st_unaryunion(geometry)
COMMENT FUNCTION st_unaryunion(geometry, gridsize double precision)
COMMENT FUNCTION st_union(geom1 geometry, geom2 geometry)
COMMENT FUNCTION st_union(geom1 geometry, geom2 geometry, gridsize double precision)
COMMENT FUNCTION st_union(geometry[])
COMMENT FUNCTION st_unite_garray(geometry[])
COMMENT FUNCTION st_upperleftx(raster)
COMMENT FUNCTION st_upperlefty(raster)
COMMENT FUNCTION st_value(rast raster, band integer, pt geometry, exclude_nodata_value boolean)
COMMENT FUNCTION st_value(rast raster, band integer, pt geometry, exclude_nodata_value boolean, resample text)
COMMENT FUNCTION st_value(rast raster, band integer, x integer, y integer, exclude_nodata_value boolean)
COMMENT FUNCTION st_value(rast raster, pt geometry, exclude_nodata_value boolean)
COMMENT FUNCTION st_value(rast raster, x integer, y integer, exclude_nodata_value boolean)
COMMENT FUNCTION st_value(raster, geometry)
COMMENT FUNCTION st_value(raster, geometry, boolean)
COMMENT FUNCTION st_value(raster, geometry, double precision)
COMMENT FUNCTION st_value(raster, integer, geometry)
COMMENT FUNCTION st_value(raster, integer, geometry, boolean)
COMMENT FUNCTION st_value(raster, integer, geometry, double precision)
COMMENT FUNCTION st_value(raster, integer, integer)
COMMENT FUNCTION st_value(raster, integer, integer, boolean)
COMMENT FUNCTION st_value(raster, integer, integer, integer)
COMMENT FUNCTION st_value(raster, integer, integer, integer, boolean)
COMMENT FUNCTION st_valuecount(rast raster, nband integer, exclude_nodata_value boolean, searchvalue double precision, roundto double precision)
COMMENT FUNCTION st_valuecount(rast raster, nband integer, exclude_nodata_value boolean, searchvalues double precision[], roundto double precision, OUT value double precision, OUT count integer)
COMMENT FUNCTION st_valuecount(rast raster, nband integer, exclude_nodata_value boolean, searchvalues double precision[], roundto double precision, out value double precision, out count integer)
COMMENT FUNCTION st_valuecount(rast raster, nband integer, searchvalue double precision, roundto double precision)
COMMENT FUNCTION st_valuecount(rast raster, nband integer, searchvalues double precision[], roundto double precision, OUT value double precision, OUT count integer)
COMMENT FUNCTION st_valuecount(rast raster, nband integer, searchvalues double precision[], roundto double precision, out value double precision, out count integer)
COMMENT FUNCTION st_valuecount(rast raster, searchvalue double precision, roundto double precision)
COMMENT FUNCTION st_valuecount(rast raster, searchvalues double precision[], roundto double precision, OUT value double precision, OUT count integer)
COMMENT FUNCTION st_valuecount(rast raster, searchvalues double precision[], roundto double precision, out value double precision, out count integer)
COMMENT FUNCTION st_valuecount(raster, double precision[], double precision)
COMMENT FUNCTION st_valuecount(raster, integer, boolean, double precision[], double precision)
COMMENT FUNCTION st_valuecount(raster, integer, double precision[], double precision)
COMMENT FUNCTION st_valuecount(rastertable text, rastercolumn text, nband integer, exclude_nodata_value boolean, searchvalue double precision, roundto double precision)
COMMENT FUNCTION st_valuecount(rastertable text, rastercolumn text, nband integer, exclude_nodata_value boolean, searchvalues double precision[], roundto double precision, OUT value double precision, OUT count integer)
COMMENT FUNCTION st_valuecount(rastertable text, rastercolumn text, nband integer, exclude_nodata_value boolean, searchvalues double precision[], roundto double precision, out value double precision, out count integer)
COMMENT FUNCTION st_valuecount(rastertable text, rastercolumn text, nband integer, searchvalue double precision, roundto double precision)
COMMENT FUNCTION st_valuecount(rastertable text, rastercolumn text, nband integer, searchvalues double precision[], roundto double precision, OUT value double precision, OUT count integer)
COMMENT FUNCTION st_valuecount(rastertable text, rastercolumn text, nband integer, searchvalues double precision[], roundto double precision, out value double precision, out count integer)
COMMENT FUNCTION st_valuecount(rastertable text, rastercolumn text, searchvalue double precision, roundto double precision)
COMMENT FUNCTION st_valuecount(rastertable text, rastercolumn text, searchvalues double precision[], roundto double precision, OUT value double precision, OUT count integer)
COMMENT FUNCTION st_valuecount(rastertable text, rastercolumn text, searchvalues double precision[], roundto double precision, out value double precision, out count integer)
COMMENT FUNCTION st_valuecount(text, text, double precision, double precision)
COMMENT FUNCTION st_valuecount(text, text, double precision[], double precision)
COMMENT FUNCTION st_valuecount(text, text, integer, boolean, double precision, double precision)
COMMENT FUNCTION st_valuecount(text, text, integer, boolean, double precision[], double precision)
COMMENT FUNCTION st_valuecount(text, text, integer, double precision, double precision)
COMMENT FUNCTION st_valuecount(text, text, integer, double precision[], double precision)
COMMENT FUNCTION st_valuepercent(rast raster, nband integer, exclude_nodata_value boolean, searchvalue double precision, roundto double precision)
COMMENT FUNCTION st_valuepercent(rast raster, nband integer, exclude_nodata_value boolean, searchvalues double precision[], roundto double precision, out value double precision, out percent double precision)
COMMENT FUNCTION st_valuepercent(rast raster, nband integer, searchvalue double precision, roundto double precision)
COMMENT FUNCTION st_valuepercent(rast raster, nband integer, searchvalues double precision[], roundto double precision, out value double precision, out percent double precision)
COMMENT FUNCTION st_valuepercent(rast raster, searchvalue double precision, roundto double precision)
COMMENT FUNCTION st_valuepercent(rast raster, searchvalues double precision[], roundto double precision, out value double precision, out percent double precision)
COMMENT FUNCTION st_valuepercent(rastertable text, rastercolumn text, nband integer, exclude_nodata_value boolean, searchvalue double precision, roundto double precision)
COMMENT FUNCTION st_valuepercent(rastertable text, rastercolumn text, nband integer, exclude_nodata_value boolean, searchvalues double precision[], roundto double precision, out value double precision, out percent double precision)
COMMENT FUNCTION st_valuepercent(rastertable text, rastercolumn text, nband integer, searchvalue double precision, roundto double precision)
COMMENT FUNCTION st_valuepercent(rastertable text, rastercolumn text, nband integer, searchvalues double precision[], roundto double precision, out value double precision, out percent double precision)
COMMENT FUNCTION st_valuepercent(rastertable text, rastercolumn text, searchvalue double precision, roundto double precision)
COMMENT FUNCTION st_valuepercent(rastertable text, rastercolumn text, searchvalues double precision[], roundto double precision, out value double precision, out percent double precision)
COMMENT FUNCTION st_volume(geometry)
COMMENT FUNCTION st_voronoi(geometry, geometry, double precision, boolean)
COMMENT FUNCTION st_voronoilines(g1 geometry, tolerance double precision, extend_to geometry)
COMMENT FUNCTION st_voronoipolygons(g1 geometry, tolerance double precision, extend_to geometry)
COMMENT FUNCTION st_width(raster)
COMMENT FUNCTION st_within(geom1 geometry, geom2 geometry)
COMMENT FUNCTION st_within(rast1 raster, nband1 integer, rast2 raster, nband2 integer)
COMMENT FUNCTION st_within(rast1 raster, rast2 raster)
COMMENT FUNCTION st_wkbtosql(wkb bytea)
COMMENT FUNCTION st_wkttosql(text)
COMMENT FUNCTION st_world2rastercoord(raster, double precision, double precision)
COMMENT FUNCTION st_world2rastercoord(raster, geometry)
COMMENT FUNCTION st_world2rastercoordx(raster, double precision)
COMMENT FUNCTION st_world2rastercoordx(raster, double precision, double precision)
COMMENT FUNCTION st_world2rastercoordx(raster, geometry)
COMMENT FUNCTION st_world2rastercoordy(raster, double precision)
COMMENT FUNCTION st_world2rastercoordy(raster, double precision, double precision)
COMMENT FUNCTION st_world2rastercoordy(raster, geometry)
COMMENT FUNCTION st_worldtorastercoord(rast raster, longitude double precision, latitude double precision, OUT columnx integer, OUT rowy integer)
COMMENT FUNCTION st_worldtorastercoord(rast raster, longitude double precision, latitude double precision, out columnx integer, out rowy integer)
COMMENT FUNCTION st_worldtorastercoord(rast raster, pt geometry, OUT columnx integer, OUT rowy integer)
COMMENT FUNCTION st_worldtorastercoord(rast raster, pt geometry, out columnx integer, out rowy integer)
COMMENT FUNCTION st_worldtorastercoordx(rast raster, pt geometry)
COMMENT FUNCTION st_worldtorastercoordx(rast raster, xw double precision)
COMMENT FUNCTION st_worldtorastercoordx(rast raster, xw double precision, yw double precision)
COMMENT FUNCTION st_worldtorastercoordy(rast raster, pt geometry)
COMMENT FUNCTION st_worldtorastercoordy(rast raster, xw double precision, yw double precision)
COMMENT FUNCTION st_worldtorastercoordy(rast raster, yw double precision)
COMMENT FUNCTION st_wrapx(geom geometry, wrap double precision, move double precision)
COMMENT FUNCTION st_x(geometry)
COMMENT FUNCTION st_xmax(box3d)
COMMENT FUNCTION st_xmin(box3d)
COMMENT FUNCTION st_y(geometry)
COMMENT FUNCTION st_ymax(box3d)
COMMENT FUNCTION st_ymin(box3d)
COMMENT FUNCTION st_z(geometry)
COMMENT FUNCTION st_zmax(box3d)
COMMENT FUNCTION st_zmflag(geometry)
COMMENT FUNCTION st_zmin(box3d)
COMMENT FUNCTION startpoint(geometry)
COMMENT FUNCTION summary(geometry)
COMMENT FUNCTION symdifference(geometry, geometry)
COMMENT FUNCTION symmetricdifference(geometry, geometry)
COMMENT FUNCTION text(geometry)
COMMENT FUNCTION topoelement(topo topogeometry)
COMMENT FUNCTION topoelementarray_append(topoelementarray, topoelement)
COMMENT FUNCTION topogeo_addgeometry(atopology character varying, ageom geometry, tolerance double precision)
COMMENT FUNCTION topogeo_addlinestring(atopology character varying, aline geometry, tolerance double precision)
COMMENT FUNCTION topogeo_addpoint(atopology character varying, apoint geometry, tolerance double precision)
COMMENT FUNCTION topogeo_addpolygon(atopology character varying, apoly geometry, tolerance double precision)
COMMENT FUNCTION topogeom_addelement(tg topogeometry, el topoelement)
COMMENT FUNCTION topogeom_addtopogeom(tgt topogeometry, src topogeometry)
COMMENT FUNCTION topogeom_remelement(tg topogeometry, el topoelement)
COMMENT FUNCTION topologysummary(atopology character varying)
COMMENT FUNCTION totopogeom(ageom geometry, atopology character varying, alayer integer, atolerance double precision)
COMMENT FUNCTION totopogeom(ageom geometry, tg topogeometry, atolerance double precision)
COMMENT FUNCTION totopogeom(geometry, character varying, integer, double precision)
COMMENT FUNCTION touches(geometry, geometry)
COMMENT FUNCTION transform(geometry, integer)
COMMENT FUNCTION transform_geometry(geometry, text, text, integer)
COMMENT FUNCTION translate(geometry, double precision, double precision)
COMMENT FUNCTION translate(geometry, double precision, double precision, double precision)
COMMENT FUNCTION transscale(geometry, double precision, double precision, double precision, double precision)
COMMENT FUNCTION unite_garray(geometry[])
COMMENT FUNCTION unlockrows(text)
COMMENT FUNCTION updategeometrysrid(catalogn_name character varying, schema_name character varying, table_name character varying, column_name character varying, new_srid_in integer)
COMMENT FUNCTION updategeometrysrid(character varying, character varying, character varying, integer)
COMMENT FUNCTION updategeometrysrid(character varying, character varying, integer)
COMMENT FUNCTION updaterastersrid(schema_name name, table_name name, column_name name, new_srid integer)
COMMENT FUNCTION updaterastersrid(table_name name, column_name name, new_srid integer)
COMMENT FUNCTION validatetopology(character varying)
COMMENT FUNCTION validatetopology(toponame character varying, bbox geometry)
COMMENT FUNCTION validatetopologyrelation(toponame character varying)
COMMENT FUNCTION within(geometry, geometry)
COMMENT FUNCTION x(geometry)
COMMENT FUNCTION xmax(box3d)
COMMENT FUNCTION xmin(box3d)
COMMENT FUNCTION y(geometry)
COMMENT FUNCTION ymax(box3d)
COMMENT FUNCTION ymin(box3d)
COMMENT FUNCTION z(geometry)
COMMENT FUNCTION zmax(box3d)
COMMENT FUNCTION zmflag(geometry)
COMMENT FUNCTION zmin(box3d)
COMMENT SCHEMA topology
COMMENT TYPE addbandarg
COMMENT TYPE agg_count
COMMENT TYPE agg_samealignment
COMMENT TYPE bandmetadata;
COMMENT TYPE box2d
COMMENT TYPE box2df
COMMENT TYPE box3d
COMMENT TYPE geography
COMMENT TYPE geometry
COMMENT TYPE geometry_dump
COMMENT TYPE geomval
COMMENT TYPE geomvalxy;
COMMENT TYPE getfaceedges_returntype
COMMENT TYPE gidx
COMMENT TYPE histogram;
COMMENT TYPE pgis_abs
COMMENT TYPE quantile;
COMMENT TYPE rastbandarg
COMMENT TYPE raster
COMMENT TYPE reclassarg
COMMENT TYPE spheroid
COMMENT TYPE summarystats
COMMENT TYPE topoelement
COMMENT TYPE topoelementarray
COMMENT TYPE topogeometry
COMMENT TYPE unionarg
COMMENT TYPE valid_detail
COMMENT TYPE validatetopology_returntype
COMMENT TYPE valuecount;
COMMENT TYPE wktgeomval;
CONSTRAINT layer layer_pkey
CONSTRAINT layer layer_schema_name_table_name_feature_column_key
CONSTRAINT spatial_ref_sys spatial_ref_sys_pkey
CONSTRAINT topology topology_name_key
CONSTRAINT topology topology_pkey
DEFAULT topology id
DOMAIN topoelement
DOMAIN topoelementarray
FK CONSTRAINT layer layer_topology_id_fkey
FUNCTION "json"(geometry)
FUNCTION "jsonb"(geometry)
FUNCTION __st_countagg_transfn(agg_count, raster, integer, boolean, double precision)
FUNCTION _add_overview_constraint(name, name, name, name, name, name, integer)
FUNCTION _add_raster_constraint(name, text)
FUNCTION _add_raster_constraint_alignment(name, name, name)
FUNCTION _add_raster_constraint_blocksize(name, name, name, text)
FUNCTION _add_raster_constraint_coverage_tile(name, name, name)
FUNCTION _add_raster_constraint_extent(name, name, name)
FUNCTION _add_raster_constraint_nodata_values(name, name, name)
FUNCTION _add_raster_constraint_num_bands(name, name, name)
FUNCTION _add_raster_constraint_out_db(name, name, name)
FUNCTION _add_raster_constraint_pixel_types(name, name, name)
FUNCTION _add_raster_constraint_regular_blocking(name, name, name)
FUNCTION _add_raster_constraint_scale(name, name, name, character)
FUNCTION _add_raster_constraint_spatially_unique(name, name, name)
FUNCTION _add_raster_constraint_srid(name, name, name)
FUNCTION _asgmledge(integer, integer, integer, geometry, regclass, text, integer, integer, text, integer)
FUNCTION _asgmlface(text, integer, regclass, text, integer, integer, text, integer)
FUNCTION _asgmlnode(integer, geometry, text, integer, integer, text, integer)
FUNCTION _checkedgelinking(integer, integer, integer, integer)
FUNCTION _drop_overview_constraint(name, name, name)
FUNCTION _drop_raster_constraint(name, name, name)
FUNCTION _drop_raster_constraint_alignment(name, name, name)
FUNCTION _drop_raster_constraint_blocksize(name, name, name, text)
FUNCTION _drop_raster_constraint_coverage_tile(name, name, name)
FUNCTION _drop_raster_constraint_extent(name, name, name)
FUNCTION _drop_raster_constraint_nodata_values(name, name, name)
FUNCTION _drop_raster_constraint_num_bands(name, name, name)
FUNCTION _drop_raster_constraint_out_db(name, name, name)
FUNCTION _drop_raster_constraint_pixel_types(name, name, name)
FUNCTION _drop_raster_constraint_regular_blocking(name, name, name)
FUNCTION _drop_raster_constraint_scale(name, name, name, character)
FUNCTION _drop_raster_constraint_spatially_unique(name, name, name)
FUNCTION _drop_raster_constraint_srid(name, name, name)
FUNCTION _overview_constraint(raster, integer, name, name, name)
FUNCTION _overview_constraint_info(name, name, name)
FUNCTION _postgis_deprecate(text, text, text)
FUNCTION _postgis_index_extent(regclass, text)
FUNCTION _postgis_join_selectivity(regclass, text, regclass, text, text)
FUNCTION _postgis_pgsql_version()
FUNCTION _postgis_scripts_pgsql_version()
FUNCTION _postgis_selectivity(regclass, text, geometry, text)
FUNCTION _postgis_stats(regclass, text, text)
FUNCTION _raster_constraint_info_alignment(name, name, name)
FUNCTION _raster_constraint_info_blocksize(name, name, name, text)
FUNCTION _raster_constraint_info_coverage_tile(name, name, name)
FUNCTION _raster_constraint_info_extent(name, name, name)
FUNCTION _raster_constraint_info_index(name, name, name)
FUNCTION _raster_constraint_info_nodata_values(name, name, name)
FUNCTION _raster_constraint_info_num_bands(name, name, name)
FUNCTION _raster_constraint_info_out_db(name, name, name)
FUNCTION _raster_constraint_info_pixel_types(name, name, name)
FUNCTION _raster_constraint_info_regular_blocking(name, name, name)
FUNCTION _raster_constraint_info_scale(name, name, name, character)
FUNCTION _raster_constraint_info_spatially_unique(name, name, name)
FUNCTION _raster_constraint_info_srid(name, name, name)
FUNCTION _raster_constraint_nodata_values(raster)
FUNCTION _raster_constraint_out_db(raster)
FUNCTION _raster_constraint_pixel_types(raster)
FUNCTION _rename_raster_tables()
FUNCTION _st_3ddfullywithin(geometry, geometry, double precision)
FUNCTION _st_3ddwithin(geometry, geometry, double precision)
FUNCTION _st_3dintersects(geometry, geometry)
FUNCTION _st_addfacesplit(character varying, integer, integer, boolean)
FUNCTION _st_adjacentedges(character varying, integer, integer)
FUNCTION _st_asgeojson(integer, geography, integer, integer)
FUNCTION _st_asgeojson(integer, geometry, integer, integer)
FUNCTION _st_asgml(integer, geography, integer, integer, text)
FUNCTION _st_asgml(integer, geography, integer, integer, text, text)
FUNCTION _st_asgml(integer, geometry, integer, integer, text)
FUNCTION _st_asgml(integer, geometry, integer, integer, text, text)
FUNCTION _st_askml(integer, geography, integer, text)
FUNCTION _st_askml(integer, geometry, integer, text)
FUNCTION _st_aspect4ma(double precision[], integer[], text[])
FUNCTION _st_aspect4ma(double precision[], text, text[])
FUNCTION _st_aspect4ma(double precision[][][], integer[][], userargs text[])
FUNCTION _st_asraster(geometry, double precision, double precision, integer, integer, text[], double precision[], double precision[], double precision, double precision, double precision, double precision, double precision, double precision, boolean)
FUNCTION _st_asx3d(integer, geometry, integer, integer, text)
FUNCTION _st_bestsrid(geography)
FUNCTION _st_bestsrid(geography, geography)
FUNCTION _st_buffer(geometry, double precision, cstring)
FUNCTION _st_clip(raster, integer[], geometry, double precision[], boolean)
FUNCTION _st_colormap(raster, integer, text, text)
FUNCTION _st_concavehull(geometry)
FUNCTION _st_contains(geometry, geometry)
FUNCTION _st_contains(geometry, raster, integer)
FUNCTION _st_contains(raster, geometry, integer)
FUNCTION _st_contains(raster, integer, raster, integer)
FUNCTION _st_containsproperly(geometry, geometry)
FUNCTION _st_containsproperly(raster, integer, raster, integer)
FUNCTION _st_convertarray4ma(double precision[])
FUNCTION _st_convertarray4ma(double precision[][])
FUNCTION _st_count(raster, integer, boolean, double precision)
FUNCTION _st_count(text, text, integer, boolean, double precision)
FUNCTION _st_countagg_finalfn(agg_count)
FUNCTION _st_countagg_transfn(agg_count, raster, boolean)
FUNCTION _st_countagg_transfn(agg_count, raster, integer, boolean)
FUNCTION _st_countagg_transfn(agg_count, raster, integer, boolean, double precision)
FUNCTION _st_coveredby(geography, geography)
FUNCTION _st_coveredby(geometry, geometry)
FUNCTION _st_coveredby(raster, integer, raster, integer)
FUNCTION _st_covers(geography, geography)
FUNCTION _st_covers(geometry, geometry)
FUNCTION _st_covers(raster, integer, raster, integer)
FUNCTION _st_crosses(geometry, geometry)
FUNCTION _st_dfullywithin(geometry, geometry, double precision)
FUNCTION _st_dfullywithin(raster, integer, raster, integer, double precision)
FUNCTION _st_distance(geography, geography, double precision, boolean)
FUNCTION _st_distancerecttree(geometry, geometry)
FUNCTION _st_distancerecttreecached(geometry, geometry)
FUNCTION _st_distancetree(geography, geography)
FUNCTION _st_distancetree(geography, geography, double precision, boolean)
FUNCTION _st_distanceuncached(geography, geography)
FUNCTION _st_distanceuncached(geography, geography, boolean)
FUNCTION _st_distanceuncached(geography, geography, double precision, boolean)
FUNCTION _st_dumpaswktpolygons(raster, integer)
FUNCTION _st_dumppoints(geometry, integer[])
FUNCTION _st_dwithin(geography, geography, double precision, boolean)
FUNCTION _st_dwithin(geometry, geometry, double precision)
FUNCTION _st_dwithin(raster, integer, raster, integer, double precision)
FUNCTION _st_dwithinuncached(geography, geography, double precision)
FUNCTION _st_dwithinuncached(geography, geography, double precision, boolean)
FUNCTION _st_equals(geometry, geometry)
FUNCTION _st_expand(geography, double precision)
FUNCTION _st_gdalwarp(raster, text, double precision, integer, double precision, double precision, double precision, double precision, double precision, double precision, integer, integer)
FUNCTION _st_geomfromgml(text, integer)
FUNCTION _st_grayscale4ma(double precision[], integer[], text[])
FUNCTION _st_grayscale4ma(double precision[][][], integer[][], userargs text[])
FUNCTION _st_hillshade4ma(double precision[], integer[], text[])
FUNCTION _st_hillshade4ma(double precision[], text, text[])
FUNCTION _st_hillshade4ma(double precision[][][], integer[][], userargs text[])
FUNCTION _st_histogram(raster, integer, boolean, double precision, integer, double precision[], boolean, double precision, double precision)
FUNCTION _st_histogram(text, text, integer, boolean, double precision, integer, double precision[], boolean)
FUNCTION _st_intersects(geometry, geometry)
FUNCTION _st_intersects(geometry, raster, integer)
FUNCTION _st_intersects(raster, geometry, integer)
FUNCTION _st_intersects(raster, integer, raster, integer)
FUNCTION _st_linecrossingdirection(geometry, geometry)
FUNCTION _st_longestline(geometry, geometry)
FUNCTION _st_mapalgebra(rastbandarg[], regprocedure, text, integer, integer, text, raster, double precision[], boolean, text[])
FUNCTION _st_mapalgebra(rastbandarg[], regprocedure, text, integer, integer, text, raster, double precision[][], boolean, userargs text[])
FUNCTION _st_mapalgebra(rastbandarg[], regprocedure, text, integer, integer, text, raster, text[])
FUNCTION _st_mapalgebra(rastbandarg[], text, text, text, text, text, double precision)
FUNCTION _st_mapalgebra4unionfinal1(raster)
FUNCTION _st_mapalgebra4unionstate(raster, raster)
FUNCTION _st_mapalgebra4unionstate(raster, raster, integer)
FUNCTION _st_mapalgebra4unionstate(raster, raster, integer, text)
FUNCTION _st_mapalgebra4unionstate(raster, raster, text)
FUNCTION _st_mapalgebra4unionstate(raster, raster, text, text, text, double precision, text, text, text, double precision)
FUNCTION _st_maxdistance(geometry, geometry)
FUNCTION _st_mintolerance(character varying, geometry)
FUNCTION _st_mintolerance(geometry)
FUNCTION _st_neighborhood(raster, integer, integer, integer, integer, integer, boolean)
FUNCTION _st_orderingequals(geometry, geometry)
FUNCTION _st_overlaps(geometry, geometry)
FUNCTION _st_overlaps(geometry, raster, integer)
FUNCTION _st_overlaps(raster, geometry, integer)
FUNCTION _st_overlaps(raster, integer, raster, integer)
FUNCTION _st_pixelascentroids(raster, integer, integer, integer, boolean)
FUNCTION _st_pixelaspolygons(raster, integer, integer, integer, boolean)
FUNCTION _st_pointoutside(geography)
FUNCTION _st_quantile(raster, integer, boolean, double precision, double precision[])
FUNCTION _st_quantile(text, text, integer, boolean, double precision, double precision[])
FUNCTION _st_raster2worldcoord(raster, integer, integer)
FUNCTION _st_rastertoworldcoord(raster, integer, integer)
FUNCTION _st_reclass(raster, reclassarg[])
FUNCTION _st_reclass(raster, reclassargset reclassarg[])
FUNCTION _st_remedgecheck(character varying, integer, integer, integer, integer)
FUNCTION _st_resample(raster, text, double precision, integer, double precision, double precision, double precision, double precision, double precision, double precision)
FUNCTION _st_resample(raster, text, double precision, integer, double precision, double precision, double precision, double precision, double precision, double precision, integer, integer)
FUNCTION _st_roughness4ma(double precision[], integer[], text[])
FUNCTION _st_roughness4ma(double precision[][][], integer[][], userargs text[])
FUNCTION _st_samealignment_finalfn(agg_samealignment)
FUNCTION _st_samealignment_transfn(agg_samealignment, raster)
FUNCTION _st_setvalues(raster, integer, integer, integer, double precision[], boolean[], boolean, double precision, boolean)
FUNCTION _st_setvalues(raster, integer, integer, integer, double precision[][], boolean[][], boolean, double precision, boolean)
FUNCTION _st_slope4ma(double precision[], integer[], text[])
FUNCTION _st_slope4ma(double precision[], text, text[])
FUNCTION _st_slope4ma(double precision[][][], integer[][], userargs text[])
FUNCTION _st_sortablehash(geometry)
FUNCTION _st_summarystats(raster, integer, boolean, double precision)
FUNCTION _st_summarystats(text, text, integer, boolean, double precision)
FUNCTION _st_summarystats_finalfn(internal)
FUNCTION _st_summarystats_transfn(internal, raster, boolean, double precision)
FUNCTION _st_summarystats_transfn(internal, raster, integer, boolean)
FUNCTION _st_summarystats_transfn(internal, raster, integer, boolean, double precision)
FUNCTION _st_tile(raster, integer, integer, integer[])
FUNCTION _st_tile(raster, integer, integer, integer[], boolean, double precision)
FUNCTION _st_touches(geometry, geometry)
FUNCTION _st_touches(geometry, raster, integer)
FUNCTION _st_touches(raster, geometry, integer)
FUNCTION _st_touches(raster, integer, raster, integer)
FUNCTION _st_tpi4ma(double precision[], integer[], text[])
FUNCTION _st_tpi4ma(double precision[][][], integer[][], userargs text[])
FUNCTION _st_tri4ma(double precision[], integer[], text[])
FUNCTION _st_tri4ma(double precision[][][], integer[][], userargs text[])
FUNCTION _st_union_finalfn(internal)
FUNCTION _st_union_transfn(internal, raster)
FUNCTION _st_union_transfn(internal, raster, integer)
FUNCTION _st_union_transfn(internal, raster, integer, text)
FUNCTION _st_union_transfn(internal, raster, text)
FUNCTION _st_union_transfn(internal, raster, unionarg[])
FUNCTION _st_valuecount(raster, integer, boolean, double precision[], double precision)
FUNCTION _st_valuecount(text, text, integer, boolean, double precision[], double precision)
FUNCTION _st_voronoi(geometry, geometry, double precision, boolean)
FUNCTION _st_within(geometry, geometry)
FUNCTION _st_within(raster, integer, raster, integer)
FUNCTION _st_world2rastercoord(raster, double precision, double precision)
FUNCTION _st_worldtorastercoord(raster, double precision, double precision)
FUNCTION _updaterastersrid(name, name, name, integer)
FUNCTION _validatetopologyedgelinking(geometry)
FUNCTION _validatetopologygetfaceshellmaximaledgering(character varying, integer)
FUNCTION _validatetopologygetringedges(integer)
FUNCTION _validatetopologyrings(geometry)
FUNCTION addauth(text)
FUNCTION addbbox(geometry)
FUNCTION addedge(character varying, geometry)
FUNCTION addface(character varying, geometry, boolean)
FUNCTION addgeometrycolumn(character varying, character varying, character varying, character varying, integer, character varying, integer)
FUNCTION addgeometrycolumn(character varying, character varying, character varying, character varying, integer, character varying, integer, boolean)
FUNCTION addgeometrycolumn(character varying, character varying, character varying, integer, character varying, integer)
FUNCTION addgeometrycolumn(character varying, character varying, character varying, integer, character varying, integer, boolean)
FUNCTION addgeometrycolumn(character varying, character varying, integer, character varying, integer)
FUNCTION addgeometrycolumn(character varying, character varying, integer, character varying, integer, boolean)
FUNCTION addnode(character varying, geometry)
FUNCTION addnode(character varying, geometry, boolean, boolean)
FUNCTION addoverviewconstraints(name, name, name, name, integer)
FUNCTION addoverviewconstraints(name, name, name, name, name, name, integer)
FUNCTION addpoint(geometry, geometry)
FUNCTION addpoint(geometry, geometry, integer)
FUNCTION addrastercolumn(character varying, character varying, character varying, character varying, integer, character varying[], boolean, boolean, double precision[], double precision, double precision, integer, integer, geometry)
FUNCTION addrastercolumn(character varying, character varying, character varying, integer, character varying[], boolean, boolean, double precision[], double precision, double precision, integer, integer, geometry)
FUNCTION addrastercolumn(character varying, character varying, integer, character varying[], boolean, boolean, double precision[], double precision, double precision, integer, integer, geometry)
FUNCTION addrasterconstraints(name, name, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean)
FUNCTION addrasterconstraints(name, name, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean)
FUNCTION addrasterconstraints(name, name, constraints text[])
FUNCTION addrasterconstraints(name, name, name, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean)
FUNCTION addrasterconstraints(name, name, name, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean)
FUNCTION addrasterconstraints(name, name, name, constraints text[])
FUNCTION addrasterconstraints(name, name, name, text[])
FUNCTION addrasterconstraints(name, name, text[])
FUNCTION addtopogeometrycolumn(character varying, character varying, character varying, character varying, character varying)
FUNCTION addtopogeometrycolumn(character varying, character varying, character varying, character varying, character varying, integer)
FUNCTION addtosearchpath(character varying)
FUNCTION affine(geometry, double precision, double precision, double precision, double precision, double precision, double precision)
FUNCTION affine(geometry, double precision, double precision, double precision, double precision, double precision, double precision, double precision, double precision, double precision, double precision, double precision, double precision)
FUNCTION area(geometry)
FUNCTION area2d(geometry)
FUNCTION asbinary(geometry)
FUNCTION asbinary(geometry, text)
FUNCTION asewkb(geometry)
FUNCTION asewkb(geometry, text)
FUNCTION asewkt(geometry)
FUNCTION asgml(geometry)
FUNCTION asgml(geometry, integer)
FUNCTION asgml(topogeometry)
FUNCTION asgml(topogeometry, regclass)
FUNCTION asgml(topogeometry, regclass, text)
FUNCTION asgml(topogeometry, text)
FUNCTION asgml(topogeometry, text, integer, integer)
FUNCTION asgml(topogeometry, text, integer, integer, regclass)
FUNCTION asgml(topogeometry, text, integer, integer, regclass, text)
FUNCTION asgml(topogeometry, text, integer, integer, regclass, text, integer)
FUNCTION ashexewkb(geometry)
FUNCTION ashexewkb(geometry, text)
FUNCTION askml(geometry)
FUNCTION askml(geometry, integer)
FUNCTION askml(integer, geometry, integer)
FUNCTION assvg(geometry)
FUNCTION assvg(geometry, integer)
FUNCTION assvg(geometry, integer, integer)
FUNCTION astext(geometry)
FUNCTION astopojson(topogeometry, regclass)
FUNCTION azimuth(geometry, geometry)
FUNCTION bdmpolyfromtext(text, integer)
FUNCTION bdpolyfromtext(text, integer)
FUNCTION boundary(geometry)
FUNCTION box(box3d)
FUNCTION box(geometry)
FUNCTION box2d(box3d)
FUNCTION box2d(geometry)
FUNCTION box2d(raster)
FUNCTION box2d_contain(box2d, box2d)
FUNCTION box2d_contained(box2d, box2d)
FUNCTION box2d_in(cstring)
FUNCTION box2d_intersects(box2d, box2d)
FUNCTION box2d_left(box2d, box2d)
FUNCTION box2d_out(box2d)
FUNCTION box2d_overlap(box2d, box2d)
FUNCTION box2d_overleft(box2d, box2d)
FUNCTION box2d_overright(box2d, box2d)
FUNCTION box2d_right(box2d, box2d)
FUNCTION box2d_same(box2d, box2d)
FUNCTION box2df_in(cstring)
FUNCTION box2df_out(box2df)
FUNCTION box3d(box2d)
FUNCTION box3d(geometry)
FUNCTION box3d(raster)
FUNCTION box3d_in(cstring)
FUNCTION box3d_out(box3d)
FUNCTION box3dtobox(box3d)
FUNCTION buffer(geometry, double precision)
FUNCTION buffer(geometry, double precision, integer)
FUNCTION buildarea(geometry)
FUNCTION bytea(geography)
FUNCTION bytea(geometry)
FUNCTION bytea(raster)
FUNCTION cache_bbox()
FUNCTION centroid(geometry)
FUNCTION checkauth(text, text)
FUNCTION checkauth(text, text, text)
FUNCTION checkauthtrigger()
FUNCTION cleartopogeom(topogeometry)
FUNCTION collect(geometry, geometry)
FUNCTION collect_garray(geometry[])
FUNCTION collector(geometry, geometry)
FUNCTION combine_bbox(box2d, geometry)
FUNCTION combine_bbox(box3d, geometry)
FUNCTION contains(geometry, geometry)
FUNCTION contains_2d(box2df, box2df)
FUNCTION contains_2d(box2df, geometry)
FUNCTION contains_2d(geometry, box2df)
FUNCTION convexhull(geometry)
FUNCTION copytopology(character varying, character varying)
FUNCTION createtopogeom(character varying, integer, integer)
FUNCTION createtopogeom(character varying, integer, integer, topoelementarray)
FUNCTION createtopology(character varying)
FUNCTION createtopology(character varying, integer)
FUNCTION createtopology(character varying, integer, double precision)
FUNCTION createtopology(character varying, integer, double precision, boolean)
FUNCTION crosses(geometry, geometry)
FUNCTION difference(geometry, geometry)
FUNCTION dimension(geometry)
FUNCTION disablelongtransactions()
FUNCTION disjoint(geometry, geometry)
FUNCTION distance(geometry, geometry)
FUNCTION distance_sphere(geometry, geometry)
FUNCTION distance_spheroid(geometry, geometry, spheroid)
FUNCTION dropbbox(geometry)
FUNCTION dropgeometrycolumn(character varying, character varying)
FUNCTION dropgeometrycolumn(character varying, character varying, character varying)
FUNCTION dropgeometrycolumn(character varying, character varying, character varying, character varying)
FUNCTION dropgeometrytable(character varying)
FUNCTION dropgeometrytable(character varying, character varying)
FUNCTION dropgeometrytable(character varying, character varying, character varying)
FUNCTION dropoverviewconstraints(name, name)
FUNCTION dropoverviewconstraints(name, name, name)
FUNCTION droprastercolumn(character varying, character varying)
FUNCTION droprastercolumn(character varying, character varying, character varying)
FUNCTION droprastercolumn(character varying, character varying, character varying, character varying)
FUNCTION droprasterconstraints(name, name, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean)
FUNCTION droprasterconstraints(name, name, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean)
FUNCTION droprasterconstraints(name, name, constraints text[])
FUNCTION droprasterconstraints(name, name, name, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean)
FUNCTION droprasterconstraints(name, name, name, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean, boolean)
FUNCTION droprasterconstraints(name, name, name, constraints text[])
FUNCTION droprasterconstraints(name, name, name, text[])
FUNCTION droprasterconstraints(name, name, text[])
FUNCTION droprastertable(character varying)
FUNCTION droprastertable(character varying, character varying)
FUNCTION droprastertable(character varying, character varying, character varying)
FUNCTION droptopogeometrycolumn(character varying, character varying, character varying)
FUNCTION droptopology(character varying)
FUNCTION dump(geometry)
FUNCTION dumpaswktpolygons(raster, integer)
FUNCTION dumprings(geometry)
FUNCTION enablelongtransactions()
FUNCTION endpoint(geometry)
FUNCTION envelope(geometry)
FUNCTION equals(geometry, geometry)
FUNCTION equals(topogeometry, topogeometry)
FUNCTION estimated_extent(text, text)
FUNCTION estimated_extent(text, text, text)
FUNCTION expand(box2d, double precision)
FUNCTION expand(box3d, double precision)
FUNCTION expand(geometry, double precision)
FUNCTION exteriorring(geometry)
FUNCTION find_extent(text, text)
FUNCTION find_extent(text, text, text)
FUNCTION find_srid(character varying, character varying, character varying)
FUNCTION findlayer(integer, integer)
FUNCTION findlayer(name, name, name)
FUNCTION findlayer(regclass, name)
FUNCTION findlayer(topogeometry)
FUNCTION findtopology(integer)
FUNCTION findtopology(name, name, name)
FUNCTION findtopology(regclass, name)
FUNCTION findtopology(text)
FUNCTION findtopology(topogeometry)
FUNCTION fix_geometry_columns()
FUNCTION force_2d(geometry)
FUNCTION force_3d(geometry)
FUNCTION force_3dm(geometry)
FUNCTION force_3dz(geometry)
FUNCTION force_4d(geometry)
FUNCTION force_collection(geometry)
FUNCTION forcerhr(geometry)
FUNCTION geog_brin_inclusion_add_value(internal, internal, internal, internal)
FUNCTION geography(bytea)
FUNCTION geography(geography, integer, boolean)
FUNCTION geography(geometry)
FUNCTION geography_analyze(internal)
FUNCTION geography_cmp(geography, geography)
FUNCTION geography_distance_knn(geography, geography)
FUNCTION geography_eq(geography, geography)
FUNCTION geography_ge(geography, geography)
FUNCTION geography_gist_compress(internal)
FUNCTION geography_gist_consistent(internal, geography, integer)
FUNCTION geography_gist_decompress(internal)
FUNCTION geography_gist_distance(internal, geography, integer)
FUNCTION geography_gist_join_selectivity(internal, oid, internal, smallint)
FUNCTION geography_gist_penalty(internal, internal, internal)
FUNCTION geography_gist_picksplit(internal, internal)
FUNCTION geography_gist_same(box2d, box2d, internal)
FUNCTION geography_gist_selectivity(internal, oid, internal, integer)
FUNCTION geography_gist_union(bytea, internal)
FUNCTION geography_gt(geography, geography)
FUNCTION geography_in(cstring, oid, integer)
FUNCTION geography_le(geography, geography)
FUNCTION geography_lt(geography, geography)
FUNCTION geography_out(geography)
FUNCTION geography_overlaps(geography, geography)
FUNCTION geography_recv(internal, oid, integer)
FUNCTION geography_send(geography)
FUNCTION geography_spgist_choose_nd(internal, internal)
FUNCTION geography_spgist_compress_nd(internal)
FUNCTION geography_spgist_config_nd(internal, internal)
FUNCTION geography_spgist_inner_consistent_nd(internal, internal)
FUNCTION geography_spgist_leaf_consistent_nd(internal, internal)
FUNCTION geography_spgist_picksplit_nd(internal, internal)
FUNCTION geography_typmod_in(cstring[])
FUNCTION geography_typmod_out(integer)
FUNCTION geom2d_brin_inclusion_add_value(internal, internal, internal, internal)
FUNCTION geom3d_brin_inclusion_add_value(internal, internal, internal, internal)
FUNCTION geom4d_brin_inclusion_add_value(internal, internal, internal, internal)
FUNCTION geom_accum(geometry[], geometry)
FUNCTION geomcollfromtext(text)
FUNCTION geomcollfromtext(text, integer)
FUNCTION geomcollfromwkb(bytea)
FUNCTION geomcollfromwkb(bytea, integer)
FUNCTION geometry(box2d)
FUNCTION geometry(box3d)
FUNCTION geometry(bytea)
FUNCTION geometry(geography)
FUNCTION geometry(geometry, integer, boolean)
FUNCTION geometry(path)
FUNCTION geometry(point)
FUNCTION geometry(polygon)
FUNCTION geometry(text)
FUNCTION geometry(topogeometry)
FUNCTION geometry_above(geometry, geometry)
FUNCTION geometry_analyze(internal)
FUNCTION geometry_below(geometry, geometry)
FUNCTION geometry_cmp(geometry, geometry)
FUNCTION geometry_contained_3d(geometry, geometry)
FUNCTION geometry_contained_by_raster(geometry, raster)
FUNCTION geometry_contains(geometry, geometry)
FUNCTION geometry_contains_3d(geometry, geometry)
FUNCTION geometry_contains_nd(geometry, geometry)
FUNCTION geometry_distance_box(geometry, geometry)
FUNCTION geometry_distance_box_nd(geometry, geometry)
FUNCTION geometry_distance_centroid(geometry, geometry)
FUNCTION geometry_distance_centroid_nd(geometry, geometry)
FUNCTION geometry_distance_cpa(geometry, geometry)
FUNCTION geometry_eq(geometry, geometry)
FUNCTION geometry_ge(geometry, geometry)
FUNCTION geometry_gist_compress_2d(internal)
FUNCTION geometry_gist_compress_nd(internal)
FUNCTION geometry_gist_consistent_2d(internal, geometry, integer)
FUNCTION geometry_gist_consistent_nd(internal, geometry, integer)
FUNCTION geometry_gist_decompress_2d(internal)
FUNCTION geometry_gist_decompress_nd(internal)
FUNCTION geometry_gist_distance_2d(internal, geometry, integer)
FUNCTION geometry_gist_distance_nd(internal, geometry, integer)
FUNCTION geometry_gist_joinsel_2d(internal, oid, internal, smallint)
FUNCTION geometry_gist_penalty_2d(internal, internal, internal)
FUNCTION geometry_gist_penalty_nd(internal, internal, internal)
FUNCTION geometry_gist_picksplit_2d(internal, internal)
FUNCTION geometry_gist_picksplit_nd(internal, internal)
FUNCTION geometry_gist_same_2d(geometry, geometry, internal)
FUNCTION geometry_gist_same_nd(geometry, geometry, internal)
FUNCTION geometry_gist_sel_2d(internal, oid, internal, integer)
FUNCTION geometry_gist_sortsupport_2d(internal)
FUNCTION geometry_gist_union_2d(bytea, internal)
FUNCTION geometry_gist_union_nd(bytea, internal)
FUNCTION geometry_gt(geometry, geometry)
FUNCTION geometry_hash(geometry)
FUNCTION geometry_in(cstring)
FUNCTION geometry_le(geometry, geometry)
FUNCTION geometry_left(geometry, geometry)
FUNCTION geometry_lt(geometry, geometry)
FUNCTION geometry_out(geometry)
FUNCTION geometry_overabove(geometry, geometry)
FUNCTION geometry_overbelow(geometry, geometry)
FUNCTION geometry_overlaps(geometry, geometry)
FUNCTION geometry_overlaps_3d(geometry, geometry)
FUNCTION geometry_overlaps_nd(geometry, geometry)
FUNCTION geometry_overleft(geometry, geometry)
FUNCTION geometry_overright(geometry, geometry)
FUNCTION geometry_raster_contain(geometry, raster)
FUNCTION geometry_raster_overlap(geometry, raster)
FUNCTION geometry_recv(internal)
FUNCTION geometry_right(geometry, geometry)
FUNCTION geometry_same(geometry, geometry)
FUNCTION geometry_same_3d(geometry, geometry)
FUNCTION geometry_same_nd(geometry, geometry)
FUNCTION geometry_send(geometry)
FUNCTION geometry_sortsupport(internal)
FUNCTION geometry_spgist_choose_2d(internal, internal)
FUNCTION geometry_spgist_choose_3d(internal, internal)
FUNCTION geometry_spgist_choose_nd(internal, internal)
FUNCTION geometry_spgist_compress_2d(internal)
FUNCTION geometry_spgist_compress_3d(internal)
FUNCTION geometry_spgist_compress_nd(internal)
FUNCTION geometry_spgist_config_2d(internal, internal)
FUNCTION geometry_spgist_config_3d(internal, internal)
FUNCTION geometry_spgist_config_nd(internal, internal)
FUNCTION geometry_spgist_inner_consistent_2d(internal, internal)
FUNCTION geometry_spgist_inner_consistent_3d(internal, internal)
FUNCTION geometry_spgist_inner_consistent_nd(internal, internal)
FUNCTION geometry_spgist_leaf_consistent_2d(internal, internal)
FUNCTION geometry_spgist_leaf_consistent_3d(internal, internal)
FUNCTION geometry_spgist_leaf_consistent_nd(internal, internal)
FUNCTION geometry_spgist_picksplit_2d(internal, internal)
FUNCTION geometry_spgist_picksplit_3d(internal, internal)
FUNCTION geometry_spgist_picksplit_nd(internal, internal)
FUNCTION geometry_typmod_in(cstring[])
FUNCTION geometry_typmod_out(integer)
FUNCTION geometry_within(geometry, geometry)
FUNCTION geometry_within_nd(geometry, geometry)
FUNCTION geometryfromtext(text)
FUNCTION geometryfromtext(text, integer)
FUNCTION geometryn(geometry, integer)
FUNCTION geometrytype(geography)
FUNCTION geometrytype(geometry)
FUNCTION geometrytype(topogeometry)
FUNCTION geomfromewkb(bytea)
FUNCTION geomfromewkt(text)
FUNCTION geomfromtext(text)
FUNCTION geomfromtext(text, integer)
FUNCTION geomfromwkb(bytea)
FUNCTION geomfromwkb(bytea, integer)
FUNCTION geomunion(geometry, geometry)
FUNCTION geosnoop(geometry)
FUNCTION get_proj4_from_srid(integer)
FUNCTION getbbox(geometry)
FUNCTION getedgebypoint(character varying, geometry, double precision)
FUNCTION getfacebypoint(character varying, geometry, double precision)
FUNCTION getfacecontainingpoint(text, geometry)
FUNCTION getnodebypoint(character varying, geometry, double precision)
FUNCTION getnodeedges(character varying, integer)
FUNCTION getringedges(character varying, integer, integer)
FUNCTION getsrid(geometry)
FUNCTION gettopogeomelementarray(character varying, integer, integer)
FUNCTION gettopogeomelementarray(topogeometry)
FUNCTION gettopogeomelements(character varying, integer, integer)
FUNCTION gettopogeomelements(topogeometry)
FUNCTION gettopologyid(character varying)
FUNCTION gettopologyname(integer)
FUNCTION gettopologysrid(character varying)
FUNCTION gettransactionid()
FUNCTION gidx_in(cstring)
FUNCTION gidx_out(gidx)
FUNCTION gserialized_gist_joinsel_2d(internal, oid, internal, smallint)
FUNCTION gserialized_gist_joinsel_nd(internal, oid, internal, smallint)
FUNCTION gserialized_gist_sel_2d(internal, oid, internal, integer)
FUNCTION gserialized_gist_sel_nd(internal, oid, internal, integer)
FUNCTION hasbbox(geometry)
FUNCTION interiorringn(geometry, integer)
FUNCTION intersection(geometry, geometry)
FUNCTION intersects(geometry, geometry)
FUNCTION intersects(topogeometry, topogeometry)
FUNCTION is_contained_2d(box2df, box2df)
FUNCTION is_contained_2d(box2df, geometry)
FUNCTION is_contained_2d(geometry, box2df)
FUNCTION isclosed(geometry)
FUNCTION isempty(geometry)
FUNCTION isring(geometry)
FUNCTION issimple(geometry)
FUNCTION isvalid(geometry)
FUNCTION json(geometry)
FUNCTION jsonb(geometry)
FUNCTION jtsnoop(geometry)
FUNCTION layertrigger()
FUNCTION length(geometry)
FUNCTION length2d(geometry)
FUNCTION length2d_spheroid(geometry, spheroid)
FUNCTION length3d(geometry)
FUNCTION length3d_spheroid(geometry, spheroid)
FUNCTION length_spheroid(geometry, spheroid)
FUNCTION line_interpolate_point(geometry, double precision)
FUNCTION line_locate_point(geometry, geometry)
FUNCTION line_substring(geometry, double precision, double precision)
FUNCTION linefrommultipoint(geometry)
FUNCTION linefromtext(text)
FUNCTION linefromtext(text, integer)
FUNCTION linefromwkb(bytea)
FUNCTION linefromwkb(bytea, integer)
FUNCTION linemerge(geometry)
FUNCTION linestringfromtext(text)
FUNCTION linestringfromtext(text, integer)
FUNCTION linestringfromwkb(bytea)
FUNCTION linestringfromwkb(bytea, integer)
FUNCTION locate_along_measure(geometry, double precision)
FUNCTION locate_between_measures(geometry, double precision, double precision)
FUNCTION lockrow(text, text, text)
FUNCTION lockrow(text, text, text, text)
FUNCTION lockrow(text, text, text, text, timestamp without time zone)
FUNCTION lockrow(text, text, text, text, timestamp)
FUNCTION lockrow(text, text, text, timestamp without time zone)
FUNCTION lockrow(text, text, text, timestamp)
FUNCTION longtransactionsenabled()
FUNCTION m(geometry)
FUNCTION makebox2d(geometry, geometry)
FUNCTION makebox3d(geometry, geometry)
FUNCTION makeline(geometry, geometry)
FUNCTION makeline_garray(geometry[])
FUNCTION makepoint(double precision, double precision)
FUNCTION makepoint(double precision, double precision, double precision)
FUNCTION makepoint(double precision, double precision, double precision, double precision)
FUNCTION makepointm(double precision, double precision, double precision)
FUNCTION makepolygon(geometry)
FUNCTION makepolygon(geometry, geometry[])
FUNCTION max_distance(geometry, geometry)
FUNCTION mem_size(geometry)
FUNCTION mlinefromtext(text)
FUNCTION mlinefromtext(text, integer)
FUNCTION mlinefromwkb(bytea)
FUNCTION mlinefromwkb(bytea, integer)
FUNCTION mpointfromtext(text)
FUNCTION mpointfromtext(text, integer)
FUNCTION mpointfromwkb(bytea)
FUNCTION mpointfromwkb(bytea, integer)
FUNCTION mpolyfromtext(text)
FUNCTION mpolyfromtext(text, integer)
FUNCTION mpolyfromwkb(bytea)
FUNCTION mpolyfromwkb(bytea, integer)
FUNCTION multi(geometry)
FUNCTION multilinefromwkb(bytea)
FUNCTION multilinefromwkb(bytea, integer)
FUNCTION multilinestringfromtext(text)
FUNCTION multilinestringfromtext(text, integer)
FUNCTION multipointfromtext(text)
FUNCTION multipointfromtext(text, integer)
FUNCTION multipointfromwkb(bytea)
FUNCTION multipointfromwkb(bytea, integer)
FUNCTION multipolyfromwkb(bytea)
FUNCTION multipolyfromwkb(bytea, integer)
FUNCTION multipolygonfromtext(text)
FUNCTION multipolygonfromtext(text, integer)
FUNCTION ndims(geometry)
FUNCTION noop(geometry)
FUNCTION npoints(geometry)
FUNCTION nrings(geometry)
FUNCTION numgeometries(geometry)
FUNCTION numinteriorring(geometry)
FUNCTION numinteriorrings(geometry)
FUNCTION numpoints(geometry)
FUNCTION overlaps(geometry, geometry)
FUNCTION overlaps_2d(box2df, box2df)
FUNCTION overlaps_2d(box2df, geometry)
FUNCTION overlaps_2d(geometry, box2df)
FUNCTION overlaps_geog(geography, gidx)
FUNCTION overlaps_geog(gidx, geography)
FUNCTION overlaps_geog(gidx, gidx)
FUNCTION overlaps_nd(geometry, gidx)
FUNCTION overlaps_nd(gidx, geometry)
FUNCTION overlaps_nd(gidx, gidx)
FUNCTION path(geometry)
FUNCTION perimeter2d(geometry)
FUNCTION perimeter3d(geometry)
FUNCTION pgis_asflatgeobuf_finalfn(internal)
FUNCTION pgis_asflatgeobuf_transfn(internal, anyelement)
FUNCTION pgis_asflatgeobuf_transfn(internal, anyelement, boolean)
FUNCTION pgis_asflatgeobuf_transfn(internal, anyelement, boolean, text)
FUNCTION pgis_asgeobuf_finalfn(internal)
FUNCTION pgis_asgeobuf_transfn(internal, anyelement)
FUNCTION pgis_asgeobuf_transfn(internal, anyelement, text)
FUNCTION pgis_asmvt_combinefn(internal, internal)
FUNCTION pgis_asmvt_deserialfn(bytea, internal)
FUNCTION pgis_asmvt_finalfn(internal)
FUNCTION pgis_asmvt_serialfn(internal)
FUNCTION pgis_asmvt_transfn(internal, anyelement)
FUNCTION pgis_asmvt_transfn(internal, anyelement, text)
FUNCTION pgis_asmvt_transfn(internal, anyelement, text, integer)
FUNCTION pgis_asmvt_transfn(internal, anyelement, text, integer, text)
FUNCTION pgis_asmvt_transfn(internal, anyelement, text, integer, text, text)
FUNCTION pgis_geometry_accum_finalfn(internal)
FUNCTION pgis_geometry_accum_transfn(internal, geometry)
FUNCTION pgis_geometry_accum_transfn(internal, geometry, double precision)
FUNCTION pgis_geometry_accum_transfn(internal, geometry, double precision, integer)
FUNCTION pgis_geometry_clusterintersecting_finalfn(internal)
FUNCTION pgis_geometry_clusterwithin_finalfn(internal)
FUNCTION pgis_geometry_collect_finalfn(internal)
FUNCTION pgis_geometry_coverageunion_finalfn(internal)
FUNCTION pgis_geometry_makeline_finalfn(internal)
FUNCTION pgis_geometry_polygonize_finalfn(internal)
FUNCTION pgis_geometry_union_finalfn(internal)
FUNCTION pgis_geometry_union_parallel_combinefn(internal, internal)
FUNCTION pgis_geometry_union_parallel_deserialfn(bytea, internal)
FUNCTION pgis_geometry_union_parallel_finalfn(internal)
FUNCTION pgis_geometry_union_parallel_serialfn(internal)
FUNCTION pgis_geometry_union_parallel_transfn(internal, geometry)
FUNCTION pgis_geometry_union_parallel_transfn(internal, geometry, double precision)
FUNCTION pgis_geometry_union_transfn(internal, geometry)
FUNCTION pgis_twkb_accum_finalfn(internal)
FUNCTION pgis_twkb_accum_transfn(internal, geometry, integer)
FUNCTION pgis_twkb_accum_transfn(internal, geometry, integer, bigint)
FUNCTION pgis_twkb_accum_transfn(internal, geometry, integer, bigint, boolean)
FUNCTION pgis_twkb_accum_transfn(internal, geometry, integer, bigint, boolean, boolean)
FUNCTION point(geometry)
FUNCTION point_inside_circle(geometry, double precision, double precision, double precision)
FUNCTION pointfromtext(text)
FUNCTION pointfromtext(text, integer)
FUNCTION pointfromwkb(bytea)
FUNCTION pointfromwkb(bytea, integer)
FUNCTION pointn(geometry, integer)
FUNCTION pointonsurface(geometry)
FUNCTION polyfromtext(text)
FUNCTION polyfromtext(text, integer)
FUNCTION polyfromwkb(bytea)
FUNCTION polyfromwkb(bytea, integer)
FUNCTION polygon(geometry)
FUNCTION polygonfromtext(text)
FUNCTION polygonfromtext(text, integer)
FUNCTION polygonfromwkb(bytea)
FUNCTION polygonfromwkb(bytea, integer)
FUNCTION polygonize(character varying)
FUNCTION polygonize_garray(geometry[])
FUNCTION populate_geometry_columns()
FUNCTION populate_geometry_columns(boolean)
FUNCTION populate_geometry_columns(oid)
FUNCTION populate_geometry_columns(oid, boolean)
FUNCTION populate_topology_layer()
FUNCTION postgis_addbbox(geometry)
FUNCTION postgis_cache_bbox()
FUNCTION postgis_constraint_dims(text, text, text)
FUNCTION postgis_constraint_srid(text, text, text)
FUNCTION postgis_constraint_type(text, text, text)
FUNCTION postgis_dropbbox(geometry)
FUNCTION postgis_extensions_upgrade()
FUNCTION postgis_extensions_upgrade(text)
FUNCTION postgis_full_version()
FUNCTION postgis_gdal_version()
FUNCTION postgis_geos_compiled_version()
FUNCTION postgis_geos_noop(geometry)
FUNCTION postgis_geos_version()
FUNCTION postgis_getbbox(geometry)
FUNCTION postgis_hasbbox(geometry)
FUNCTION postgis_index_supportfn(internal)
FUNCTION postgis_lib_build_date()
FUNCTION postgis_lib_revision()
FUNCTION postgis_lib_version()
FUNCTION postgis_libjson_version()
FUNCTION postgis_liblwgeom_version()
FUNCTION postgis_libprotobuf_version()
FUNCTION postgis_libxml_version()
FUNCTION postgis_noop(geometry)
FUNCTION postgis_noop(raster)
FUNCTION postgis_proj_version()
FUNCTION postgis_raster_lib_build_date()
FUNCTION postgis_raster_lib_version()
FUNCTION postgis_raster_scripts_installed()
FUNCTION postgis_scripts_build_date()
FUNCTION postgis_scripts_installed()
FUNCTION postgis_scripts_released()
FUNCTION postgis_sfcgal_full_version()
FUNCTION postgis_sfcgal_noop(geometry)
FUNCTION postgis_sfcgal_scripts_installed()
FUNCTION postgis_sfcgal_version()
FUNCTION postgis_srs(text, text)
FUNCTION postgis_srs_all()
FUNCTION postgis_srs_codes(text)
FUNCTION postgis_srs_search(geometry, text)
FUNCTION postgis_svn_version()
FUNCTION postgis_topology_scripts_installed()
FUNCTION postgis_transform_geometry(geometry, text, text, integer)
FUNCTION postgis_transform_pipeline_geometry(geometry, text, boolean, integer)
FUNCTION postgis_type_name(character varying, integer, boolean)
FUNCTION postgis_typmod_dims(integer)
FUNCTION postgis_typmod_srid(integer)
FUNCTION postgis_typmod_type(integer)
FUNCTION postgis_uses_stats()
FUNCTION postgis_version()
FUNCTION postgis_wagyu_version()
FUNCTION probe_geometry_columns()
FUNCTION raster_above(raster, raster)
FUNCTION raster_below(raster, raster)
FUNCTION raster_contain(raster, raster)
FUNCTION raster_contained(raster, raster)
FUNCTION raster_contained_by_geometry(raster, geometry)
FUNCTION raster_eq(raster, raster)
FUNCTION raster_geometry_contain(raster, geometry)
FUNCTION raster_geometry_overlap(raster, geometry)
FUNCTION raster_hash(raster)
FUNCTION raster_in(cstring)
FUNCTION raster_left(raster, raster)
FUNCTION raster_out(raster)
FUNCTION raster_overabove(raster, raster)
FUNCTION raster_overbelow(raster, raster)
FUNCTION raster_overlap(raster, raster)
FUNCTION raster_overleft(raster, raster)
FUNCTION raster_overright(raster, raster)
FUNCTION raster_right(raster, raster)
FUNCTION raster_same(raster, raster)
FUNCTION relate(geometry, geometry)
FUNCTION relate(geometry, geometry, text)
FUNCTION relationtrigger()
FUNCTION removepoint(geometry, integer)
FUNCTION removeunusedprimitives(text, geometry)
FUNCTION rename_geometry_table_constraints()
FUNCTION renametopogeometrycolumn(regclass, name, name)
FUNCTION renametopology(character varying, character varying)
FUNCTION reverse(geometry)
FUNCTION rotate(geometry, double precision)
FUNCTION rotatex(geometry, double precision)
FUNCTION rotatey(geometry, double precision)
FUNCTION rotatez(geometry, double precision)
FUNCTION scale(geometry, double precision, double precision)
FUNCTION scale(geometry, double precision, double precision, double precision)
FUNCTION se_envelopesintersect(geometry, geometry)
FUNCTION se_is3d(geometry)
FUNCTION se_ismeasured(geometry)
FUNCTION se_locatealong(geometry, double precision)
FUNCTION se_locatebetween(geometry, double precision, double precision)
FUNCTION se_m(geometry)
FUNCTION se_z(geometry)
FUNCTION segmentize(geometry, double precision)
FUNCTION setpoint(geometry, integer, geometry)
FUNCTION setsrid(geometry, integer)
FUNCTION shift_longitude(geometry)
FUNCTION simplify(geometry, double precision)
FUNCTION snaptogrid(geometry, double precision)
FUNCTION snaptogrid(geometry, double precision, double precision)
FUNCTION snaptogrid(geometry, double precision, double precision, double precision, double precision)
FUNCTION snaptogrid(geometry, geometry, double precision, double precision, double precision, double precision)
FUNCTION spheroid_in(cstring)
FUNCTION spheroid_out(spheroid)
FUNCTION srid(geometry)
FUNCTION st_3darea(geometry)
FUNCTION st_3dclosestpoint(geometry, geometry)
FUNCTION st_3dconvexhull(geometry)
FUNCTION st_3ddfullywithin(geometry, geometry, double precision)
FUNCTION st_3ddifference(geometry, geometry)
FUNCTION st_3ddistance(geometry, geometry)
FUNCTION st_3ddwithin(geometry, geometry, double precision)
FUNCTION st_3dintersection(geometry, geometry)
FUNCTION st_3dintersects(geometry, geometry)
FUNCTION st_3dlength(geometry)
FUNCTION st_3dlength_spheroid(geometry, spheroid)
FUNCTION st_3dlineinterpolatepoint(geometry, double precision)
FUNCTION st_3dlongestline(geometry, geometry)
FUNCTION st_3dmakebox(geometry, geometry)
FUNCTION st_3dmaxdistance(geometry, geometry)
FUNCTION st_3dperimeter(geometry)
FUNCTION st_3dshortestline(geometry, geometry)
FUNCTION st_3dunion(geometry, geometry)
FUNCTION st_above(raster, raster)
FUNCTION st_addband(raster, addbandarg[])
FUNCTION st_addband(raster, integer, text)
FUNCTION st_addband(raster, integer, text, double precision)
FUNCTION st_addband(raster, integer, text, double precision, double precision)
FUNCTION st_addband(raster, integer, text, integer[], double precision)
FUNCTION st_addband(raster, raster)
FUNCTION st_addband(raster, raster, integer)
FUNCTION st_addband(raster, raster, integer, integer)
FUNCTION st_addband(raster, raster[], integer)
FUNCTION st_addband(raster, raster[], integer, integer)
FUNCTION st_addband(raster, text)
FUNCTION st_addband(raster, text, double precision)
FUNCTION st_addband(raster, text, double precision, double precision)
FUNCTION st_addband(raster, text, integer[], integer, double precision)
FUNCTION st_addbbox(geometry)
FUNCTION st_addedgemodface(character varying, integer, integer, geometry)
FUNCTION st_addedgenewfaces(character varying, integer, integer, geometry)
FUNCTION st_addisoedge(character varying, integer, integer, geometry)
FUNCTION st_addisonode(character varying, integer, geometry)
FUNCTION st_addmeasure(geometry, double precision, double precision)
FUNCTION st_addpoint(geometry, geometry)
FUNCTION st_addpoint(geometry, geometry, integer)
FUNCTION st_affine(geometry, double precision, double precision, double precision, double precision, double precision, double precision)
FUNCTION st_affine(geometry, double precision, double precision, double precision, double precision, double precision, double precision, double precision, double precision, double precision, double precision, double precision, double precision)
FUNCTION st_alphashape(geometry, double precision, boolean)
FUNCTION st_angle(geometry, geometry)
FUNCTION st_angle(geometry, geometry, geometry, geometry)
FUNCTION st_approxcount(raster, boolean, double precision)
FUNCTION st_approxcount(raster, double precision)
FUNCTION st_approxcount(raster, integer, boolean, double precision)
FUNCTION st_approxcount(raster, integer, double precision)
FUNCTION st_approxcount(text, text, boolean, double precision)
FUNCTION st_approxcount(text, text, double precision)
FUNCTION st_approxcount(text, text, integer, boolean, double precision)
FUNCTION st_approxcount(text, text, integer, double precision)
FUNCTION st_approxhistogram(raster, double precision)
FUNCTION st_approxhistogram(raster, integer, boolean, double precision, integer, boolean)
FUNCTION st_approxhistogram(raster, integer, boolean, double precision, integer, double precision[], boolean)
FUNCTION st_approxhistogram(raster, integer, double precision)
FUNCTION st_approxhistogram(raster, integer, double precision, integer, boolean)
FUNCTION st_approxhistogram(raster, integer, double precision, integer, double precision[], boolean)
FUNCTION st_approxhistogram(text, text, double precision)
FUNCTION st_approxhistogram(text, text, integer, boolean, double precision, integer, boolean)
FUNCTION st_approxhistogram(text, text, integer, boolean, double precision, integer, double precision[], boolean)
FUNCTION st_approxhistogram(text, text, integer, double precision)
FUNCTION st_approxhistogram(text, text, integer, double precision, integer, boolean)
FUNCTION st_approxhistogram(text, text, integer, double precision, integer, double precision[], boolean)
FUNCTION st_approximatemedialaxis(geometry)
FUNCTION st_approxquantile(raster, boolean, double precision)
FUNCTION st_approxquantile(raster, double precision)
FUNCTION st_approxquantile(raster, double precision, double precision)
FUNCTION st_approxquantile(raster, double precision, double precision[])
FUNCTION st_approxquantile(raster, double precision[])
FUNCTION st_approxquantile(raster, integer, boolean, double precision, double precision)
FUNCTION st_approxquantile(raster, integer, boolean, double precision, double precision[])
FUNCTION st_approxquantile(raster, integer, double precision, double precision)
FUNCTION st_approxquantile(raster, integer, double precision, double precision[])
FUNCTION st_approxquantile(text, text, boolean, double precision)
FUNCTION st_approxquantile(text, text, double precision)
FUNCTION st_approxquantile(text, text, double precision, double precision)
FUNCTION st_approxquantile(text, text, double precision, double precision[])
FUNCTION st_approxquantile(text, text, double precision[])
FUNCTION st_approxquantile(text, text, integer, boolean, double precision, double precision)
FUNCTION st_approxquantile(text, text, integer, boolean, double precision, double precision[])
FUNCTION st_approxquantile(text, text, integer, double precision, double precision)
FUNCTION st_approxquantile(text, text, integer, double precision, double precision[])
FUNCTION st_approxsummarystats(raster, boolean, double precision)
FUNCTION st_approxsummarystats(raster, double precision)
FUNCTION st_approxsummarystats(raster, integer, boolean, double precision)
FUNCTION st_approxsummarystats(raster, integer, double precision)
FUNCTION st_approxsummarystats(text, text, boolean)
FUNCTION st_approxsummarystats(text, text, double precision)
FUNCTION st_approxsummarystats(text, text, integer, boolean, double precision)
FUNCTION st_approxsummarystats(text, text, integer, double precision)
FUNCTION st_area(geography)
FUNCTION st_area(geography, boolean)
FUNCTION st_area(geometry)
FUNCTION st_area(text)
FUNCTION st_area2d(geometry)
FUNCTION st_asbinary(geography)
FUNCTION st_asbinary(geography, text)
FUNCTION st_asbinary(geometry)
FUNCTION st_asbinary(geometry, text)
FUNCTION st_asbinary(raster)
FUNCTION st_asbinary(raster, boolean)
FUNCTION st_asbinary(text)
FUNCTION st_asencodedpolyline(geometry, integer)
FUNCTION st_asewkb(geometry)
FUNCTION st_asewkb(geometry, text)
FUNCTION st_asewkt(geography)
FUNCTION st_asewkt(geography, integer)
FUNCTION st_asewkt(geometry)
FUNCTION st_asewkt(geometry, integer)
FUNCTION st_asewkt(text)
FUNCTION st_asgdalraster(raster, text, text[], integer)
FUNCTION st_asgeojson(geography)
FUNCTION st_asgeojson(geography, integer)
FUNCTION st_asgeojson(geography, integer, integer)
FUNCTION st_asgeojson(geometry)
FUNCTION st_asgeojson(geometry, integer)
FUNCTION st_asgeojson(geometry, integer, integer)
FUNCTION st_asgeojson(integer, geography)
FUNCTION st_asgeojson(integer, geography, integer)
FUNCTION st_asgeojson(integer, geography, integer, integer)
FUNCTION st_asgeojson(integer, geometry)
FUNCTION st_asgeojson(integer, geometry, integer)
FUNCTION st_asgeojson(integer, geometry, integer, integer)
FUNCTION st_asgeojson(record, text, integer, boolean)
FUNCTION st_asgeojson(text)
FUNCTION st_asgml(geography)
FUNCTION st_asgml(geography, integer)
FUNCTION st_asgml(geography, integer, integer)
FUNCTION st_asgml(geography, integer, integer, text, text)
FUNCTION st_asgml(geometry)
FUNCTION st_asgml(geometry, integer)
FUNCTION st_asgml(geometry, integer, integer)
FUNCTION st_asgml(integer, geography)
FUNCTION st_asgml(integer, geography, integer)
FUNCTION st_asgml(integer, geography, integer, integer)
FUNCTION st_asgml(integer, geography, integer, integer, text)
FUNCTION st_asgml(integer, geography, integer, integer, text, text)
FUNCTION st_asgml(integer, geometry)
FUNCTION st_asgml(integer, geometry, integer)
FUNCTION st_asgml(integer, geometry, integer, integer)
FUNCTION st_asgml(integer, geometry, integer, integer, text)
FUNCTION st_asgml(integer, geometry, integer, integer, text, text)
FUNCTION st_asgml(text)
FUNCTION st_ashexewkb(geometry)
FUNCTION st_ashexewkb(geometry, text)
FUNCTION st_ashexwkb(raster, boolean)
FUNCTION st_asjpeg(raster, integer, integer)
FUNCTION st_asjpeg(raster, integer, text[])
FUNCTION st_asjpeg(raster, integer[], integer)
FUNCTION st_asjpeg(raster, integer[], text[])
FUNCTION st_asjpeg(raster, text[])
FUNCTION st_askml(geography)
FUNCTION st_askml(geography, integer, text)
FUNCTION st_askml(geometry)
FUNCTION st_askml(geometry, integer, text)
FUNCTION st_askml(integer, geography, integer)
FUNCTION st_askml(integer, geography, integer, text)
FUNCTION st_askml(integer, geometry, integer)
FUNCTION st_askml(integer, geometry, integer, text)
FUNCTION st_askml(text)
FUNCTION st_aslatlontext(geometry)
FUNCTION st_aslatlontext(geometry, text)
FUNCTION st_asmarc21(geometry, text)
FUNCTION st_asmvtgeom(geometry, box2d, integer, integer, boolean)
FUNCTION st_aspect(raster, integer, raster, text, text, boolean)
FUNCTION st_aspect(raster, integer, text)
FUNCTION st_aspect(raster, integer, text, boolean)
FUNCTION st_aspect(raster, integer, text, text, boolean)
FUNCTION st_aspng(raster, integer, integer)
FUNCTION st_aspng(raster, integer, text[])
FUNCTION st_aspng(raster, integer[], integer)
FUNCTION st_aspng(raster, integer[], text[])
FUNCTION st_aspng(raster, text[])
FUNCTION st_asraster(geometry, double precision, double precision, double precision, double precision, text, double precision, double precision, double precision, double precision, boolean)
FUNCTION st_asraster(geometry, double precision, double precision, double precision, double precision, text[], double precision[], double precision[], double precision, double precision, boolean)
FUNCTION st_asraster(geometry, double precision, double precision, text, double precision, double precision, double precision, double precision, double precision, double precision)
FUNCTION st_asraster(geometry, double precision, double precision, text, double precision, double precision, double precision, double precision, double precision, double precision, boolean)
FUNCTION st_asraster(geometry, double precision, double precision, text[], double precision[], double precision[], double precision, double precision, double precision, double precision, boolean)
FUNCTION st_asraster(geometry, integer, integer, double precision, double precision, text, double precision, double precision, double precision, double precision)
FUNCTION st_asraster(geometry, integer, integer, double precision, double precision, text, double precision, double precision, double precision, double precision, boolean)
FUNCTION st_asraster(geometry, integer, integer, double precision, double precision, text[], double precision[], double precision[], double precision, double precision)
FUNCTION st_asraster(geometry, integer, integer, double precision, double precision, text[], double precision[], double precision[], double precision, double precision, boolean)
FUNCTION st_asraster(geometry, integer, integer, text, double precision, double precision, double precision, double precision, double precision, double precision)
FUNCTION st_asraster(geometry, integer, integer, text, double precision, double precision, double precision, double precision, double precision, double precision, boolean)
FUNCTION st_asraster(geometry, integer, integer, text[], double precision[], double precision[], double precision, double precision, double precision, double precision)
FUNCTION st_asraster(geometry, integer, integer, text[], double precision[], double precision[], double precision, double precision, double precision, double precision, boolean)
FUNCTION st_asraster(geometry, raster, text, double precision, double precision)
FUNCTION st_asraster(geometry, raster, text, double precision, double precision, boolean)
FUNCTION st_asraster(geometry, raster, text[], double precision[], double precision[], boolean)
FUNCTION st_assvg(geography)
FUNCTION st_assvg(geography, integer)
FUNCTION st_assvg(geography, integer, integer)
FUNCTION st_assvg(geometry)
FUNCTION st_assvg(geometry, integer)
FUNCTION st_assvg(geometry, integer, integer)
FUNCTION st_assvg(text)
FUNCTION st_astext(bytea)
FUNCTION st_astext(geography)
FUNCTION st_astext(geography, integer)
FUNCTION st_astext(geometry)
FUNCTION st_astext(geometry, integer)
FUNCTION st_astext(text)
FUNCTION st_astiff(raster, integer[], text, integer)
FUNCTION st_astiff(raster, integer[], text[], integer)
FUNCTION st_astiff(raster, text, integer)
FUNCTION st_astiff(raster, text[], integer)
FUNCTION st_astwkb(geometry, integer, bigint, boolean, boolean)
FUNCTION st_astwkb(geometry, integer, integer, integer, boolean, boolean)
FUNCTION st_astwkb(geometry[], bigint[], integer, integer, integer, boolean, boolean)
FUNCTION st_aswkb(raster, boolean)
FUNCTION st_asx3d(geometry)
FUNCTION st_asx3d(geometry, integer)
FUNCTION st_asx3d(geometry, integer, integer)
FUNCTION st_azimuth(geography, geography)
FUNCTION st_azimuth(geometry, geometry)
FUNCTION st_band(raster, integer)
FUNCTION st_band(raster, integer[])
FUNCTION st_band(raster, text, character)
FUNCTION st_bandfilesize(raster, integer)
FUNCTION st_bandfiletimestamp(raster, integer)
FUNCTION st_bandisnodata(raster)
FUNCTION st_bandisnodata(raster, boolean)
FUNCTION st_bandisnodata(raster, integer)
FUNCTION st_bandisnodata(raster, integer, boolean)
FUNCTION st_bandmetadata(raster, integer)
FUNCTION st_bandmetadata(raster, integer[])
FUNCTION st_bandnodatavalue(raster)
FUNCTION st_bandnodatavalue(raster, integer)
FUNCTION st_bandpath(raster)
FUNCTION st_bandpath(raster, integer)
FUNCTION st_bandpixeltype(raster)
FUNCTION st_bandpixeltype(raster, integer)
FUNCTION st_bandsurface(raster, integer)
FUNCTION st_bdmpolyfromtext(text, integer)
FUNCTION st_bdpolyfromtext(text, integer)
FUNCTION st_below(raster, raster)
FUNCTION st_boundary(geometry)
FUNCTION st_boundingdiagonal(geometry, boolean)
FUNCTION st_box(box3d)
FUNCTION st_box(geometry)
FUNCTION st_box2d(box3d)
FUNCTION st_box2d(geometry)
FUNCTION st_box2d_contain(box2d, box2d)
FUNCTION st_box2d_contained(box2d, box2d)
FUNCTION st_box2d_in(cstring)
FUNCTION st_box2d_intersects(box2d, box2d)
FUNCTION st_box2d_left(box2d, box2d)
FUNCTION st_box2d_out(box2d)
FUNCTION st_box2d_overlap(box2d, box2d)
FUNCTION st_box2d_overleft(box2d, box2d)
FUNCTION st_box2d_overright(box2d, box2d)
FUNCTION st_box2d_right(box2d, box2d)
FUNCTION st_box2d_same(box2d, box2d)
FUNCTION st_box2dfromgeohash(text, integer)
FUNCTION st_box3d(box2d)
FUNCTION st_box3d(geometry)
FUNCTION st_box3d_in(cstring)
FUNCTION st_box3d_out(box3d)
FUNCTION st_buffer(geography, double precision)
FUNCTION st_buffer(geography, double precision, integer)
FUNCTION st_buffer(geography, double precision, text)
FUNCTION st_buffer(geometry, double precision)
FUNCTION st_buffer(geometry, double precision, cstring)
FUNCTION st_buffer(geometry, double precision, integer)
FUNCTION st_buffer(geometry, double precision, text)
FUNCTION st_buffer(text, double precision)
FUNCTION st_buffer(text, double precision, integer)
FUNCTION st_buffer(text, double precision, text)
FUNCTION st_buildarea(geometry)
FUNCTION st_bytea(geometry)
FUNCTION st_bytea(raster)
FUNCTION st_cache_bbox()
FUNCTION st_centroid(geography, boolean)
FUNCTION st_centroid(geometry)
FUNCTION st_centroid(text)
FUNCTION st_chaikinsmoothing(geometry, integer, boolean)
FUNCTION st_changeedgegeom(character varying, integer, geometry)
FUNCTION st_cleangeometry(geometry)
FUNCTION st_clip(raster, geometry, boolean)
FUNCTION st_clip(raster, geometry, double precision, boolean)
FUNCTION st_clip(raster, geometry, double precision[], boolean)
FUNCTION st_clip(raster, integer, geometry, boolean)
FUNCTION st_clip(raster, integer, geometry, double precision, boolean)
FUNCTION st_clip(raster, integer, geometry, double precision[], boolean)
FUNCTION st_clip(raster, integer[], geometry, double precision[], boolean)
FUNCTION st_clipbybox2d(geometry, box2d)
FUNCTION st_closestpoint(geography, geography, boolean)
FUNCTION st_closestpoint(geometry, geometry)
FUNCTION st_closestpoint(text, text)
FUNCTION st_closestpointofapproach(geometry, geometry)
FUNCTION st_clusterdbscan(geometry, double precision, integer)
FUNCTION st_clusterintersecting(geometry[])
FUNCTION st_clusterintersectingwin(geometry)
FUNCTION st_clusterkmeans(geometry, integer)
FUNCTION st_clusterkmeans(geometry, integer, double precision)
FUNCTION st_clusterwithin(geometry[], double precision)
FUNCTION st_clusterwithinwin(geometry, double precision)
FUNCTION st_collect(geometry, geometry)
FUNCTION st_collect(geometry[])
FUNCTION st_collect_garray(geometry[])
FUNCTION st_collectionextract(geometry)
FUNCTION st_collectionextract(geometry, integer)
FUNCTION st_collectionhomogenize(geometry)
FUNCTION st_collector(geometry, geometry)
FUNCTION st_colormap(raster, integer, text, text)
FUNCTION st_colormap(raster, text, text)
FUNCTION st_combine_bbox(box2d, geometry)
FUNCTION st_combine_bbox(box3d, geometry)
FUNCTION st_combinebbox(box2d, geometry)
FUNCTION st_combinebbox(box3d, box3d)
FUNCTION st_combinebbox(box3d, geometry)
FUNCTION st_concavehull(geometry, double precision, boolean)
FUNCTION st_concavehull(geometry, float)
FUNCTION st_concavehull(geometry, float, boolean)
FUNCTION st_constraineddelaunaytriangles(geometry)
FUNCTION st_contain(raster, raster)
FUNCTION st_contained(raster, raster)
FUNCTION st_contains(geometry, geometry)
FUNCTION st_contains(geometry, raster, integer)
FUNCTION st_contains(raster, geometry, integer)
FUNCTION st_contains(raster, integer, geometry)
FUNCTION st_contains(raster, integer, raster, integer)
FUNCTION st_contains(raster, raster)
FUNCTION st_containsproperly(geometry, geometry)
FUNCTION st_containsproperly(raster, integer, raster, integer)
FUNCTION st_containsproperly(raster, raster)
FUNCTION st_contour(raster, integer, double precision, double precision, double precision[], boolean)
FUNCTION st_convexhull(geometry)
FUNCTION st_convexhull(raster)
FUNCTION st_coorddim(geometry)
FUNCTION st_count(raster, boolean)
FUNCTION st_count(raster, integer, boolean)
FUNCTION st_count(text, text, boolean)
FUNCTION st_count(text, text, integer, boolean)
FUNCTION st_coverageinvalidedges(geometry, double precision)
FUNCTION st_coverageinvalidlocations(geometry, double precision)
FUNCTION st_coveragesimplify(geometry, double precision, boolean)
FUNCTION st_coverageunion(geometry[])
FUNCTION st_coveredby(geography, geography)
FUNCTION st_coveredby(geometry, geometry)
FUNCTION st_coveredby(raster, integer, raster, integer)
FUNCTION st_coveredby(raster, raster)
FUNCTION st_coveredby(text, text)
FUNCTION st_covers(geography, geography)
FUNCTION st_covers(geometry, geometry)
FUNCTION st_covers(raster, integer, raster, integer)
FUNCTION st_covers(raster, raster)
FUNCTION st_covers(text, text)
FUNCTION st_cpawithin(geometry, geometry, double precision)
FUNCTION st_createoverview(regclass, name, integer, text)
FUNCTION st_createtopogeo(character varying, geometry)
FUNCTION st_crosses(geometry, geometry)
FUNCTION st_curvetoline(geometry)
FUNCTION st_curvetoline(geometry, double precision, integer, integer)
FUNCTION st_curvetoline(geometry, integer)
FUNCTION st_delaunaytriangles(geometry, double precision, integer)
FUNCTION st_dfullywithin(geometry, geometry, double precision)
FUNCTION st_dfullywithin(raster, integer, raster, integer, double precision)
FUNCTION st_dfullywithin(raster, raster, double precision)
FUNCTION st_difference(geometry, geometry)
FUNCTION st_difference(geometry, geometry, double precision)
FUNCTION st_dimension(geometry)
FUNCTION st_disjoint(geometry, geometry)
FUNCTION st_disjoint(raster, integer, raster, integer)
FUNCTION st_disjoint(raster, raster)
FUNCTION st_distance(geography, geography)
FUNCTION st_distance(geography, geography, boolean)
FUNCTION st_distance(geography, geography, double precision, boolean)
FUNCTION st_distance(geometry, geometry)
FUNCTION st_distance(text, text)
FUNCTION st_distance_sphere(geometry, geometry)
FUNCTION st_distance_spheroid(geometry, geometry, spheroid)
FUNCTION st_distancecpa(geometry, geometry)
FUNCTION st_distancesphere(geometry, geometry)
FUNCTION st_distancesphere(geometry, geometry, double precision)
FUNCTION st_distancespheroid(geometry, geometry)
FUNCTION st_distancespheroid(geometry, geometry, spheroid)
FUNCTION st_distinct4ma(double precision[], integer[], text[])
FUNCTION st_distinct4ma(double precision[], text, text[])
FUNCTION st_distinct4ma(double precision[][][], integer[][], userargs text[])
FUNCTION st_distinct4ma(float[][], text, args text[])
FUNCTION st_dropbbox(geometry)
FUNCTION st_dump(geometry)
FUNCTION st_dumpaspolygons(raster)
FUNCTION st_dumpaspolygons(raster, integer)
FUNCTION st_dumpaspolygons(raster, integer, boolean)
FUNCTION st_dumppoints(geometry)
FUNCTION st_dumprings(geometry)
FUNCTION st_dumpsegments(geometry)
FUNCTION st_dumpvalues(raster, integer, boolean)
FUNCTION st_dumpvalues(raster, integer[], boolean)
FUNCTION st_dwithin(geography, geography, double precision, boolean)
FUNCTION st_dwithin(geometry, geometry, double precision)
FUNCTION st_dwithin(raster, integer, raster, integer, double precision)
FUNCTION st_dwithin(raster, raster, double precision)
FUNCTION st_dwithin(text, text, double precision)
FUNCTION st_endpoint(geometry)
FUNCTION st_envelope(geometry)
FUNCTION st_envelope(raster)
FUNCTION st_equals(geometry, geometry)
FUNCTION st_estimated_extent(text, text)
FUNCTION st_estimated_extent(text, text, text)
FUNCTION st_estimatedextent(text, text)
FUNCTION st_estimatedextent(text, text, text)
FUNCTION st_estimatedextent(text, text, text, boolean)
FUNCTION st_expand(box2d, double precision)
FUNCTION st_expand(box2d, double precision, double precision)
FUNCTION st_expand(box3d, double precision)
FUNCTION st_expand(box3d, double precision, double precision, double precision)
FUNCTION st_expand(geometry, double precision)
FUNCTION st_expand(geometry, double precision, double precision, double precision, double precision)
FUNCTION st_exteriorring(geometry)
FUNCTION st_extrude(geometry, double precision, double precision, double precision)
FUNCTION st_filterbym(geometry, double precision, double precision, boolean)
FUNCTION st_find_extent(text, text)
FUNCTION st_find_extent(text, text, text)
FUNCTION st_findextent(text, text)
FUNCTION st_findextent(text, text, text)
FUNCTION st_flipcoordinates(geometry)
FUNCTION st_force2d(geometry)
FUNCTION st_force3d(geometry)
FUNCTION st_force3d(geometry, double precision)
FUNCTION st_force3dm(geometry)
FUNCTION st_force3dm(geometry, double precision)
FUNCTION st_force3dz(geometry)
FUNCTION st_force3dz(geometry, double precision)
FUNCTION st_force4d(geometry)
FUNCTION st_force4d(geometry, double precision, double precision)
FUNCTION st_force_2d(geometry)
FUNCTION st_force_3d(geometry)
FUNCTION st_force_3dm(geometry)
FUNCTION st_force_3dz(geometry)
FUNCTION st_force_4d(geometry)
FUNCTION st_force_collection(geometry)
FUNCTION st_forcecollection(geometry)
FUNCTION st_forcecurve(geometry)
FUNCTION st_forcelhr(geometry)
FUNCTION st_forcepolygonccw(geometry)
FUNCTION st_forcepolygoncw(geometry)
FUNCTION st_forcerhr(geometry)
FUNCTION st_forcesfs(geometry)
FUNCTION st_forcesfs(geometry, text)
FUNCTION st_frechetdistance(geometry, geometry, double precision)
FUNCTION st_fromflatgeobuf(anyelement, bytea)
FUNCTION st_fromflatgeobuftotable(text, text, bytea)
FUNCTION st_fromgdalraster(bytea, integer)
FUNCTION st_gdaldrivers()
FUNCTION st_gdalopenoptions(text[])
FUNCTION st_generatepoints(geometry, integer)
FUNCTION st_generatepoints(geometry, integer, integer)
FUNCTION st_generatepoints(geometry, numeric)
FUNCTION st_geogfromtext(text)
FUNCTION st_geogfromwkb(bytea)
FUNCTION st_geographyfromtext(text)
FUNCTION st_geohash(geography, integer)
FUNCTION st_geohash(geometry)
FUNCTION st_geohash(geometry, integer)
FUNCTION st_geom_accum(geometry[], geometry)
FUNCTION st_geomcollfromtext(text)
FUNCTION st_geomcollfromtext(text, integer)
FUNCTION st_geomcollfromwkb(bytea)
FUNCTION st_geomcollfromwkb(bytea, integer)
FUNCTION st_geometricmedian(geometry, double precision, integer, boolean)
FUNCTION st_geometry(box2d)
FUNCTION st_geometry(box3d)
FUNCTION st_geometry(bytea)
FUNCTION st_geometry(text)
FUNCTION st_geometry_analyze(internal)
FUNCTION st_geometry_cmp(geometry, geometry)
FUNCTION st_geometry_eq(geometry, geometry)
FUNCTION st_geometry_ge(geometry, geometry)
FUNCTION st_geometry_gt(geometry, geometry)
FUNCTION st_geometry_in(cstring)
FUNCTION st_geometry_le(geometry, geometry)
FUNCTION st_geometry_lt(geometry, geometry)
FUNCTION st_geometry_out(geometry)
FUNCTION st_geometry_recv(internal)
FUNCTION st_geometry_send(geometry)
FUNCTION st_geometryfromtext(text)
FUNCTION st_geometryfromtext(text, integer)
FUNCTION st_geometryn(geometry, integer)
FUNCTION st_geometrytype(geometry)
FUNCTION st_geometrytype(topogeometry)
FUNCTION st_geomfromewkb(bytea)
FUNCTION st_geomfromewkt(text)
FUNCTION st_geomfromgeohash(text, integer)
FUNCTION st_geomfromgeojson(json)
FUNCTION st_geomfromgeojson(jsonb)
FUNCTION st_geomfromgeojson(text)
FUNCTION st_geomfromgml(text)
FUNCTION st_geomfromgml(text, integer)
FUNCTION st_geomfromkml(text)
FUNCTION st_geomfrommarc21(text)
FUNCTION st_geomfromtext(text)
FUNCTION st_geomfromtext(text, integer)
FUNCTION st_geomfromtwkb(bytea)
FUNCTION st_geomfromwkb(bytea)
FUNCTION st_geomfromwkb(bytea, integer)
FUNCTION st_georeference(raster)
FUNCTION st_georeference(raster, text)
FUNCTION st_geotransform(raster)
FUNCTION st_getfaceedges(character varying, integer)
FUNCTION st_getfacegeometry(character varying, integer)
FUNCTION st_gmltosql(text)
FUNCTION st_gmltosql(text, integer)
FUNCTION st_grayscale(rastbandarg[], text)
FUNCTION st_grayscale(raster, integer, integer, integer, text)
FUNCTION st_hasarc(geometry)
FUNCTION st_hasbbox(geometry)
FUNCTION st_hasnoband(raster)
FUNCTION st_hasnoband(raster, integer)
FUNCTION st_hausdorffdistance(geometry, geometry)
FUNCTION st_hausdorffdistance(geometry, geometry, double precision)
FUNCTION st_height(raster)
FUNCTION st_hexagon(double precision, integer, integer, geometry)
FUNCTION st_hexagongrid(double precision, geometry)
FUNCTION st_hillshade(raster, integer, raster, text, double precision, double precision, double precision, double precision, boolean)
FUNCTION st_hillshade(raster, integer, text, double precision, double precision, double precision, double precision, boolean)
FUNCTION st_hillshade(raster, integer, text, float, float, float, float)
FUNCTION st_hillshade(raster, integer, text, float, float, float, float, boolean)
FUNCTION st_histogram(ext, text, integer, integer, boolean)
FUNCTION st_histogram(raster, integer, boolean, integer, boolean)
FUNCTION st_histogram(raster, integer, boolean, integer, double precision[], boolean)
FUNCTION st_histogram(raster, integer, integer, boolean)
FUNCTION st_histogram(raster, integer, integer, double precision[], boolean)
FUNCTION st_histogram(text, text, integer, boolean, integer, boolean)
FUNCTION st_histogram(text, text, integer, boolean, integer, double precision[], boolean)
FUNCTION st_histogram(text, text, integer, integer, boolean)
FUNCTION st_histogram(text, text, integer, integer, double precision[], boolean)
FUNCTION st_inittopogeo(character varying)
FUNCTION st_interiorringn(geometry, integer)
FUNCTION st_interpolatepoint(geometry, geometry)
FUNCTION st_interpolateraster(geometry, text, raster, integer)
FUNCTION st_intersection(geography, geography)
FUNCTION st_intersection(geometry, geometry)
FUNCTION st_intersection(geometry, geometry, double precision)
FUNCTION st_intersection(geometry, raster)
FUNCTION st_intersection(geometry, raster, integer)
FUNCTION st_intersection(raster, geometry)
FUNCTION st_intersection(raster, geometry, regprocedure)
FUNCTION st_intersection(raster, geometry, text, regprocedure)
FUNCTION st_intersection(raster, integer, geometry)
FUNCTION st_intersection(raster, integer, geometry, regprocedure)
FUNCTION st_intersection(raster, integer, geometry, text, regprocedure)
FUNCTION st_intersection(raster, integer, raster, integer, double precision)
FUNCTION st_intersection(raster, integer, raster, integer, double precision[])
FUNCTION st_intersection(raster, integer, raster, integer, regprocedure)
FUNCTION st_intersection(raster, integer, raster, integer, text, double precision)
FUNCTION st_intersection(raster, integer, raster, integer, text, double precision[])
FUNCTION st_intersection(raster, integer, raster, integer, text, regprocedure)
FUNCTION st_intersection(raster, raster, double precision)
FUNCTION st_intersection(raster, raster, double precision[])
FUNCTION st_intersection(raster, raster, integer, integer)
FUNCTION st_intersection(raster, raster, regprocedure)
FUNCTION st_intersection(raster, raster, text, double precision)
FUNCTION st_intersection(raster, raster, text, double precision[])
FUNCTION st_intersection(raster, raster, text, regprocedure)
FUNCTION st_intersection(text, text)
FUNCTION st_intersects(geography, geography)
FUNCTION st_intersects(geometry, geometry)
FUNCTION st_intersects(geometry, raster)
FUNCTION st_intersects(geometry, raster, boolean)
FUNCTION st_intersects(geometry, raster, integer)
FUNCTION st_intersects(geometry, raster, integer, boolean)
FUNCTION st_intersects(raster, boolean, geometry)
FUNCTION st_intersects(raster, geometry)
FUNCTION st_intersects(raster, geometry, integer)
FUNCTION st_intersects(raster, integer, boolean, geometry)
FUNCTION st_intersects(raster, integer, geometry)
FUNCTION st_intersects(raster, integer, raster, integer)
FUNCTION st_intersects(raster, raster)
FUNCTION st_intersects(text, text)
FUNCTION st_invdistweight4ma(double precision[], integer[], text[])
FUNCTION st_invdistweight4ma(double precision[][][], integer[][], userargs text[])
FUNCTION st_inversetransformpipeline(geometry, text, integer)
FUNCTION st_isclosed(geometry)
FUNCTION st_iscollection(geometry)
FUNCTION st_iscoveragetile(raster, raster, integer, integer)
FUNCTION st_isempty(geometry)
FUNCTION st_isempty(raster)
FUNCTION st_isplanar(geometry)
FUNCTION st_ispolygonccw(geometry)
FUNCTION st_ispolygoncw(geometry)
FUNCTION st_isring(geometry)
FUNCTION st_issimple(geometry)
FUNCTION st_issolid(geometry)
FUNCTION st_isvalid(geometry)
FUNCTION st_isvalid(geometry, integer)
FUNCTION st_isvaliddetail(geometry)
FUNCTION st_isvaliddetail(geometry, integer)
FUNCTION st_isvalidreason(geometry)
FUNCTION st_isvalidreason(geometry, integer)
FUNCTION st_isvalidtrajectory(geometry)
FUNCTION st_largestemptycircle(geometry, double precision, geometry)
FUNCTION st_left(raster, raster)
FUNCTION st_length(geography)
FUNCTION st_length(geography, boolean)
FUNCTION st_length(geometry)
FUNCTION st_length(text)
FUNCTION st_length2d(geometry)
FUNCTION st_length2d_spheroid(geometry, spheroid)
FUNCTION st_length2dspheroid(geometry, spheroid)
FUNCTION st_length3d(geometry)
FUNCTION st_length_spheroid(geometry, spheroid)
FUNCTION st_length_spheroid3d(geometry, spheroid)
FUNCTION st_lengthspheroid(geometry, spheroid)
FUNCTION st_letters(text, json)
FUNCTION st_line_interpolate_point(geometry, double precision)
FUNCTION st_line_locate_point(geometry, geometry)
FUNCTION st_line_substring(geometry, double precision, double precision)
FUNCTION st_linecrossingdirection(geometry, geometry)
FUNCTION st_lineextend(geometry, double precision, double precision)
FUNCTION st_linefromencodedpolyline(text, integer)
FUNCTION st_linefrommultipoint(geometry)
FUNCTION st_linefromtext(text)
FUNCTION st_linefromtext(text, integer)
FUNCTION st_linefromwkb(bytea)
FUNCTION st_linefromwkb(bytea, integer)
FUNCTION st_lineinterpolatepoint(geography, double precision, boolean)
FUNCTION st_lineinterpolatepoint(geometry, double precision)
FUNCTION st_lineinterpolatepoint(text, double precision)
FUNCTION st_lineinterpolatepoints(geography, double precision, boolean, boolean)
FUNCTION st_lineinterpolatepoints(geometry, double precision, boolean)
FUNCTION st_lineinterpolatepoints(text, double precision)
FUNCTION st_linelocatepoint(geography, geography, boolean)
FUNCTION st_linelocatepoint(geometry, geometry)
FUNCTION st_linelocatepoint(text, text)
FUNCTION st_linemerge(geometry)
FUNCTION st_linemerge(geometry, boolean)
FUNCTION st_linestringfromwkb(bytea)
FUNCTION st_linestringfromwkb(bytea, integer)
FUNCTION st_linesubstring(geography, double precision, double precision)
FUNCTION st_linesubstring(geometry, double precision, double precision)
FUNCTION st_linesubstring(text, double precision, double precision)
FUNCTION st_linetocurve(geometry)
FUNCTION st_locate_along_measure(geometry, double precision)
FUNCTION st_locate_between_measures(geometry, double precision, double precision)
FUNCTION st_locatealong(geometry, double precision, double precision)
FUNCTION st_locatebetween(geometry, double precision, double precision, double precision)
FUNCTION st_locatebetweenelevations(geometry, double precision, double precision)
FUNCTION st_longestline(geometry, geometry)
FUNCTION st_m(geometry)
FUNCTION st_makebox2d(geometry, geometry)
FUNCTION st_makebox3d(geometry, geometry)
FUNCTION st_makeemptycoverage(integer, integer, integer, integer, double precision, double precision, double precision, double precision, double precision, double precision, integer)
FUNCTION st_makeemptyraster(integer, integer, double precision, double precision, double precision)
FUNCTION st_makeemptyraster(integer, integer, double precision, double precision, double precision, double precision, double precision, double precision)
FUNCTION st_makeemptyraster(integer, integer, double precision, double precision, double precision, double precision, double precision, double precision, integer)
FUNCTION st_makeemptyraster(raster)
FUNCTION st_makeenvelope(double precision, double precision, double precision, double precision, integer)
FUNCTION st_makeline(geometry, geometry)
FUNCTION st_makeline(geometry[])
FUNCTION st_makeline_garray(geometry[])
FUNCTION st_makepoint(double precision, double precision)
FUNCTION st_makepoint(double precision, double precision, double precision)
FUNCTION st_makepoint(double precision, double precision, double precision, double precision)
FUNCTION st_makepointm(double precision, double precision, double precision)
FUNCTION st_makepolygon(geometry)
FUNCTION st_makepolygon(geometry, geometry[])
FUNCTION st_makesolid(geometry)
FUNCTION st_makevalid(geometry)
FUNCTION st_makevalid(geometry, text)
FUNCTION st_mapalgebra(rastbandarg[], regprocedure, text, text, raster, integer, integer, text[])
FUNCTION st_mapalgebra(rastbandarg[], regprocedure, text, text, raster, integer, integer, userargs text[])
FUNCTION st_mapalgebra(raster, integer, raster, integer, regprocedure, text, text, raster, integer, integer, text[])
FUNCTION st_mapalgebra(raster, integer, raster, integer, regprocedure, text, text, raster, integer, integer, userargs text[])
FUNCTION st_mapalgebra(raster, integer, raster, integer, text, text, text, text, text, double precision)
FUNCTION st_mapalgebra(raster, integer, regprocedure, double precision [][], boolean, text, text, raster, userargs text[])
FUNCTION st_mapalgebra(raster, integer, regprocedure, double precision[], boolean, text, text, raster, text[])
FUNCTION st_mapalgebra(raster, integer, regprocedure, text, text, raster, integer, integer, text[])
FUNCTION st_mapalgebra(raster, integer, regprocedure, text, text, raster, integer, integer, userargs text[])
FUNCTION st_mapalgebra(raster, integer, text, text, double precision)
FUNCTION st_mapalgebra(raster, integer, text, text, text)
FUNCTION st_mapalgebra(raster, integer[], regprocedure, text, text, raster, integer, integer, text[])
FUNCTION st_mapalgebra(raster, integer[], regprocedure, text, text, raster, integer, integer, userargs text[])
FUNCTION st_mapalgebra(raster, raster, text, text, text, text, text, double precision)
FUNCTION st_mapalgebra(raster, text, text, double precision)
FUNCTION st_mapalgebra(raster, text, text, text)
FUNCTION st_mapalgebraexpr(raster, integer, raster, integer, text, text, text, text, text, double precision)
FUNCTION st_mapalgebraexpr(raster, integer, text, text, double precision)
FUNCTION st_mapalgebraexpr(raster, integer, text, text, text)
FUNCTION st_mapalgebraexpr(raster, raster, text, text, text, text, text, double precision)
FUNCTION st_mapalgebraexpr(raster, text, text, double precision)
FUNCTION st_mapalgebraexpr(raster, text, text, text)
FUNCTION st_mapalgebrafct(raster, integer, raster, integer, regprocedure, text, text, text[])
FUNCTION st_mapalgebrafct(raster, integer, raster, integer, regprocedure, text, text, userargs text[])
FUNCTION st_mapalgebrafct(raster, integer, regprocedure)
FUNCTION st_mapalgebrafct(raster, integer, regprocedure, args text[])
FUNCTION st_mapalgebrafct(raster, integer, regprocedure, text[])
FUNCTION st_mapalgebrafct(raster, integer, text, regprocedure)
FUNCTION st_mapalgebrafct(raster, integer, text, regprocedure, args text[])
FUNCTION st_mapalgebrafct(raster, integer, text, regprocedure, text[])
FUNCTION st_mapalgebrafct(raster, raster, regprocedure, text, text, text[])
FUNCTION st_mapalgebrafct(raster, raster, regprocedure, text, text, userargs text[])
FUNCTION st_mapalgebrafct(raster, raster, regprocedure, text[])
FUNCTION st_mapalgebrafct(raster, regprocedure)
FUNCTION st_mapalgebrafct(raster, regprocedure, args text[])
FUNCTION st_mapalgebrafct(raster, regprocedure, text[])
FUNCTION st_mapalgebrafct(raster, text, regprocedure)
FUNCTION st_mapalgebrafct(raster, text, regprocedure, args text[])
FUNCTION st_mapalgebrafct(raster, text, regprocedure, text[])
FUNCTION st_mapalgebrafctngb(raster, integer, text, integer, integer, regprocedure, text, args text[])
FUNCTION st_mapalgebrafctngb(raster, integer, text, integer, integer, regprocedure, text, text[])
FUNCTION st_max4ma(double precision[], integer[], text[])
FUNCTION st_max4ma(double precision[], text, text[])
FUNCTION st_max4ma(double precision[][][], integer[][], userargs text[])
FUNCTION st_max4ma(float[][], text, args text[])
FUNCTION st_max_distance(geometry, geometry)
FUNCTION st_maxdistance(geometry, geometry)
FUNCTION st_maximuminscribedcircle(geometry)
FUNCTION st_mean4ma(double precision[], integer[], text[])
FUNCTION st_mean4ma(double precision[], text, text[])
FUNCTION st_mean4ma(double precision[][][], integer[][], userargs text[])
FUNCTION st_mean4ma(float[][], text, args text[])
FUNCTION st_mem_size(geometry)
FUNCTION st_memsize(geometry)
FUNCTION st_memsize(raster)
FUNCTION st_metadata(raster)
FUNCTION st_min4ma(double precision[], integer[], text[])
FUNCTION st_min4ma(double precision[], text, text[])
FUNCTION st_min4ma(double precision[][][], integer[][], userargs text[])
FUNCTION st_min4ma(float[][], text, args text[])
FUNCTION st_minconvexhull(raster, integer)
FUNCTION st_mindist4ma(double precision[], integer[], text[])
FUNCTION st_mindist4ma(double precision[][][], integer[][], userargs text[])
FUNCTION st_minimumboundingcircle(geometry)
FUNCTION st_minimumboundingcircle(geometry, integer)
FUNCTION st_minimumboundingradius(geometry)
FUNCTION st_minimumclearance(geometry)
FUNCTION st_minimumclearanceline(geometry)
FUNCTION st_minkowskisum(geometry, geometry)
FUNCTION st_minpossibleval(text)
FUNCTION st_minpossiblevalue(text)
FUNCTION st_mlinefromtext(text)
FUNCTION st_mlinefromtext(text, integer)
FUNCTION st_mlinefromwkb(bytea)
FUNCTION st_mlinefromwkb(bytea, integer)
FUNCTION st_modedgeheal(character varying, integer, integer)
FUNCTION st_modedgesplit(character varying, integer, geometry)
FUNCTION st_moveisonode(character varying, integer, geometry)
FUNCTION st_mpointfromtext(text)
FUNCTION st_mpointfromtext(text, integer)
FUNCTION st_mpointfromwkb(bytea)
FUNCTION st_mpointfromwkb(bytea, integer)
FUNCTION st_mpolyfromtext(text)
FUNCTION st_mpolyfromtext(text, integer)
FUNCTION st_mpolyfromwkb(bytea)
FUNCTION st_mpolyfromwkb(bytea, integer)
FUNCTION st_multi(geometry)
FUNCTION st_multilinefromwkb(bytea)
FUNCTION st_multilinestringfromtext(text)
FUNCTION st_multilinestringfromtext(text, integer)
FUNCTION st_multipointfromtext(text)
FUNCTION st_multipointfromwkb(bytea)
FUNCTION st_multipointfromwkb(bytea, integer)
FUNCTION st_multipolyfromwkb(bytea)
FUNCTION st_multipolyfromwkb(bytea, integer)
FUNCTION st_multipolygonfromtext(text)
FUNCTION st_multipolygonfromtext(text, integer)
FUNCTION st_ndims(geometry)
FUNCTION st_nearestvalue(raster, geometry, boolean)
FUNCTION st_nearestvalue(raster, integer, geometry, boolean)
FUNCTION st_nearestvalue(raster, integer, integer, boolean)
FUNCTION st_nearestvalue(raster, integer, integer, integer, boolean)
FUNCTION st_neighborhood(raster, geometry, integer, boolean)
FUNCTION st_neighborhood(raster, geometry, integer, integer, boolean)
FUNCTION st_neighborhood(raster, integer, geometry, integer, boolean)
FUNCTION st_neighborhood(raster, integer, geometry, integer, integer, boolean)
FUNCTION st_neighborhood(raster, integer, integer, integer, boolean)
FUNCTION st_neighborhood(raster, integer, integer, integer, integer, boolean)
FUNCTION st_neighborhood(raster, integer, integer, integer, integer, integer, boolean)
FUNCTION st_newedgeheal(character varying, integer, integer)
FUNCTION st_newedgessplit(character varying, integer, geometry)
FUNCTION st_node(geometry)
FUNCTION st_noop(geometry)
FUNCTION st_normalize(geometry)
FUNCTION st_notsamealignmentreason(raster, raster)
FUNCTION st_npoints(geometry)
FUNCTION st_nrings(geometry)
FUNCTION st_numbands(raster)
FUNCTION st_numgeometries(geometry)
FUNCTION st_numinteriorring(geometry)
FUNCTION st_numinteriorrings(geometry)
FUNCTION st_numpatches(geometry)
FUNCTION st_numpoints(geometry)
FUNCTION st_offsetcurve(geometry, double precision, text)
FUNCTION st_optimalalphashape(geometry, boolean, integer)
FUNCTION st_orderingequals(geometry, geometry)
FUNCTION st_orientation(geometry)
FUNCTION st_orientedenvelope(geometry)
FUNCTION st_overabove(raster, raster)
FUNCTION st_overbelow(raster, raster)
FUNCTION st_overlap(raster, raster)
FUNCTION st_overlaps(geometry, geometry)
FUNCTION st_overlaps(geometry, raster, integer)
FUNCTION st_overlaps(raster, geometry, integer)
FUNCTION st_overlaps(raster, integer, geometry)
FUNCTION st_overlaps(raster, integer, raster, integer)
FUNCTION st_overlaps(raster, raster)
FUNCTION st_overleft(raster, raster)
FUNCTION st_overright(raster, raster)
FUNCTION st_patchn(geometry, integer)
FUNCTION st_perimeter(geography)
FUNCTION st_perimeter(geography, boolean)
FUNCTION st_perimeter(geometry)
FUNCTION st_perimeter2d(geometry)
FUNCTION st_perimeter3d(geometry)
FUNCTION st_pixelascentroid(raster, integer, integer)
FUNCTION st_pixelascentroids(raster, integer, boolean)
FUNCTION st_pixelaspoint(raster, integer, integer)
FUNCTION st_pixelaspoints(raster, integer, boolean)
FUNCTION st_pixelaspolygon(raster, integer, integer)
FUNCTION st_pixelaspolygon(raster, integer, integer, integer)
FUNCTION st_pixelaspolygons(raster)
FUNCTION st_pixelaspolygons(raster, integer)
FUNCTION st_pixelaspolygons(raster, integer, boolean)
FUNCTION st_pixelheight(raster)
FUNCTION st_pixelofvalue(raster, double precision, boolean)
FUNCTION st_pixelofvalue(raster, double precision[], boolean)
FUNCTION st_pixelofvalue(raster, integer, double precision, boolean)
FUNCTION st_pixelofvalue(raster, integer, double precision[], boolean)
FUNCTION st_pixelwidth(raster)
FUNCTION st_point(double precision, double precision)
FUNCTION st_point(double precision, double precision, integer)
FUNCTION st_point_inside_circle(geometry, double precision, double precision, double precision)
FUNCTION st_pointfromgeohash(text, integer)
FUNCTION st_pointfromtext(text)
FUNCTION st_pointfromtext(text, integer)
FUNCTION st_pointfromwkb(bytea)
FUNCTION st_pointfromwkb(bytea, integer)
FUNCTION st_pointinsidecircle(geometry, double precision, double precision, double precision)
FUNCTION st_pointm(double precision, double precision, double precision, integer)
FUNCTION st_pointn(geometry, integer)
FUNCTION st_pointonsurface(geometry)
FUNCTION st_points(geometry)
FUNCTION st_pointz(double precision, double precision, double precision, integer)
FUNCTION st_pointzm(double precision, double precision, double precision, double precision, integer)
FUNCTION st_polyfromtext(text)
FUNCTION st_polyfromtext(text, integer)
FUNCTION st_polyfromwkb(bytea)
FUNCTION st_polyfromwkb(bytea, integer)
FUNCTION st_polygon(geometry, integer)
FUNCTION st_polygon(raster)
FUNCTION st_polygon(raster, integer)
FUNCTION st_polygonfromtext(text)
FUNCTION st_polygonfromtext(text, integer)
FUNCTION st_polygonfromwkb(bytea)
FUNCTION st_polygonfromwkb(bytea, integer)
FUNCTION st_polygonize(geometry[])
FUNCTION st_polygonize_garray(geometry[])
FUNCTION st_project(geography, double precision, double precision)
FUNCTION st_project(geography, geography, double precision)
FUNCTION st_project(geometry, double precision, double precision)
FUNCTION st_project(geometry, geometry, double precision)
FUNCTION st_quantile(raster, boolean, double precision)
FUNCTION st_quantile(raster, double precision)
FUNCTION st_quantile(raster, double precision[])
FUNCTION st_quantile(raster, integer, boolean, double precision)
FUNCTION st_quantile(raster, integer, boolean, double precision[])
FUNCTION st_quantile(raster, integer, double precision)
FUNCTION st_quantile(raster, integer, double precision[])
FUNCTION st_quantile(text, text, boolean, double precision)
FUNCTION st_quantile(text, text, double precision)
FUNCTION st_quantile(text, text, double precision[])
FUNCTION st_quantile(text, text, integer, boolean, double precision)
FUNCTION st_quantile(text, text, integer, boolean, double precision[])
FUNCTION st_quantile(text, text, integer, double precision)
FUNCTION st_quantile(text, text, integer, double precision[])
FUNCTION st_quantizecoordinates(geometry, integer, integer, integer, integer)
FUNCTION st_range4ma(double precision[], integer[], text[])
FUNCTION st_range4ma(double precision[], text, text[])
FUNCTION st_range4ma(double precision[][][], integer[][], userargs text[])
FUNCTION st_range4ma(float[][], text, args text[])
FUNCTION st_raster2worldcoord(raster, integer, integer)
FUNCTION st_raster2worldcoordx(raster, integer)
FUNCTION st_raster2worldcoordx(raster, integer, integer)
FUNCTION st_raster2worldcoordy(raster, integer)
FUNCTION st_raster2worldcoordy(raster, integer, integer)
FUNCTION st_rastertoworldcoord(raster, integer, integer)
FUNCTION st_rastertoworldcoord(raster, integer, integer, double precision)
FUNCTION st_rastertoworldcoordx(raster, integer)
FUNCTION st_rastertoworldcoordx(raster, integer, integer)
FUNCTION st_rastertoworldcoordy(raster, integer)
FUNCTION st_rastertoworldcoordy(raster, integer, integer)
FUNCTION st_rastfromhexwkb(text)
FUNCTION st_rastfromwkb(bytea)
FUNCTION st_reclass(raster, integer, text, text, double precision)
FUNCTION st_reclass(raster, reclassarg[])
FUNCTION st_reclass(raster, reclassargset reclassarg[])
FUNCTION st_reclass(raster, text, text)
FUNCTION st_reduceprecision(geometry, double precision)
FUNCTION st_relate(geometry, geometry)
FUNCTION st_relate(geometry, geometry, integer)
FUNCTION st_relate(geometry, geometry, text)
FUNCTION st_relatematch(text, text)
FUNCTION st_remedgemodface(character varying, integer)
FUNCTION st_remedgenewface(character varying, integer)
FUNCTION st_remisonode(character varying, integer)
FUNCTION st_removeisoedge(character varying, integer)
FUNCTION st_removeisonode(character varying, integer)
FUNCTION st_removepoint(geometry, integer)
FUNCTION st_removerepeatedpoints(geometry)
FUNCTION st_removerepeatedpoints(geometry, double precision)
FUNCTION st_resample(raster, double precision, double precision, double precision, double precision, double precision, double precision, text, double precision)
FUNCTION st_resample(raster, integer, double precision, double precision, double precision, double precision, double precision, double precision, text, double precision)
FUNCTION st_resample(raster, integer, integer, double precision, double precision, double precision, double precision, text, double precision)
FUNCTION st_resample(raster, integer, integer, integer, double precision, double precision, double precision, double precision, text, double precision)
FUNCTION st_resample(raster, raster, boolean, text, double precision)
FUNCTION st_resample(raster, raster, text, double precision)
FUNCTION st_resample(raster, raster, text, double precision, boolean)
FUNCTION st_rescale(raster, double precision, double precision, text, double precision)
FUNCTION st_rescale(raster, double precision, text, double precision)
FUNCTION st_resize(raster, double precision, double precision, text, double precision)
FUNCTION st_resize(raster, integer, integer, text, double precision)
FUNCTION st_resize(raster, text, text, text, double precision)
FUNCTION st_reskew(raster, double precision, double precision, text, double precision)
FUNCTION st_reskew(raster, double precision, text, double precision)
FUNCTION st_retile(regclass, name, geometry, double precision, double precision, integer, integer, text)
FUNCTION st_reverse(geometry)
FUNCTION st_right(raster, raster)
FUNCTION st_rotate(geometry, double precision)
FUNCTION st_rotate(geometry, double precision, double precision, double precision)
FUNCTION st_rotate(geometry, double precision, geometry)
FUNCTION st_rotatex(geometry, double precision)
FUNCTION st_rotatey(geometry, double precision)
FUNCTION st_rotatez(geometry, double precision)
FUNCTION st_rotation(raster)
FUNCTION st_roughness(raster, integer, raster, text, boolean)
FUNCTION st_roughness(raster, integer, text, boolean)
FUNCTION st_same(raster, raster)
FUNCTION st_samealignment(double precision, double precision, double precision, double precision, double precision, double precision, double precision, double precision, double precision, double precision, double precision, double precision)
FUNCTION st_samealignment(raster, raster)
FUNCTION st_scale(geometry, double precision, double precision)
FUNCTION st_scale(geometry, double precision, double precision, double precision)
FUNCTION st_scale(geometry, geometry)
FUNCTION st_scale(geometry, geometry, geometry)
FUNCTION st_scalex(raster)
FUNCTION st_scaley(raster)
FUNCTION st_scroll(geometry, geometry)
FUNCTION st_segmentize(geography, double precision)
FUNCTION st_segmentize(geometry, double precision)
FUNCTION st_setbandindex(raster, integer, integer, boolean)
FUNCTION st_setbandisnodata(raster)
FUNCTION st_setbandisnodata(raster, integer)
FUNCTION st_setbandnodatavalue(raster, double precision)
FUNCTION st_setbandnodatavalue(raster, integer, double precision)
FUNCTION st_setbandnodatavalue(raster, integer, double precision, boolean)
FUNCTION st_setbandpath(raster, integer, text, integer, boolean)
FUNCTION st_seteffectivearea(geometry, double precision)
FUNCTION st_seteffectivearea(geometry, double precision, integer)
FUNCTION st_setgeoreference(raster, double precision, double precision, double precision, double precision, double precision, double precision)
FUNCTION st_setgeoreference(raster, text)
FUNCTION st_setgeoreference(raster, text, text)
FUNCTION st_setgeotransform(raster, double precision, double precision, double precision, double precision, double precision, double precision)
FUNCTION st_setm(raster, geometry, text, integer)
FUNCTION st_setpoint(geometry, integer, geometry)
FUNCTION st_setrotation(raster, double precision)
FUNCTION st_setscale(raster, double precision)
FUNCTION st_setscale(raster, double precision, double precision)
FUNCTION st_setskew(raster, double precision)
FUNCTION st_setskew(raster, double precision, double precision)
FUNCTION st_setsrid(geography, integer)
FUNCTION st_setsrid(geometry, integer)
FUNCTION st_setsrid(raster, integer)
FUNCTION st_setupperleft(raster, double precision, double precision)
FUNCTION st_setvalue(raster, geometry, double precision)
FUNCTION st_setvalue(raster, integer, geometry, double precision)
FUNCTION st_setvalue(raster, integer, integer, double precision)
FUNCTION st_setvalue(raster, integer, integer, integer, double precision)
FUNCTION st_setvalues(raster, integer, geomval[], boolean)
FUNCTION st_setvalues(raster, integer, integer, integer, double precision[], boolean[], boolean)
FUNCTION st_setvalues(raster, integer, integer, integer, double precision[], double precision, boolean)
FUNCTION st_setvalues(raster, integer, integer, integer, double precision[][], boolean[][], boolean)
FUNCTION st_setvalues(raster, integer, integer, integer, double precision[][], double precision, boolean)
FUNCTION st_setvalues(raster, integer, integer, integer, integer, double precision, boolean)
FUNCTION st_setvalues(raster, integer, integer, integer, integer, integer, double precision, boolean)
FUNCTION st_setz(raster, geometry, text, integer)
FUNCTION st_sharedpaths(geometry, geometry)
FUNCTION st_shift_longitude(geometry)
FUNCTION st_shiftlongitude(geometry)
FUNCTION st_shortestline(geography, geography, boolean)
FUNCTION st_shortestline(geometry, geometry)
FUNCTION st_shortestline(text, text)
FUNCTION st_simplify(geometry, double precision)
FUNCTION st_simplify(geometry, double precision, boolean)
FUNCTION st_simplify(topogeometry, double precision)
FUNCTION st_simplifypolygonhull(geometry, double precision, boolean)
FUNCTION st_simplifypreservetopology(geometry, double precision)
FUNCTION st_simplifyvw(geometry, double precision)
FUNCTION st_skewx(raster)
FUNCTION st_skewy(raster)
FUNCTION st_slope(raster, integer, raster, text, text, double precision, boolean)
FUNCTION st_slope(raster, integer, text)
FUNCTION st_slope(raster, integer, text, boolean)
FUNCTION st_slope(raster, integer, text, text, double precision, boolean)
FUNCTION st_snap(geometry, geometry, double precision)
FUNCTION st_snaptogrid(geometry, double precision)
FUNCTION st_snaptogrid(geometry, double precision, double precision)
FUNCTION st_snaptogrid(geometry, double precision, double precision, double precision, double precision)
FUNCTION st_snaptogrid(geometry, geometry, double precision, double precision, double precision, double precision)
FUNCTION st_snaptogrid(raster, double precision, double precision, double precision, double precision, text, double precision)
FUNCTION st_snaptogrid(raster, double precision, double precision, double precision, text, double precision)
FUNCTION st_snaptogrid(raster, double precision, double precision, text, double precision, double precision, double precision)
FUNCTION st_spheroid_in(cstring)
FUNCTION st_spheroid_out(spheroid)
FUNCTION st_split(geometry, geometry)
FUNCTION st_square(double precision, integer, integer, geometry)
FUNCTION st_squaregrid(double precision, geometry)
FUNCTION st_srid(geography)
FUNCTION st_srid(geometry)
FUNCTION st_srid(raster)
FUNCTION st_srid(topogeometry)
FUNCTION st_startpoint(geometry)
FUNCTION st_stddev4ma(double precision[], integer[], text[])
FUNCTION st_stddev4ma(double precision[], text, text[])
FUNCTION st_stddev4ma(double precision[][][], integer[][], userargs text[])
FUNCTION st_stddev4ma(float[][], text, args text[])
FUNCTION st_straightskeleton(geometry)
FUNCTION st_subdivide(geometry, integer)
FUNCTION st_subdivide(geometry, integer, double precision)
FUNCTION st_sum4ma(double precision[], integer[], text[])
FUNCTION st_sum4ma(double precision[], text, text[])
FUNCTION st_sum4ma(double precision[][][], integer[][], userargs text[])
FUNCTION st_sum4ma(float[][], text, args text[])
FUNCTION st_summary(geography)
FUNCTION st_summary(geometry)
FUNCTION st_summary(raster)
FUNCTION st_summarystats(raster, boolean)
FUNCTION st_summarystats(raster, integer, boolean)
FUNCTION st_summarystats(text, text, boolean)
FUNCTION st_summarystats(text, text, integer, boolean)
FUNCTION st_swapordinates(geometry, cstring)
FUNCTION st_symdifference(geometry, geometry)
FUNCTION st_symdifference(geometry, geometry, double precision)
FUNCTION st_symmetricdifference(geometry, geometry)
FUNCTION st_tesselate(geometry)
FUNCTION st_text(geometry)
FUNCTION st_tile(raster, integer, integer)
FUNCTION st_tile(raster, integer, integer, boolean, double precision)
FUNCTION st_tile(raster, integer, integer, integer)
FUNCTION st_tile(raster, integer, integer, integer, boolean, double precision)
FUNCTION st_tile(raster, integer, integer, integer[])
FUNCTION st_tile(raster, integer[], integer, integer)
FUNCTION st_tile(raster, integer[], integer, integer, boolean, double precision)
FUNCTION st_tileenvelope(integer, integer, integer, geometry)
FUNCTION st_tileenvelope(integer, integer, integer, geometry, double precision)
FUNCTION st_touches(geometry, geometry)
FUNCTION st_touches(geometry, raster, integer)
FUNCTION st_touches(raster, geometry, integer)
FUNCTION st_touches(raster, integer, geometry)
FUNCTION st_touches(raster, integer, raster, integer)
FUNCTION st_touches(raster, raster)
FUNCTION st_tpi(raster, integer, raster, text, boolean)
FUNCTION st_tpi(raster, integer, text, boolean)
FUNCTION st_transform(geometry, integer)
FUNCTION st_transform(geometry, text)
FUNCTION st_transform(geometry, text, integer)
FUNCTION st_transform(geometry, text, text)
FUNCTION st_transform(raster, integer, double precision, double precision, text, double precision)
FUNCTION st_transform(raster, integer, double precision, text, double precision)
FUNCTION st_transform(raster, integer, text, double precision, double precision, double precision)
FUNCTION st_transform(raster, raster, text, double precision)
FUNCTION st_transformpipeline(geometry, text, integer)
FUNCTION st_translate(geometry, double precision, double precision)
FUNCTION st_translate(geometry, double precision, double precision, double precision)
FUNCTION st_transscale(geometry, double precision, double precision, double precision, double precision)
FUNCTION st_tri(raster, integer, raster, text, boolean)
FUNCTION st_tri(raster, integer, text, boolean)
FUNCTION st_triangulatepolygon(geometry)
FUNCTION st_unaryunion(geometry)
FUNCTION st_unaryunion(geometry, double precision)
FUNCTION st_union(geometry, geometry)
FUNCTION st_union(geometry, geometry, double precision)
FUNCTION st_union(geometry[])
FUNCTION st_unite_garray(geometry[])
FUNCTION st_upperleftx(raster)
FUNCTION st_upperlefty(raster)
FUNCTION st_value(raster, geometry)
FUNCTION st_value(raster, geometry, boolean)
FUNCTION st_value(raster, geometry, double precision)
FUNCTION st_value(raster, integer, geometry)
FUNCTION st_value(raster, integer, geometry, boolean)
FUNCTION st_value(raster, integer, geometry, boolean, text)
FUNCTION st_value(raster, integer, geometry, double precision)
FUNCTION st_value(raster, integer, integer)
FUNCTION st_value(raster, integer, integer, boolean)
FUNCTION st_value(raster, integer, integer, integer)
FUNCTION st_value(raster, integer, integer, integer, boolean)
FUNCTION st_valuecount(raster, double precision, double precision)
FUNCTION st_valuecount(raster, double precision[], double precision)
FUNCTION st_valuecount(raster, integer, boolean, double precision, double precision)
FUNCTION st_valuecount(raster, integer, boolean, double precision[], double precision)
FUNCTION st_valuecount(raster, integer, double precision, double precision)
FUNCTION st_valuecount(raster, integer, double precision[], double precision)
FUNCTION st_valuecount(text, text, double precision, double precision)
FUNCTION st_valuecount(text, text, double precision[], double precision)
FUNCTION st_valuecount(text, text, integer, boolean, double precision, double precision)
FUNCTION st_valuecount(text, text, integer, boolean, double precision[], double precision)
FUNCTION st_valuecount(text, text, integer, double precision, double precision)
FUNCTION st_valuecount(text, text, integer, double precision[], double precision)
FUNCTION st_valuepercent(raster, double precision, double precision)
FUNCTION st_valuepercent(raster, double precision[], double precision)
FUNCTION st_valuepercent(raster, integer, boolean, double precision, double precision)
FUNCTION st_valuepercent(raster, integer, boolean, double precision[], double precision)
FUNCTION st_valuepercent(raster, integer, double precision, double precision)
FUNCTION st_valuepercent(raster, integer, double precision[], double precision)
FUNCTION st_valuepercent(text, text, double precision, double precision)
FUNCTION st_valuepercent(text, text, double precision[], double precision)
FUNCTION st_valuepercent(text, text, integer, boolean, double precision, double precision)
FUNCTION st_valuepercent(text, text, integer, boolean, double precision[], double precision)
FUNCTION st_valuepercent(text, text, integer, double precision, double precision)
FUNCTION st_valuepercent(text, text, integer, double precision[], double precision)
FUNCTION st_volume(geometry)
FUNCTION st_voronoi(geometry, geometry, double precision, boolean)
FUNCTION st_voronoilines(geometry, double precision, geometry)
FUNCTION st_voronoipolygons(geometry, double precision, geometry)
FUNCTION st_width(raster)
FUNCTION st_within(geometry, geometry)
FUNCTION st_within(raster, integer, raster, integer)
FUNCTION st_within(raster, raster)
FUNCTION st_wkbtosql(bytea)
FUNCTION st_wkttosql(text)
FUNCTION st_world2rastercoord(raster, double precision, double precision)
FUNCTION st_world2rastercoord(raster, geometry)
FUNCTION st_world2rastercoordx(raster, double precision)
FUNCTION st_world2rastercoordx(raster, double precision, double precision)
FUNCTION st_world2rastercoordx(raster, geometry)
FUNCTION st_world2rastercoordy(raster, double precision)
FUNCTION st_world2rastercoordy(raster, double precision, double precision)
FUNCTION st_world2rastercoordy(raster, geometry)
FUNCTION st_worldtorastercoord(raster, double precision, double precision)
FUNCTION st_worldtorastercoord(raster, geometry)
FUNCTION st_worldtorastercoordx(raster, double precision)
FUNCTION st_worldtorastercoordx(raster, double precision, double precision)
FUNCTION st_worldtorastercoordx(raster, geometry)
FUNCTION st_worldtorastercoordy(raster, double precision)
FUNCTION st_worldtorastercoordy(raster, double precision, double precision)
FUNCTION st_worldtorastercoordy(raster, geometry)
FUNCTION st_wrapx(geometry, double precision, double precision)
FUNCTION st_x(geometry)
FUNCTION st_xmax(box3d)
FUNCTION st_xmin(box3d)
FUNCTION st_y(geometry)
FUNCTION st_ymax(box3d)
FUNCTION st_ymin(box3d)
FUNCTION st_z(geometry)
FUNCTION st_zmax(box3d)
FUNCTION st_zmflag(geometry)
FUNCTION st_zmin(box3d)
FUNCTION startpoint(geometry)
FUNCTION summary(geometry)
FUNCTION symdifference(geometry, geometry)
FUNCTION symmetricdifference(geometry, geometry)
FUNCTION text(geometry)
FUNCTION topoelement(topogeometry)
FUNCTION topoelementarray_append(topoelementarray, topoelement)
FUNCTION topogeo_addgeometry(character varying, geometry, double precision)
FUNCTION topogeo_addlinestring(character varying, geometry, double precision)
FUNCTION topogeo_addpoint(character varying, geometry, double precision)
FUNCTION topogeo_addpolygon(character varying, geometry, double precision)
FUNCTION topogeom_addelement(topogeometry, topoelement)
FUNCTION topogeom_addtopogeom(topogeometry, topogeometry)
FUNCTION topogeom_remelement(topogeometry, topoelement)
FUNCTION topologysummary(character varying)
FUNCTION totopogeom(geometry, character varying, integer, double precision)
FUNCTION totopogeom(geometry, topogeometry, double precision)
FUNCTION touches(geometry, geometry)
FUNCTION transform(geometry, integer)
FUNCTION transform_geometry(geometry, text, text, integer)
FUNCTION translate(geometry, double precision, double precision)
FUNCTION translate(geometry, double precision, double precision, double precision)
FUNCTION transscale(geometry, double precision, double precision, double precision, double precision)
FUNCTION unite_garray(geometry[])
FUNCTION unlockrows(text)
FUNCTION updategeometrysrid(character varying, character varying, character varying, character varying, integer)
FUNCTION updategeometrysrid(character varying, character varying, character varying, integer)
FUNCTION updategeometrysrid(character varying, character varying, integer)
FUNCTION updaterastersrid(name, name, integer)
FUNCTION updaterastersrid(name, name, name, integer)
FUNCTION validatetopology(character varying)
FUNCTION validatetopology(character varying, geometry)
FUNCTION validatetopologyrelation(character varying)
FUNCTION within(geometry, geometry)
FUNCTION x(geometry)
FUNCTION xmax(box3d)
FUNCTION xmin(box3d)
FUNCTION y(geometry)
FUNCTION ymax(box3d)
FUNCTION ymin(box3d)
FUNCTION z(geometry)
FUNCTION zmax(box3d)
FUNCTION zmflag(geometry)
FUNCTION zmin(box3d)
OPERATOR &&
OPERATOR &&&
OPERATOR &/&
OPERATOR &<
OPERATOR &<|
OPERATOR &>
OPERATOR <
OPERATOR <#>
OPERATOR <->
OPERATOR <<
OPERATOR <<->>
OPERATOR <<@
OPERATOR <<|
OPERATOR <=
OPERATOR =
OPERATOR >
OPERATOR >=
OPERATOR >>
OPERATOR @
OPERATOR @>>
OPERATOR @@
OPERATOR public brin_geography_inclusion_ops
OPERATOR public brin_geometry_inclusion_ops_2d
OPERATOR public brin_geometry_inclusion_ops_3d
OPERATOR public brin_geometry_inclusion_ops_4d
OPERATOR public btree_geography_ops
OPERATOR public btree_geometry_ops
OPERATOR public gist_geography_ops
OPERATOR public gist_geometry_ops_2d
OPERATOR public gist_geometry_ops_nd
OPERATOR public hash_geometry_ops
OPERATOR public hash_raster_ops
OPERATOR public spgist_geography_ops_nd
OPERATOR public spgist_geometry_ops_2d
OPERATOR public spgist_geometry_ops_3d
OPERATOR public spgist_geometry_ops_nd
OPERATOR |&>
OPERATOR |=|
OPERATOR |>>
OPERATOR ~
OPERATOR ~=
OPERATOR ~==
OPERATOR ~~
OPERATOR ~~=
OPERATOR&&&(geometry,geometry)
OPERATOR&&&(geometry,gidx)
OPERATOR&&&(gidx,geometry)
OPERATOR&&&(gidx,gidx)
OPERATOR&&(box2df,box2df)
OPERATOR&&(box2df,geometry)
OPERATOR&&(geography,geography)
OPERATOR&&(geography,gidx)
OPERATOR&&(geometry,box2df)
OPERATOR&&(geometry,geometry)
OPERATOR&&(gidx,geography)
OPERATOR&&(gidx,gidx)
OPERATOR&/&(geometry,geometry)
OPERATOR&<(geometry,geometry)
OPERATOR&<|(geometry,geometry)
OPERATOR&>(geometry,geometry)
OPERATOR<#>(geometry,geometry)
OPERATOR<(geography,geography)
OPERATOR<(geometry,geometry)
OPERATOR<->(geography,geography)
OPERATOR<->(geometry,geometry)
OPERATOR<<(geometry,geometry)
OPERATOR<<->>(geometry,geometry)
OPERATOR<<@(geometry,geometry)
OPERATOR<<|(geometry,geometry)
OPERATOR<=(geography,geography)
OPERATOR<=(geometry,geometry)
OPERATOR=(geography,geography)
OPERATOR=(geometry,geometry)
OPERATOR>(geography,geography)
OPERATOR>(geometry,geometry)
OPERATOR>=(geography,geography)
OPERATOR>=(geometry,geometry)
OPERATOR>>(geometry,geometry)
OPERATOR@(box2df,box2df)
OPERATOR@(box2df,geometry)
OPERATOR@(geometry,box2df)
OPERATOR@(geometry,geometry)
OPERATOR@>>(geometry,geometry)
OPERATOR@@(geometry,geometry)
OPERATORCLASS brin_geography_inclusion_ops
OPERATORCLASS brin_geometry_inclusion_ops_2d
OPERATORCLASS brin_geometry_inclusion_ops_3d
OPERATORCLASS brin_geometry_inclusion_ops_4d
OPERATORCLASS btree_geography_ops
OPERATORCLASS btree_geometry_ops
OPERATORCLASS gist_geography_ops
OPERATORCLASS gist_geometry_ops_2d
OPERATORCLASS gist_geometry_ops_nd
OPERATORCLASS hash_geometry_ops
OPERATORCLASS hash_raster_ops
OPERATORCLASS spgist_geography_ops_nd
OPERATORCLASS spgist_geometry_ops_2d
OPERATORCLASS spgist_geometry_ops_3d
OPERATORCLASS spgist_geometry_ops_nd
OPERATOR|&>(geometry,geometry)
OPERATOR|=|(geometry,geometry)
OPERATOR|>>(geometry,geometry)
OPERATOR~(box2df,box2df)
OPERATOR~(box2df,geometry)
OPERATOR~(geometry,box2df)
OPERATOR~(geometry,geometry)
OPERATOR~=(geometry,geometry)
OPERATOR~==(geometry,geometry)
OPERATOR~~(geometry,geometry)
OPERATOR~~=(geometry,geometry)
RULE geometry_columns geometry_columns_delete
RULE geometry_columns geometry_columns_insert
RULE geometry_columns geometry_columns_update
SCHEMA topology
SEQUENCE BY topology topology_id_seq
SEQUENCE topology topology_id_seq
SEQUENCE topology_id_seq
SHELLTYPE box2d
SHELLTYPE box2df
SHELLTYPE box3d
SHELLTYPE geography
SHELLTYPE geometry
SHELLTYPE gidx
SHELLTYPE raster
SHELLTYPE spheroid
TABLE layer
TABLE spatial_ref_sys
TABLE topology
TABLEDATA spatial_ref_sys
TRIGGER layer layer_integrity_checks
TYPE addbandarg
TYPE agg_count
TYPE agg_samealignment
TYPE bandmetadata;
TYPE box2d
TYPE box2df
TYPE box3d
TYPE geography
TYPE geometry
TYPE geometry_dump
TYPE geomval
TYPE geomvalxy;
TYPE getfaceedges_returntype
TYPE gidx
TYPE histogram;
TYPE pgis_abs
TYPE quantile;
TYPE rastbandarg
TYPE raster
TYPE reclassarg
TYPE spheroid
TYPE summarystats
TYPE topoelement
TYPE topoelementarray
TYPE topogeometry
TYPE unionarg
TYPE valid_detail
TYPE validatetopology_returntype
TYPE valuecount;
TYPE wktgeomval;
VIEW geography_columns
VIEW geometry_columns
VIEW raster_columns
VIEW raster_overviews
